diff -pruN 4:22.12.3-1/.gitlab-ci.yml 4:24.02.2-1/.gitlab-ci.yml
--- 4:22.12.3-1/.gitlab-ci.yml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/.gitlab-ci.yml	2024-04-08 15:00:12.000000000 +0000
@@ -2,6 +2,11 @@
 # SPDX-License-Identifier: CC0-1.0
 
 include:
-  #- https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/reuse-lint.yml
-  - https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/linux.yml
-  - https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/freebsd.yml
+  - project: sysadmin/ci-utilities
+    file:
+      - /gitlab-templates/json-validation.yml
+  #    - /gitlab-templates/reuse-lint.yml
+      - /gitlab-templates/linux.yml
+      - /gitlab-templates/freebsd.yml
+      # - /gitlab-templates/linux-qt6.yml # no libaccounts-qt and friends in CI yet
+      # - /gitlab-templates/freebsd-qt6.yml
diff -pruN 4:22.12.3-1/.kde-ci.yml 4:24.02.2-1/.kde-ci.yml
--- 4:22.12.3-1/.kde-ci.yml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/.kde-ci.yml	2024-04-08 15:00:12.000000000 +0000
@@ -9,6 +9,11 @@ Dependencies:
     'frameworks/ki18n': '@stable'
     'frameworks/kcoreaddons': '@stable'
     'frameworks/kdbusaddons': '@stable'
-    'frameworks/kdeclarative': '@stable'
     'frameworks/kwallet': '@stable'
     'frameworks/kio': '@stable'
+    'third-party/qcoro': '@latest'
+    'third-party/libaccounts-qt': '@latest'
+    'third-party/signond': '@latest'
+
+Options:
+  cmake-options: "-DKF6_COMPAT_BUILD=ON" # This is for the Qt5 build. Revisit this once we have a working Qt6 build and only enable for Qt5
diff -pruN 4:22.12.3-1/CMakeLists.txt 4:24.02.2-1/CMakeLists.txt
--- 4:22.12.3-1/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -1,16 +1,26 @@
 cmake_minimum_required(VERSION 3.16)
 
-set(RELEASE_SERVICE_VERSION_MAJOR "22")
-set(RELEASE_SERVICE_VERSION_MINOR "12")
-set(RELEASE_SERVICE_VERSION_MICRO "3")
+set(RELEASE_SERVICE_VERSION_MAJOR "24")
+set(RELEASE_SERVICE_VERSION_MINOR "02")
+set(RELEASE_SERVICE_VERSION_MICRO "2")
 set(KACCOUNTS_VERSION "${RELEASE_SERVICE_VERSION_MAJOR}.${RELEASE_SERVICE_VERSION_MINOR}.${RELEASE_SERVICE_VERSION_MICRO}")
 
 project(KAccounts LANGUAGES CXX VERSION ${KACCOUNTS_VERSION})
 
-set(QT_REQUIRED_VERSION "5.15.0")
-set(KF5_MIN_VERSION "5.97.0")
+set(QT_REQUIRED_VERSION "6.5.0")
+set(KF_MIN_VERSION "5.240.0")
+set(CMAKE_CXX_STANDARD 20)
+set(CMAKE_CXX_STANDARD_REQUIRED ON)
+
+option(KF6_COMPAT_BUILD "Enable this to get a build to support KF5 applications" OFF)
+
+if(KF6_COMPAT_BUILD)
+   set(QT_REQUIRED_VERSION "5.15.2")
+   set(KF_MIN_VERSION "5.97.0")
+   set(QT_MAJOR_VERSION "5")
+endif()
 
-find_package(ECM ${KF5_MIN_VERSION} REQUIRED NO_MODULE)
+find_package(ECM ${KF_MIN_VERSION} REQUIRED NO_MODULE)
 set(CMAKE_MODULE_PATH ${ECM_MODULE_PATH})
 
 include(KDEInstallDirs)
@@ -26,14 +36,15 @@ include(CMakePackageConfigHelpers)
 include(GenerateExportHeader)
 include(FeatureSummary)
 include(ECMQmlModule)
+include(ECMDeprecationSettings)
 
 set(KACCOUNTS_SOVERSION "2")
-set(ACCOUNTSQT_DEP_VERSION "1.13")
+set(ACCOUNTSQT_DEP_VERSION "1.16")
 set(SIGNONQT_DEP_VERSION "8.55")
 set(ACCOUNTSGLIB_DEP_VERSION "1.21")
 
-find_package(Qt${QT_MAJOR_VERSION} ${QT_REQUIRED_VERSION} CONFIG REQUIRED Core Widgets)
-find_package(KF5 ${KF5_MIN_VERSION} REQUIRED KCMUtils I18n CoreAddons DBusAddons Declarative Wallet KIO)
+find_package(Qt${QT_MAJOR_VERSION} ${QT_REQUIRED_VERSION} CONFIG REQUIRED Core Widgets Qml)
+find_package(KF${QT_MAJOR_VERSION} ${KF_MIN_VERSION} REQUIRED KCMUtils I18n CoreAddons DBusAddons Wallet KIO)
 
 find_package(AccountsQt${QT_MAJOR_VERSION} ${ACCOUNTSQT_DEP_VERSION} CONFIG)
 set_package_properties(AccountsQt${QT_MAJOR_VERSION} PROPERTIES DESCRIPTION "Accounts management library for Qt applications"
@@ -47,11 +58,21 @@ set_package_properties(SignOnQt${QT_MAJO
    TYPE REQUIRED
    PURPOSE "Required for building this module")
 
-add_definitions (-DTRANSLATION_DOMAIN=\"kaccounts-integration\")
+find_package(QCoro${QT_MAJOR_VERSION} REQUIRED COMPONENTS Core)
+
+qcoro_enable_coroutines()
+
+add_definitions(-DTRANSLATION_DOMAIN=\"kaccounts-integration\")
+
+ecm_set_disabled_deprecation_versions(QT 5.13.0
+     KF 5.101.0
+)
 
 add_subdirectory(src)
 
-ki18n_install(po)
+if(NOT KF6_COMPAT_BUILD)
+   ki18n_install(po)
+endif()
 
 file(GLOB_RECURSE ALL_CLANG_FORMAT_SOURCE_FILES *.cpp *.h)
 kde_clang_format(${ALL_CLANG_FORMAT_SOURCE_FILES})
diff -pruN 4:22.12.3-1/debian/changelog 4:24.02.2-1/debian/changelog
--- 4:22.12.3-1/debian/changelog	2023-03-01 10:57:45.000000000 +0000
+++ 4:24.02.2-1/debian/changelog	2024-05-21 21:20:18.000000000 +0000
@@ -1,3 +1,23 @@
+kaccounts-integration (4:24.02.2-1) experimental; urgency=medium
+
+  [ Aurélien COUDERC ]
+  * New upstream release (24.02.2).
+  * Build against Qt6:
+    - switch from libkaccounts-dev to libkaccounts6-dev development package
+    - switch from libkaccounts2 to libkaccounts6-2 shared library
+    - switch from qml-module-org-kde-kaccounts to
+      qml6-module-org-kde-kaccounts QML module.
+  * Replace manual use of dh addons with dh-sequence-kf6 and
+    dh-sequence-pkgkde-symbolshelper declarative build dependencies.
+  * Replace transitional pkg-config build dependency with actual pkgconf.
+  * Refresh copyright information.
+  * Recommend systemsettings.
+  * Improve package descriptions.
+  * Drop old Breaks relations.
+  * Bump Standards-Version to 4.7.0, no change required.
+
+ -- Aurélien COUDERC <coucouf@debian.org>  Tue, 21 May 2024 23:20:18 +0200
+
 kaccounts-integration (4:22.12.3-1) unstable; urgency=medium
 
   [ Aurélien COUDERC ]
diff -pruN 4:22.12.3-1/debian/control 4:24.02.2-1/debian/control
--- 4:22.12.3-1/debian/control	2023-03-01 10:14:06.000000000 +0000
+++ 4:24.02.2-1/debian/control	2024-05-21 21:20:18.000000000 +0000
@@ -7,26 +7,25 @@ Uploaders: Aurélien COUDERC <coucouf@de
            Norbert Preining <norbert@preining.info>,
 Build-Depends: cmake (>= 3.16~),
                debhelper-compat (= 13),
-               extra-cmake-modules (>= 5.97.0~),
+               dh-sequence-kf6,
+               dh-sequence-pkgkde-symbolshelper,
+               extra-cmake-modules (>= 5.240.0~),
                gettext,
-               libaccounts-glib-dev (>= 1.21~),
-               libaccounts-qt5-dev (>= 1.13~),
-               libkf5config-dev (>= 5.4.0~),
-               libkf5coreaddons-dev (>= 5.97.0~),
-               libkf5dbusaddons-dev (>= 5.97.0~),
-               libkf5declarative-dev (>= 5.97.0~),
-               libkf5i18n-dev (>= 5.97.0~),
-               libkf5iconthemes-dev (>= 5.4.0~),
-               libkf5kcmutils-dev (>= 5.97.0~),
-               libkf5kio-dev (>= 5.97.0~),
-               libkf5wallet-dev (>= 5.97.0~),
-               libkf5widgetsaddons-dev (>= 5.4.0~),
-               libsignon-qt5-dev (>= 8.55~),
-               pkg-config,
-               pkg-kde-tools (>> 0.15.15),
-               qtbase5-dev (>= 5.15.0~),
-               qtdeclarative5-dev (>= 5.7.0~),
-Standards-Version: 4.6.2
+               libaccounts-qt6-dev (>= 1.16~),
+               libkf6config-dev (>= 5.240.0~),
+               libkf6coreaddons-dev (>= 5.240.0~),
+               libkf6dbusaddons-dev (>= 5.240.0~),
+               libkf6i18n-dev (>= 5.240.0~),
+               libkf6kcmutils-dev (>= 5.240.0~),
+               libkf6kio-dev (>= 5.240.0~),
+               libkf6wallet-dev (>= 5.240.0~),
+               libsignon-qt6-dev (>= 8.55~),
+               pkgconf,
+               pkg-kde-tools,
+               qcoro-qt6-dev,
+               qt6-base-dev (>= 6.5.0+dfsg~),
+               qt6-declarative-dev (>= 6.5.0+dfsg~),
+Standards-Version: 4.7.0
 Rules-Requires-Root: no
 Homepage: https://projects.kde.org/projects/kde/kdenetwork/kaccounts-integration
 Vcs-Browser: https://salsa.debian.org/qt-kde-team/kde/kaccounts-integration
@@ -34,65 +33,84 @@ Vcs-Git: https://salsa.debian.org/qt-kde
 
 Package: kaccounts-integration
 Architecture: any
-Depends: qml-module-org-kde-kaccounts (= ${binary:Version}),
-         qml-module-org-kde-kcm,
-         qml-module-org-kde-kirigami2,
-         qml-module-qtquick-controls2,
-         qml-module-qtquick-layouts,
-         qml-module-qtquick2,
+Depends: qml6-module-org-kde-kaccounts (= ${binary:Version}),
+         qml6-module-org-kde-kcmutils,
+         qml6-module-org-kde-kirigami,
+         qml6-module-qtquick,
+         qml6-module-qtquick-controls,
+         qml6-module-qtquick-layouts,
          signon-kwallet-extension,
          signon-plugin-oauth2,
          signon-plugin-password,
-         signon-ui-x11,
+         signon-ui-qt,
          signond,
          ${misc:Depends},
          ${shlibs:Depends},
-Recommends: kaccounts-providers,
-Breaks: kde-config-telepathy-accounts (<< 17.08),
-        libktpcommoninternals9 (<< 17.08),
-Description: System to administer web accounts
- Small system to administer web accounts for the sites and services
- across the Plasma desktop, including: Google, Facebook, Owncloud, IMAP,
- Jabber and others.
+Recommends: kaccounts-providers, systemsettings
+Description: integration for Accounts-SSO and SignOn-SSO
+ KAccounts Integration provides a way to share accounts data such as login
+ tokens and general user information (like usernames and such) between various
+ applications.
 
-Package: libkaccounts-dev
+Package: libkaccounts6-dev
 Section: libdevel
 Architecture: any
 Depends: intltool,
-         libaccounts-glib-dev,
-         libaccounts-qt5-dev (>= 1.13~),
-         libkaccounts2 (= ${binary:Version}),
-         libkf5coreaddons-dev (>= 5.97.0~),
-         libsignon-qt5-dev (>= 8.55~),
-         pkg-config,
+         libaccounts-qt6-dev (>= 1.16~),
+         libkaccounts6-2 (= ${binary:Version}),
+         libkf6config-dev (>= 5.240.0~),
+         libkf6coreaddons-dev (>= 5.240.0~),
+         libkf6dbusaddons-dev (>= 5.240.0~),
+         libkf6i18n-dev (>= 5.240.0~),
+         libkf6kcmutils-dev (>= 5.240.0~),
+         libkf6kio-dev (>= 5.240.0~),
+         libkf6wallet-dev (>= 5.240.0~),
+         libsignon-qt6-dev (>= 8.55~),
+         qcoro-qt6-dev,
+         qt6-base-dev (>= 6.5.0+dfsg~),
+         qt6-declarative-dev (>= 6.5.0+dfsg~),
          ${misc:Depends},
-Description: System to administer web accounts - development files
- Small system to administer web accounts for the sites and services across the
- Plasma desktop, including: Google, Facebook, Owncloud, IMAP, Jabber and others.
+Description: integration library and QML module for Accounts-SSO and SignOn-SSO - development files
+ KAccounts Integration provides a way to share accounts data such as login
+ tokens and general user information (like usernames and such) between various
+ applications.
+ .
+ The KAccounts library is a KDE Frameworks style abstraction layer on top of
+ the Accounts-SSO and SignOnD libraries, which uses a combination of models and
+ jobs to expose the functionality of those.
+ .
+ The kaccounts QML plugin exposes that functionality directly to Qt Quick based
+ applications.
  .
  This package contains development files.
 
-Package: libkaccounts2
+Package: libkaccounts6-2
 Section: libs
 Architecture: any
 Multi-Arch: same
 Depends: ${misc:Depends}, ${shlibs:Depends},
 Recommends: kaccounts-providers,
-Breaks: kaccounts-providers (<< 4:17.08),
-        kde-config-telepathy-accounts (<< 17.08),
-        kde-telepathy-auth-handler (<< 17.08),
-        kde-telepathy-kaccounts (<< 17.08),
-Description: System to administer web accounts - shared library
- Small system to administer web accounts for the sites and services across the
- Plasma desktop, including: Google, Facebook, Owncloud, IMAP, Jabber and others.
+Description: integration library for Accounts-SSO and SignOn-SSO
+ KAccounts Integration provides a way to share accounts data such as login
+ tokens and general user information (like usernames and such) between various
+ applications.
  .
- This package contains the shared library.
+ The KAccounts library is a KDE Frameworks style abstraction layer on top of
+ the Accounts-SSO and SignOnD libraries, which uses a combination of models and
+ jobs to expose the functionality of those.
 
-Package: qml-module-org-kde-kaccounts
+Package: qml6-module-org-kde-kaccounts
 Architecture: any
 Multi-Arch: same
 Depends: ${misc:Depends}, ${shlibs:Depends},
-Description: KAccounts QtDeclarative QML Support
- Contains a plugin for QtDeclarative that provides
- support for using KAccounts components written
- in QML.
+Description: QML module for Accounts-SSO and SignOn-SSO
+ KAccounts Integration provides a way to share accounts data such as login
+ tokens and general user information (like usernames and such) between various
+ applications.
+ .
+ The KAccounts library is a KDE Frameworks style abstraction layer on top of
+ the Accounts-SSO and SignOnD libraries, which uses a combination of models and
+ jobs to expose the functionality of those.
+ .
+ The kaccounts QML plugin exposes that functionality directly to Qt Quick based
+ applications.
diff -pruN 4:22.12.3-1/debian/copyright 4:24.02.2-1/debian/copyright
--- 4:22.12.3-1/debian/copyright	2022-12-10 15:02:04.000000000 +0000
+++ 4:24.02.2-1/debian/copyright	2024-05-21 21:20:18.000000000 +0000
@@ -20,12 +20,11 @@ Files: src/lib/core.cpp
 Copyright: 2014, Martin Klapetek <mklapetek@kde.org>
 License: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-Files: src/kcm/package/contents/ui/AccountDetails.qml
-       src/kcm/package/contents/ui/AvailableAccounts.qml
-       src/kcm/package/contents/ui/main.qml
-       src/kcm/package/contents/ui/MessageBoxSheet.qml
-       src/kcm/package/contents/ui/RemoveAccountDialog.qml
-       src/kcm/package/contents/ui/RenameAccountDialog.qml
+Files: src/kcm/ui/AccountDetails.qml
+       src/kcm/ui/AvailableAccounts.qml
+       src/kcm/ui/main.qml
+       src/kcm/ui/RemoveAccountDialog.qml
+       src/kcm/ui/RenameAccountDialog.qml
        src/lib/getcredentialsjob.cpp
        src/lib/getcredentialsjob.h
 Copyright: 2013, Alejandro Fiestas Olivares <afiestas@kde.org>
@@ -34,8 +33,14 @@ Copyright: 2013, Alejandro Fiestas Oliva
            2019, Nicolas Fella <nicolas.fella@gmx.de>
 License: LGPL-2.0-or-later
 
+Files: po/ca/*
+       po/ca@valencia/*
+       po/uk/*
+Copyright: 2014-2021, This_file_is_part_of_KDE
+License: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+
 Files: debian/*
-Copyright: 2020-2022, Debian Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
+Copyright: 2020-2024, Debian Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
            2014, Harald Sitter <sitter@kde.org>
 License: GPL-2.0-or-later
 
@@ -117,6 +122,44 @@ License: LGPL-2.0-or-later
  Public License version 2 can be found in
  `/usr/share/common-licenses/LGPL-2’.
 
+License: LGPL-2.1-only
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of the GNU Lesser General Public License version
+ 2.1 as published by the Free Software Foundation.
+ .
+ This library is distributed in the hope that it will be useful, but
+ WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ Lesser General Public License for more details.
+ .
+ You should have received a copy of the GNU Lesser General Public
+ License along with this library; if not, write to the Free Software
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ 02110-1301  USA Also add information on how to contact you by
+ electronic and paper mail.
+ .
+ On Debian systems, the complete text of the GNU Lesser General
+ Public License version 2.1 can be found in
+ `/usr/share/common-licenses/LGPL-2.1’.
+
+License: LGPL-3.0-only
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of the GNU Lesser General Public License version
+ 3 as published by the Free Software Foundation.
+ .
+ This library is distributed in the hope that it will be useful, but
+ WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ Lesser General Public License for more details.
+ .
+ You should have received a copy of the GNU Lesser General Public
+ License along with this library.  If not, see
+ <http://www.gnu.org/licenses/>.
+ .
+ On Debian systems, the complete text of the GNU Lesser General
+ Public License version 3 can be found in
+ `/usr/share/common-licenses/LGPL-3’.
+
 License: LicenseRef-KDE-Accepted-GPL
  This library is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -128,5 +171,19 @@ License: LicenseRef-KDE-Accepted-GPL
  .
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ General Public License for more details.
+
+License: LicenseRef-KDE-Accepted-LGPL
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of the GNU Lesser General Public License as
+ published by the Free Software Foundation; either version 3 of the
+ license or (at your option) any later version that is accepted by
+ the membership of KDE e.V. (or its successor approved by the
+ membership of KDE e.V.), which shall act as a proxy as defined in
+ Section 6 of version 3 of the license.
+ .
+ This program is distributed in the hope that it will be useful, but
+ WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.
diff -pruN 4:22.12.3-1/debian/kaccounts-integration.install 4:24.02.2-1/debian/kaccounts-integration.install
--- 4:22.12.3-1/debian/kaccounts-integration.install	2022-11-28 16:59:57.000000000 +0000
+++ 4:24.02.2-1/debian/kaccounts-integration.install	2024-05-21 20:31:07.000000000 +0000
@@ -1,5 +1,5 @@
-usr/lib/*/qt5/plugins/kaccounts/
-usr/lib/*/qt5/plugins/plasma/kcms/systemsettings/kcm_kaccounts.so
-usr/lib/*/qt5/plugins/kf5/kded/kded_accounts.so
-usr/share/kpackage/
-usr/share/locale/
+usr/lib/*/qt6/plugins/kaccounts/
+usr/lib/*/qt6/plugins/plasma/kcms/systemsettings/kcm_kaccounts.so
+usr/lib/*/qt6/plugins/kf6/kded/kded_accounts.so
+usr/share/applications/kcm_kaccounts.desktop
+usr/share/locale/*/LC_MESSAGES/kaccounts-integration.mo
diff -pruN 4:22.12.3-1/debian/kaccounts-integration.lintian-overrides 4:24.02.2-1/debian/kaccounts-integration.lintian-overrides
--- 4:22.12.3-1/debian/kaccounts-integration.lintian-overrides	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/debian/kaccounts-integration.lintian-overrides	2024-05-21 21:20:18.000000000 +0000
@@ -0,0 +1,2 @@
+# systemsettings executable required to use the KCM module is provided by the Recommends: systemsettings dependency
+kaccounts-integration: desktop-command-not-in-package systemsettings [usr/share/applications/kcm_kaccounts.desktop]
diff -pruN 4:22.12.3-1/debian/libkaccounts-dev.install 4:24.02.2-1/debian/libkaccounts-dev.install
--- 4:22.12.3-1/debian/libkaccounts-dev.install	2022-09-04 12:46:38.000000000 +0000
+++ 4:24.02.2-1/debian/libkaccounts-dev.install	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-usr/include/KAccounts/
-usr/lib/*/cmake/KAccounts/
-usr/lib/*/libkaccounts.so
diff -pruN 4:22.12.3-1/debian/libkaccounts2.install 4:24.02.2-1/debian/libkaccounts2.install
--- 4:22.12.3-1/debian/libkaccounts2.install	2022-09-04 12:46:38.000000000 +0000
+++ 4:24.02.2-1/debian/libkaccounts2.install	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-usr/lib/*/libkaccounts.so.2
-usr/lib/*/libkaccounts.so.2*
diff -pruN 4:22.12.3-1/debian/libkaccounts2.symbols 4:24.02.2-1/debian/libkaccounts2.symbols
--- 4:22.12.3-1/debian/libkaccounts2.symbols	2022-09-04 12:46:38.000000000 +0000
+++ 4:24.02.2-1/debian/libkaccounts2.symbols	1970-01-01 00:00:00.000000000 +0000
@@ -1,192 +0,0 @@
-# SymbolsHelper-Confirmed: 4:20.07.90 amd64
-libkaccounts.so.2 libkaccounts2 #MINVER#
-* Build-Depends-Package: libkaccounts-dev
- _ZN13AccountsModel11qt_metacallEN11QMetaObject4CallEiPPv@Base 4:20.07.90
- _ZN13AccountsModel11qt_metacastEPKc@Base 4:20.07.90
- _ZN13AccountsModel16staticMetaObjectE@Base 4:20.07.90
- _ZN13AccountsModel7Private11accountByIdEi@Base 4:20.07.90
- _ZN13AccountsModel7Private13removeAccountEj@Base 4:20.07.90
- _ZN13AccountsModelC1EP7QObject@Base 4:20.07.90
- _ZN13AccountsModelC2EP7QObject@Base 4:20.07.90
- _ZN13AccountsModelD0Ev@Base 4:20.07.90
- _ZN13AccountsModelD1Ev@Base 4:20.07.90
- _ZN13AccountsModelD2Ev@Base 4:20.07.90
- _ZN13ServicesModel10setAccountEP7QObject@Base 4:20.07.90
- _ZN13ServicesModel11qt_metacallEN11QMetaObject4CallEiPPv@Base 4:20.07.90
- _ZN13ServicesModel11qt_metacastEPKc@Base 4:20.07.90
- _ZN13ServicesModel14accountChangedEv@Base 4:20.07.90
- _ZN13ServicesModel16staticMetaObjectE@Base 4:20.07.90
- _ZN13ServicesModelC1EP7QObject@Base 4:20.07.90
- _ZN13ServicesModelC2EP7QObject@Base 4:20.07.90
- _ZN13ServicesModelD0Ev@Base 4:20.07.90
- _ZN13ServicesModelD1Ev@Base 4:20.07.90
- _ZN13ServicesModelD2Ev@Base 4:20.07.90
- _ZN14ProvidersModel11qt_metacallEN11QMetaObject4CallEiPPv@Base 4:20.07.90
- _ZN14ProvidersModel11qt_metacastEPKc@Base 4:20.07.90
- _ZN14ProvidersModel16staticMetaObjectE@Base 4:20.07.90
- _ZN14ProvidersModelC1EP7QObject@Base 4:20.07.90
- _ZN14ProvidersModelC2EP7QObject@Base 4:20.07.90
- _ZN14ProvidersModelD0Ev@Base 4:20.07.90
- _ZN14ProvidersModelD1Ev@Base 4:20.07.90
- _ZN14ProvidersModelD2Ev@Base 4:20.07.90
- _ZN16CreateAccountJob11pluginErrorERK7QString@Base 4:20.07.90
- _ZN16CreateAccountJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 4:20.07.90
- _ZN16CreateAccountJob11qt_metacastEPKc@Base 4:20.07.90
- _ZN16CreateAccountJob12sessionErrorERKN6SignOn5ErrorE@Base 4:20.07.90
- _ZN16CreateAccountJob14pluginFinishedERK7QStringS2_RK4QMapIS0_8QVariantE@Base 4:20.07.90
- _ZN16CreateAccountJob14processSessionEv@Base 4:20.07.90
- _ZN16CreateAccountJob15pluginCancelledEv@Base 4:20.12.0
- _ZN16CreateAccountJob15sessionResponseERKN6SignOn11SessionDataE@Base 4:20.07.90
- _ZN16CreateAccountJob15setProviderNameERK7QString@Base 4:20.07.90
- _ZN16CreateAccountJob16staticMetaObjectE@Base 4:20.07.90
- _ZN16CreateAccountJob19providerNameChangedEv@Base 4:20.07.90
- _ZN16CreateAccountJob23loadPluginAndShowDialogERK7QString@Base 4:20.07.90
- _ZN16CreateAccountJob4infoERKN6SignOn12IdentityInfoE@Base 4:20.07.90
- _ZN16CreateAccountJob5startEv@Base 4:20.07.90
- _ZN16CreateAccountJobC1EP7QObject@Base 4:20.07.90
- _ZN16CreateAccountJobC1ERK7QStringP7QObject@Base 4:20.07.90
- _ZN16CreateAccountJobC2EP7QObject@Base 4:20.07.90
- _ZN16CreateAccountJobC2ERK7QStringP7QObject@Base 4:20.07.90
- _ZN16KAccountsDPlugin11qt_metacallEN11QMetaObject4CallEiPPv@Base 0.0
- _ZN16KAccountsDPlugin11qt_metacastEPKc@Base 0.0
- _ZN16KAccountsDPlugin16staticMetaObjectE@Base 0.0
- _ZN16KAccountsDPluginC1EP7QObjectRK5QListI8QVariantE@Base 4:20.07.90
- _ZN16KAccountsDPluginC2EP7QObjectRK5QListI8QVariantE@Base 4:20.07.90
- _ZN16KAccountsDPluginD0Ev@Base 0.0
- _ZN16KAccountsDPluginD1Ev@Base 0.0
- _ZN16KAccountsDPluginD2Ev@Base 0.0
- _ZN16RemoveAccountJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 4:20.07.90
- _ZN16RemoveAccountJob11qt_metacastEPKc@Base 4:20.07.90
- _ZN16RemoveAccountJob12setAccountIdERK7QString@Base 4:20.07.90
- _ZN16RemoveAccountJob16accountIdChangedEv@Base 4:20.07.90
- _ZN16RemoveAccountJob16staticMetaObjectE@Base 4:20.07.90
- _ZN16RemoveAccountJob5startEv@Base 4:20.07.90
- _ZN16RemoveAccountJobC1EP7QObject@Base 4:20.07.90
- _ZN16RemoveAccountJobC2EP7QObject@Base 4:20.07.90
- _ZN16RemoveAccountJobD0Ev@Base 4:20.07.90
- _ZN16RemoveAccountJobD1Ev@Base 4:20.07.90
- _ZN16RemoveAccountJobD2Ev@Base 4:20.07.90
- _ZN17GetCredentialsJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 0.0
- _ZN17GetCredentialsJob11qt_metacastEPKc@Base 0.0
- _ZN17GetCredentialsJob14setServiceTypeERK7QString@Base 0.0
- _ZN17GetCredentialsJob16staticMetaObjectE@Base 0.0
- _ZN17GetCredentialsJob5startEv@Base 0.0
- _ZN17GetCredentialsJob7Private14getCredentialsEv@Base 0.0
- _ZN17GetCredentialsJobC1EjP7QObject@Base 4:20.07.90
- _ZN17GetCredentialsJobC1EjRK7QStringS2_P7QObject@Base 4:20.07.90
- _ZN17GetCredentialsJobC2EjP7QObject@Base 4:20.07.90
- _ZN17GetCredentialsJobC2EjRK7QStringS2_P7QObject@Base 4:20.07.90
- _ZN17GetCredentialsJobD0Ev@Base 4:20.07.90
- _ZN17GetCredentialsJobD1Ev@Base 4:20.07.90
- _ZN17GetCredentialsJobD2Ev@Base 4:20.07.90
- _ZN17KAccountsUiPlugin11qt_metacallEN11QMetaObject4CallEiPPv@Base 0.0
- _ZN17KAccountsUiPlugin11qt_metacastEPKc@Base 0.0
- _ZN17KAccountsUiPlugin13configUiReadyEv@Base 15.08.3
- _ZN17KAccountsUiPlugin16staticMetaObjectE@Base 0.0
- _ZN17KAccountsUiPlugin5errorERK7QString@Base 0.0
- _ZN17KAccountsUiPlugin7successERK7QStringS2_RK4QMapIS0_8QVariantE@Base 0.0
- _ZN17KAccountsUiPlugin7uiReadyEv@Base 0.0
- _ZN17KAccountsUiPlugin8canceledEv@Base 4:20.12.0
- _ZN17KAccountsUiPluginC1EP7QObject@Base 0.0
- _ZN17KAccountsUiPluginC2EP7QObject@Base 0.0
- _ZN17KAccountsUiPluginD0Ev@Base 0.0
- _ZN17KAccountsUiPluginD1Ev@Base 0.0
- _ZN17KAccountsUiPluginD2Ev@Base 0.0
- _ZN23AccountServiceToggleJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 4:20.07.90
- _ZN23AccountServiceToggleJob11qt_metacastEPKc@Base 4:20.07.90
- _ZN23AccountServiceToggleJob12setAccountIdERK7QString@Base 4:20.07.90
- _ZN23AccountServiceToggleJob12setServiceIdERK7QString@Base 4:20.07.90
- _ZN23AccountServiceToggleJob16accountIdChangedEv@Base 4:20.07.90
- _ZN23AccountServiceToggleJob16serviceIdChangedEv@Base 4:20.07.90
- _ZN23AccountServiceToggleJob16staticMetaObjectE@Base 4:20.07.90
- _ZN23AccountServiceToggleJob17setServiceEnabledEb@Base 4:20.07.90
- _ZN23AccountServiceToggleJob21serviceEnabledChangedEv@Base 4:20.07.90
- _ZN23AccountServiceToggleJob5startEv@Base 4:20.07.90
- _ZN23AccountServiceToggleJobC1EP7QObject@Base 4:20.07.90
- _ZN23AccountServiceToggleJobC2EP7QObject@Base 4:20.07.90
- _ZN23AccountServiceToggleJobD0Ev@Base 4:20.07.90
- _ZN23AccountServiceToggleJobD1Ev@Base 4:20.07.90
- _ZN23AccountServiceToggleJobD2Ev@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob11qt_metacastEPKc@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob12setAccountIdERK7QString@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob14setDisplayNameERK7QString@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob16accountIdChangedEv@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob16staticMetaObjectE@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob18displayNameChangedEv@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJob5startEv@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJobC1EP7QObject@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJobC2EP7QObject@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJobD0Ev@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJobD1Ev@Base 4:20.07.90
- _ZN27ChangeAccountDisplayNameJobD2Ev@Base 4:20.07.90
- _ZN9KAccounts15accountsManagerEv@Base 0.0
- _ZNK13AccountsModel10metaObjectEv@Base 4:20.07.90
- _ZNK13AccountsModel4dataERK11QModelIndexi@Base 4:20.07.90
- _ZNK13AccountsModel8rowCountERK11QModelIndex@Base 4:20.07.90
- _ZNK13AccountsModel9roleNamesEv@Base 4:20.07.90
- _ZNK13ServicesModel10metaObjectEv@Base 4:20.07.90
- _ZNK13ServicesModel15accountIconNameEv@Base 4:20.07.90
- _ZNK13ServicesModel18accountDisplayNameEv@Base 4:20.07.90
- _ZNK13ServicesModel19accountProviderNameEv@Base 4:20.07.90
- _ZNK13ServicesModel4dataERK11QModelIndexi@Base 4:20.07.90
- _ZNK13ServicesModel7accountEv@Base 4:20.07.90
- _ZNK13ServicesModel8rowCountERK11QModelIndex@Base 4:20.07.90
- _ZNK13ServicesModel9accountIdEv@Base 4:20.07.90
- _ZNK13ServicesModel9roleNamesEv@Base 4:20.07.90
- _ZNK14ProvidersModel10metaObjectEv@Base 4:20.07.90
- _ZNK14ProvidersModel4dataERK11QModelIndexi@Base 4:20.07.90
- _ZNK14ProvidersModel8rowCountERK11QModelIndex@Base 4:20.07.90
- _ZNK14ProvidersModel9roleNamesEv@Base 4:20.07.90
- _ZNK16CreateAccountJob10metaObjectEv@Base 4:20.07.90
- _ZNK16KAccountsDPlugin10metaObjectEv@Base 0.0
- _ZNK16RemoveAccountJob10metaObjectEv@Base 4:20.07.90
- _ZNK16RemoveAccountJob9accountIdEv@Base 4:20.07.90
- _ZNK17GetCredentialsJob10metaObjectEv@Base 0.0
- _ZNK17GetCredentialsJob15credentialsDataEv@Base 0.0
- _ZNK17GetCredentialsJob9accountIdEv@Base 0.0
- _ZNK17KAccountsUiPlugin10metaObjectEv@Base 0.0
- _ZNK17KAccountsUiPlugin15transientParentEv@Base 15.08.3
- _ZNK23AccountServiceToggleJob10metaObjectEv@Base 4:20.07.90
- _ZNK23AccountServiceToggleJob14serviceEnabledEv@Base 4:20.07.90
- _ZNK23AccountServiceToggleJob9accountIdEv@Base 4:20.07.90
- _ZNK23AccountServiceToggleJob9serviceIdEv@Base 4:20.07.90
- _ZNK27ChangeAccountDisplayNameJob10metaObjectEv@Base 4:20.07.90
- _ZNK27ChangeAccountDisplayNameJob11displayNameEv@Base 4:20.07.90
- _ZNK27ChangeAccountDisplayNameJob9accountIdEv@Base 4:20.07.90
- _ZTI13AccountsModel@Base 4:20.07.90
- _ZTI13ServicesModel@Base 4:20.07.90
- _ZTI14ProvidersModel@Base 4:20.07.90
- _ZTI16CreateAccountJob@Base 4:20.07.90
- _ZTI16KAccountsDPlugin@Base 0.0
- _ZTI16RemoveAccountJob@Base 4:20.07.90
- _ZTI17GetCredentialsJob@Base 0.0
- _ZTI17KAccountsUiPlugin@Base 0.0
- _ZTI23AccountServiceToggleJob@Base 4:20.07.90
- _ZTI27ChangeAccountDisplayNameJob@Base 4:20.07.90
- _ZTIN13AccountsModel7PrivateE@Base 4:20.07.90
- _ZTIN13ServicesModel7PrivateE@Base 4:20.07.90
- _ZTS13AccountsModel@Base 4:20.07.90
- _ZTS13ServicesModel@Base 4:20.07.90
- _ZTS14ProvidersModel@Base 4:20.07.90
- _ZTS16CreateAccountJob@Base 4:20.07.90
- _ZTS16KAccountsDPlugin@Base 0.0
- _ZTS16RemoveAccountJob@Base 4:20.07.90
- _ZTS17GetCredentialsJob@Base 0.0
- _ZTS17KAccountsUiPlugin@Base 0.0
- _ZTS23AccountServiceToggleJob@Base 4:20.07.90
- _ZTS27ChangeAccountDisplayNameJob@Base 4:20.07.90
- _ZTSN13AccountsModel7PrivateE@Base 4:20.07.90
- _ZTSN13ServicesModel7PrivateE@Base 4:20.07.90
- _ZTV13AccountsModel@Base 4:20.07.90
- _ZTV13ServicesModel@Base 4:20.07.90
- _ZTV14ProvidersModel@Base 4:20.07.90
- _ZTV16CreateAccountJob@Base 4:20.07.90
- _ZTV16KAccountsDPlugin@Base 0.0
- _ZTV16RemoveAccountJob@Base 4:20.07.90
- _ZTV17GetCredentialsJob@Base 0.0
- _ZTV17KAccountsUiPlugin@Base 0.0
- _ZTV23AccountServiceToggleJob@Base 4:20.07.90
- _ZTV27ChangeAccountDisplayNameJob@Base 4:20.07.90
- _ZTVN13AccountsModel7PrivateE@Base 4:20.07.90
- _ZTVN13ServicesModel7PrivateE@Base 4:20.07.90
diff -pruN 4:22.12.3-1/debian/libkaccounts6-2.install 4:24.02.2-1/debian/libkaccounts6-2.install
--- 4:22.12.3-1/debian/libkaccounts6-2.install	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/debian/libkaccounts6-2.install	2024-05-21 20:14:46.000000000 +0000
@@ -0,0 +1,2 @@
+usr/lib/*/libkaccounts6.so.2
+usr/lib/*/libkaccounts6.so.2*
diff -pruN 4:22.12.3-1/debian/libkaccounts6-2.symbols 4:24.02.2-1/debian/libkaccounts6-2.symbols
--- 4:22.12.3-1/debian/libkaccounts6-2.symbols	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/debian/libkaccounts6-2.symbols	2024-05-21 21:20:18.000000000 +0000
@@ -0,0 +1,198 @@
+# SymbolsHelper-Confirmed: 24.02.2 amd64
+libkaccounts6.so.2 libkaccounts6-2 #MINVER#
+* Build-Depends-Package: libkaccounts-dev
+ _ZN9KAccounts13AccountsModel11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts13AccountsModel11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts13AccountsModel16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts13AccountsModel7Private11accountByIdEi@Base 24.02.2
+ _ZN9KAccounts13AccountsModel7Private13removeAccountEj@Base 24.02.2
+ _ZN9KAccounts13AccountsModelC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts13AccountsModelC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts13AccountsModelD0Ev@Base 24.02.2
+ _ZN9KAccounts13AccountsModelD1Ev@Base 24.02.2
+ _ZN9KAccounts13AccountsModelD2Ev@Base 24.02.2
+ _ZN9KAccounts13ServicesModel10setAccountEP7QObject@Base 24.02.2
+ _ZN9KAccounts13ServicesModel11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts13ServicesModel11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts13ServicesModel14accountChangedEv@Base 24.02.2
+ _ZN9KAccounts13ServicesModel16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts13ServicesModelC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts13ServicesModelC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts13ServicesModelD0Ev@Base 24.02.2
+ _ZN9KAccounts13ServicesModelD1Ev@Base 24.02.2
+ _ZN9KAccounts13ServicesModelD2Ev@Base 24.02.2
+ _ZN9KAccounts14ProvidersModel11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts14ProvidersModel11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts14ProvidersModel16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts14ProvidersModelC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts14ProvidersModelC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts14ProvidersModelD0Ev@Base 24.02.2
+ _ZN9KAccounts14ProvidersModelD1Ev@Base 24.02.2
+ _ZN9KAccounts14ProvidersModelD2Ev@Base 24.02.2
+ _ZN9KAccounts15accountsManagerEv@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob11pluginErrorERK7QString@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob12sessionErrorERKN6SignOn5ErrorE@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob14pluginFinishedERK7QStringS3_RK4QMapIS1_8QVariantE@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob14processSessionEv@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob15pluginCancelledEv@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob15sessionResponseERKN6SignOn11SessionDataE@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob15setProviderNameERK7QString@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob16startAuthSessionERK4QMapI7QString8QVariantE@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob19providerNameChangedEv@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob23loadPluginAndShowDialogERK7QString@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob4infoERKN6SignOn12IdentityInfoE@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJob5startEv@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJobC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJobC1ERK7QStringP7QObject@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJobC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts16CreateAccountJobC2ERK7QStringP7QObject@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPlugin11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPlugin11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPlugin16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPluginC1EP7QObjectRK5QListI8QVariantE@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPluginC2EP7QObjectRK5QListI8QVariantE@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPluginD0Ev@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPluginD1Ev@Base 24.02.2
+ _ZN9KAccounts16KAccountsDPluginD2Ev@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJob11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJob12setAccountIdERK7QString@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJob16accountIdChangedEv@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJob16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJob5startEv@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJobC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJobC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJobD0Ev@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJobD1Ev@Base 24.02.2
+ _ZN9KAccounts16RemoveAccountJobD2Ev@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJob11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJob14setServiceTypeERK7QString@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJob16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJob5startEv@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJob7Private14getCredentialsEv@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJobC1EjP7QObject@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJobC1EjRK7QStringS3_P7QObject@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJobC2EjP7QObject@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJobC2EjRK7QStringS3_P7QObject@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJobD0Ev@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJobD1Ev@Base 24.02.2
+ _ZN9KAccounts17GetCredentialsJobD2Ev@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin13configUiReadyEv@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin16startAuthSessionERK4QMapI7QString8QVariantE@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin5errorERK7QString@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin7successERK7QStringS3_RK4QMapIS1_8QVariantE@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin7uiReadyEv@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPlugin8canceledEv@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPluginC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPluginC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPluginD0Ev@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPluginD1Ev@Base 24.02.2
+ _ZN9KAccounts17KAccountsUiPluginD2Ev@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob12setAccountIdERK7QString@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob12setServiceIdERK7QString@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob16accountIdChangedEv@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob16serviceIdChangedEv@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob17setServiceEnabledEb@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob21serviceEnabledChangedEv@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJob5startEv@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJobC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJobC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJobD0Ev@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJobD1Ev@Base 24.02.2
+ _ZN9KAccounts23AccountServiceToggleJobD2Ev@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob11qt_metacallEN11QMetaObject4CallEiPPv@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob11qt_metacastEPKc@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob12setAccountIdERK7QString@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob14setDisplayNameERK7QString@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob16accountIdChangedEv@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob16staticMetaObjectE@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob18displayNameChangedEv@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJob5startEv@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJobC1EP7QObject@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJobC2EP7QObject@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJobD0Ev@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJobD1Ev@Base 24.02.2
+ _ZN9KAccounts27ChangeAccountDisplayNameJobD2Ev@Base 24.02.2
+ _ZNK9KAccounts13AccountsModel10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts13AccountsModel4dataERK11QModelIndexi@Base 24.02.2
+ _ZNK9KAccounts13AccountsModel8rowCountERK11QModelIndex@Base 24.02.2
+ _ZNK9KAccounts13AccountsModel9roleNamesEv@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel15accountIconNameEv@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel18accountDisplayNameEv@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel19accountProviderNameEv@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel4dataERK11QModelIndexi@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel7accountEv@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel8rowCountERK11QModelIndex@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel9accountIdEv@Base 24.02.2
+ _ZNK9KAccounts13ServicesModel9roleNamesEv@Base 24.02.2
+ _ZNK9KAccounts14ProvidersModel10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts14ProvidersModel4dataERK11QModelIndexi@Base 24.02.2
+ _ZNK9KAccounts14ProvidersModel8rowCountERK11QModelIndex@Base 24.02.2
+ _ZNK9KAccounts14ProvidersModel9roleNamesEv@Base 24.02.2
+ _ZNK9KAccounts16CreateAccountJob10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts16KAccountsDPlugin10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts16RemoveAccountJob10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts16RemoveAccountJob9accountIdEv@Base 24.02.2
+ _ZNK9KAccounts17GetCredentialsJob10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts17GetCredentialsJob15credentialsDataEv@Base 24.02.2
+ _ZNK9KAccounts17GetCredentialsJob9accountIdEv@Base 24.02.2
+ _ZNK9KAccounts17KAccountsUiPlugin10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts17KAccountsUiPlugin15transientParentEv@Base 24.02.2
+ _ZNK9KAccounts23AccountServiceToggleJob10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts23AccountServiceToggleJob14serviceEnabledEv@Base 24.02.2
+ _ZNK9KAccounts23AccountServiceToggleJob9accountIdEv@Base 24.02.2
+ _ZNK9KAccounts23AccountServiceToggleJob9serviceIdEv@Base 24.02.2
+ _ZNK9KAccounts27ChangeAccountDisplayNameJob10metaObjectEv@Base 24.02.2
+ _ZNK9KAccounts27ChangeAccountDisplayNameJob11displayNameEv@Base 24.02.2
+ _ZNK9KAccounts27ChangeAccountDisplayNameJob9accountIdEv@Base 24.02.2
+ (optional=templinst)_ZNKSt8_Rb_treeI7QStringSt4pairIKS0_8QVariantESt10_Select1stIS4_ESt4lessIS0_ESaIS4_EE4findERS2_@Base 24.02.2
+ (optional=templinst)_ZNSt8_Rb_treeI7QStringSt4pairIKS0_8QVariantESt10_Select1stIS4_ESt4lessIS0_ESaIS4_EE16_M_insert_uniqueIS4_EES1_ISt17_Rb_tree_iteratorIS4_EbEOT_@Base 24.02.2
+ (optional=templinst)_ZNSt8_Rb_treeI7QStringSt4pairIKS0_8QVariantESt10_Select1stIS4_ESt4lessIS0_ESaIS4_EE24_M_get_insert_unique_posERS2_@Base 24.02.2
+ (optional=templinst)_ZNSt8_Rb_treeI7QStringSt4pairIKS0_8QVariantESt10_Select1stIS4_ESt4lessIS0_ESaIS4_EE29_M_get_insert_hint_unique_posESt23_Rb_tree_const_iteratorIS4_ERS2_@Base 24.02.2
+ _ZTIN9KAccounts13AccountsModel7PrivateE@Base 24.02.2
+ _ZTIN9KAccounts13AccountsModelE@Base 24.02.2
+ _ZTIN9KAccounts13ServicesModel7PrivateE@Base 24.02.2
+ _ZTIN9KAccounts13ServicesModelE@Base 24.02.2
+ _ZTIN9KAccounts14ProvidersModelE@Base 24.02.2
+ _ZTIN9KAccounts16CreateAccountJobE@Base 24.02.2
+ _ZTIN9KAccounts16KAccountsDPluginE@Base 24.02.2
+ _ZTIN9KAccounts16RemoveAccountJobE@Base 24.02.2
+ _ZTIN9KAccounts17GetCredentialsJobE@Base 24.02.2
+ _ZTIN9KAccounts17KAccountsUiPluginE@Base 24.02.2
+ _ZTIN9KAccounts23AccountServiceToggleJobE@Base 24.02.2
+ _ZTIN9KAccounts27ChangeAccountDisplayNameJobE@Base 24.02.2
+ _ZTSN9KAccounts13AccountsModel7PrivateE@Base 24.02.2
+ _ZTSN9KAccounts13AccountsModelE@Base 24.02.2
+ _ZTSN9KAccounts13ServicesModel7PrivateE@Base 24.02.2
+ _ZTSN9KAccounts13ServicesModelE@Base 24.02.2
+ _ZTSN9KAccounts14ProvidersModelE@Base 24.02.2
+ _ZTSN9KAccounts16CreateAccountJobE@Base 24.02.2
+ _ZTSN9KAccounts16KAccountsDPluginE@Base 24.02.2
+ _ZTSN9KAccounts16RemoveAccountJobE@Base 24.02.2
+ _ZTSN9KAccounts17GetCredentialsJobE@Base 24.02.2
+ _ZTSN9KAccounts17KAccountsUiPluginE@Base 24.02.2
+ _ZTSN9KAccounts23AccountServiceToggleJobE@Base 24.02.2
+ _ZTSN9KAccounts27ChangeAccountDisplayNameJobE@Base 24.02.2
+ _ZTVN9KAccounts13AccountsModel7PrivateE@Base 24.02.2
+ _ZTVN9KAccounts13AccountsModelE@Base 24.02.2
+ _ZTVN9KAccounts13ServicesModel7PrivateE@Base 24.02.2
+ _ZTVN9KAccounts13ServicesModelE@Base 24.02.2
+ _ZTVN9KAccounts14ProvidersModelE@Base 24.02.2
+ _ZTVN9KAccounts16CreateAccountJobE@Base 24.02.2
+ _ZTVN9KAccounts16KAccountsDPluginE@Base 24.02.2
+ _ZTVN9KAccounts16RemoveAccountJobE@Base 24.02.2
+ _ZTVN9KAccounts17GetCredentialsJobE@Base 24.02.2
+ _ZTVN9KAccounts17KAccountsUiPluginE@Base 24.02.2
+ _ZTVN9KAccounts23AccountServiceToggleJobE@Base 24.02.2
+ _ZTVN9KAccounts27ChangeAccountDisplayNameJobE@Base 24.02.2
diff -pruN 4:22.12.3-1/debian/libkaccounts6-dev.install 4:24.02.2-1/debian/libkaccounts6-dev.install
--- 4:22.12.3-1/debian/libkaccounts6-dev.install	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/debian/libkaccounts6-dev.install	2024-05-21 21:20:18.000000000 +0000
@@ -0,0 +1,3 @@
+usr/include/KAccounts6/
+usr/lib/*/cmake/KAccounts6/
+usr/lib/*/libkaccounts6.so
diff -pruN 4:22.12.3-1/debian/qml-module-org-kde-kaccounts.install 4:24.02.2-1/debian/qml-module-org-kde-kaccounts.install
--- 4:22.12.3-1/debian/qml-module-org-kde-kaccounts.install	2022-09-04 12:46:38.000000000 +0000
+++ 4:24.02.2-1/debian/qml-module-org-kde-kaccounts.install	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-usr/lib/*/qt5/qml/org/kde/kaccounts/libkaccountsdeclarativeplugin.so
-usr/lib/*/qt5/qml/org/kde/kaccounts/qmldir
diff -pruN 4:22.12.3-1/debian/qml6-module-org-kde-kaccounts.install 4:24.02.2-1/debian/qml6-module-org-kde-kaccounts.install
--- 4:22.12.3-1/debian/qml6-module-org-kde-kaccounts.install	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/debian/qml6-module-org-kde-kaccounts.install	2024-05-21 20:34:13.000000000 +0000
@@ -0,0 +1,4 @@
+usr/lib/*/qt6/qml/org/kde/kaccounts/kaccountsdeclarativeplugin.qmltypes
+usr/lib/*/qt6/qml/org/kde/kaccounts/kde-qmlmodule.version
+usr/lib/*/qt6/qml/org/kde/kaccounts/libkaccountsdeclarativeplugin.so
+usr/lib/*/qt6/qml/org/kde/kaccounts/qmldir
diff -pruN 4:22.12.3-1/debian/rules 4:24.02.2-1/debian/rules
--- 4:22.12.3-1/debian/rules	2022-09-04 12:46:38.000000000 +0000
+++ 4:24.02.2-1/debian/rules	2024-05-21 21:20:18.000000000 +0000
@@ -6,7 +6,7 @@ libpkgs_gen_strict_local_shlibs = $(libp
 include /usr/share/pkg-kde-tools/qt-kde-team/3/library-packages.mk
 
 %:
-	dh $@ --with kf5,pkgkde_symbolshelper
+	dh $@
 
 override_dh_gencontrol-arch: libpkgs_gen_strict_local_shlibs
 	dh_gencontrol -a
diff -pruN 4:22.12.3-1/po/ar/kaccounts-integration.po 4:24.02.2-1/po/ar/kaccounts-integration.po
--- 4:22.12.3-1/po/ar/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ar/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,13 +1,13 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
 #
-# Safa Alfulaij <safa1996alfulaij@gmail.com>, ٢٠١٥.
+# Safa Alfulaij <safa1996alfulaij@gmail.com>, 2015.
 # Zayed Al-Saidi <zayed.alsaidi@gmail.com>, 2021.
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-07-10 19:37+0400\n"
 "Last-Translator: Zayed Al-Saidi <zayed.alsaidi@gmail.com>\n"
 "Language-Team: ar\n"
@@ -19,24 +19,22 @@ msgstr ""
 "&& n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;\n"
 "X-Generator: Lokalize 21.07.70\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "تفاصيل الحساب"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "حساب %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -44,18 +42,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "غيّر اسم عرض الحساب"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "استخدم هذا الحساب لـ"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "أزل هذا الحساب"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -65,12 +63,12 @@ msgstr ""
 "لا توجد خدمات قابلة للضبط متوفرة لهذا الحساب. لا يزال بإمكانك تغيير اسم "
 "العرض الخاص به عن طريق النقر فوق أيقونة التحرير أعلاه."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "أضف حسابًا جديدًا"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -78,13 +76,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "أزِل %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "لم تضف أي حساب بعد"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgid ""
 msgstr ""
 "انقر على زر<interface>أضف حساب جديد...</interface> في الأسفل لتضيف واحد"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "أضف حسابًا جديدًا..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "أأزيل الحساب؟"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "أمتأكد أنك تريد إزالة حساب \"%1\" \"%2\" ؟"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "أمتأكد أنك تريد إزالة حساب \"%1\"؟"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "أمتأكد أنك تريد إزالة حساب \"%1\"؟"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "أزل الحساب"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "غير اسم الحساب"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "أدخل الاسم الجديد:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "ضع اسم الحساب"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "لم يعثر على حساب بالمعرف %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "لا يوجد مدير حسابات ، هذا ليس رائعًا."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "اسم العرض لا يمكن أن يكون فارغا"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "تعذّر تحميل الملحقة %1، فضلًا تأكّد من تثبيتك"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "ألغيت بواسطة المستخدم"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "حدث خطأ أثناء محاولة معالجة الطلب: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "تعذر العثور على الحساب"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "تعذر العثور على معلومات الاستيثاق"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "تعثذر إنشاء جلسة استيثاق"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "تعذّر فتح المحفظة"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "أزل الحساب"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "ضع اسم الحساب"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "تعذّر فتح المحفظة"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/az/kaccounts-integration.po 4:24.02.2-1/po/az/kaccounts-integration.po
--- 4:22.12.3-1/po/az/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/az/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,40 +1,38 @@
 # Copyright (C) YEAR This file is copyright:
 # This file is distributed under the same license as the kaccounts-integration package.
 #
-# Kheyyam Gojayev <xxmn77@gmail.com>, 2020, 2021.
+# Kheyyam Gojayev <xxmn77@gmail.com>, 2020, 2021, 2023.
 msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
-"PO-Revision-Date: 2021-03-24 12:21+0400\n"
-"Last-Translator: Kheyyam Gojayev <xxmn77@gmail.com>\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
+"PO-Revision-Date: 2023-01-02 23:31+0400\n"
+"Last-Translator: Kheyyam <xxmn77@gmail.com>\n"
 "Language-Team: Azerbaijani <kde-i18n-doc@kde.org>\n"
 "Language: az\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Lokalize 20.12.3\n"
+"X-Generator: Lokalize 22.12.0\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "İstifadəçi Hesabları haqqında"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 hesab"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Hesabın adını dəyişmək"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Bu Hesabı bunun üçün istifadə etmək"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Bu Hesabı silmək"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -63,12 +61,12 @@ msgstr ""
 "Bu Hesab üçün tənzimlənə bilən xidmət yoxdur. Siz hələ də yuxarıdakı nişana "
 "vurmaqla hesabın adını dəyişə bilərsiniz."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
-msgstr "Yeni Hesab əlaə etmək"
+msgstr "Yeni hesab əlavə et"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,13 +74,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 silmək"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Hələlik hesablar əlavə edilməyib"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -91,18 +89,18 @@ msgstr ""
 "Bir hesab əlavə etmək üçün, aşağıda <interface>Yeni hesab əlavə edin...</"
 "interface> düyməsinə vurun"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Yeni Hesab əlavə etmək..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Hesab silinsin?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -110,7 +108,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Siz \"%1\" \"%2\" hesabını silinmək istədiyinizə əminsiniz?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -118,7 +116,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "\"%1\" hesabını silmək istədiyinizə əminsiniz?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -126,14 +124,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Bu \"%1\" hesabını silmək istədiyinizə əminsiniz?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Hesabı Silmək"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -141,7 +132,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Hesabın adını dəyişmək"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -149,64 +140,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Yeni ad daxil edin:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Hesabın adını təyin edin"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "%1 İD-si ilə hesab tapılmadı"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Hesab Meneceri yoxdur, bu yaxşı deyil."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Hesab adı boş ola bilməz"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "%1 qoşması yüklənə bilmədi, lütfən quraşdırmanı yoxlayın"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "İstifadəçi tərəfindən ləğv edildi"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Bu sorğunun işlənməsi zamanı xəta baş verdi: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Hesab tapıla bilmədi"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Hesab məlumatlarını"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Doğrulama sessiyası yaradıla bilmədi"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Cüzdan açıla bilmir"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Hesabı Silmək"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Hesabın adını təyin edin"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Cüzdan açıla bilmir"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/bg/kaccounts-integration.po 4:24.02.2-1/po/bg/kaccounts-integration.po
--- 4:22.12.3-1/po/bg/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/bg/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2022-07-21 19:53+0200\n"
 "Last-Translator: Mincho Kondarev <mkondarev@yahoo.de>\n"
 "Language-Team: Bulgarian <kde-i18n-doc@kde.org>\n"
@@ -18,24 +18,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Poedit 3.0.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Данни на профила"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr " %1 ( %2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 акаунт"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Промяна на показваното име на акаунт"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Използване на акаунта за"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Премахване на акаунта"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -65,12 +63,12 @@ msgstr ""
 "промените показваното му име, като кликнете върху иконата за редактиране по-"
 "горе."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Добавяне на нов акаунт"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -78,13 +76,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Премахване на %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Все още няма добавени акаунти"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -93,18 +91,18 @@ msgstr ""
 "Кликнете върху бутона <interface> Добавяне на нов акаунт ... </interface> по-"
 "долу, за добавяне"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Добавяне на нов акаунт..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Премахване на акаунт?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -112,7 +110,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Наистина ли искате да премахнете \"%1\" акаунта \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -120,7 +118,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Наистина ли искате да премахнете акаунта \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -128,14 +126,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Наистина ли искате да премахнете този \"%1\"акаунт?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Премахване на акаунт"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -143,7 +134,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Преименуване на акаунт"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -151,61 +142,59 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Въведете ново име:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Задаване на име на акаунт"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Не е намерен акаунт с идентификатор %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Няма мениджър на акаунти, това не е добре."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Показваното име не може да бъде празно"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Неуспешно зареждане на %1 приставка, моля, проверете вашата инсталация"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Oтмененo от потребителя"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "При опит за обработка на заявката възникна грешка: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Неуспешно намиране на акаунт"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Неуспешно намиране на идентификационни данни"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Неуспешно създаване на сесия за удостоверяване"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Неуспешно отваряне на портфейл"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Премахване на акаунт"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Задаване на име на акаунт"
diff -pruN 4:22.12.3-1/po/bs/kaccounts-integration.po 4:24.02.2-1/po/bs/kaccounts-integration.po
--- 4:22.12.3-1/po/bs/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/bs/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kde5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2015-02-19 10:14+0100\n"
 "Last-Translator: Samir ribic <megaribi@localhost>\n"
 "Language-Team: Bosnian\n"
@@ -19,24 +19,22 @@ msgstr ""
 "Plural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n"
 "%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -44,18 +42,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -63,12 +61,12 @@ msgid ""
 "change its display name by clicking the edit icon above."
 msgstr ""
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,31 +74,31 @@ msgctxt ""
 msgid "Remove %1"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
 "Click the <interface>Add New Account...</interface> button below to add one"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr ""
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -108,7 +106,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -116,7 +114,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -124,14 +122,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr ""
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -139,7 +130,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -147,61 +138,48 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr ""
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
-
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr ""
diff -pruN 4:22.12.3-1/po/ca/kaccounts-integration.po 4:24.02.2-1/po/ca/kaccounts-integration.po
--- 4:22.12.3-1/po/ca/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ca/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-10-29 17:53+0200\n"
 "Last-Translator: Josep M. Ferrer <txemaq@gmail.com>\n"
 "Language-Team: Catalan <kde-i18n-ca@kde.org>\n"
@@ -21,24 +21,22 @@ msgstr ""
 "X-Accelerator-Marker: &\n"
 "X-Generator: Lokalize 20.12.0\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detalls del compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Compte de %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -46,18 +44,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Canvia el nom a mostrar del compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Usa aquest compte per a"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Elimina aquest compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -67,12 +65,12 @@ msgstr ""
 "No hi ha cap servei configurable per a aquest compte. Encara podreu canviar "
 "el seu nom a mostrar fent clic a la icona d'edició de dalt."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Afegeix un compte nou"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -80,13 +78,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Elimina %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Encara no s'ha afegit cap compte"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -95,18 +93,18 @@ msgstr ""
 "Feu clic al botó <interface>Afegeix un compte nou...</interface> que hi ha a "
 "sota per a afegir-ne un"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Afegeix un compte nou..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Elimino el compte?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -114,7 +112,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Esteu segur que voleu eliminar el compte «%2» de «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -122,7 +120,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Esteu segur que voleu eliminar el compte «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -130,14 +128,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Esteu segur que voleu eliminar aquest compte de «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Elimina el compte"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -145,7 +136,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Reanomena el compte"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -153,62 +144,60 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Introduïu el nom nou:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Indiqueu el nom del compte"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "No s'ha trobat cap compte amb la ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "No hi ha cap gestor de comptes, això no és impressionant."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "El nom de la pantalla no pot estar buit"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr ""
 "No s'ha pogut carregar el connector %1. Si us plau, comproveu la instal·lació"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Cancel·lada per l'usuari"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "S'ha produït un error en provar de processar la sol·licitud: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "No s'ha pogut trobar el compte"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "No s'han pogut trobar les credencials"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "No s'ha pogut crear la sessió d'autorització"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "No s'ha pogut obrir la cartera"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Elimina el compte"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Indiqueu el nom del compte"
diff -pruN 4:22.12.3-1/po/ca@valencia/kaccounts-integration.po 4:24.02.2-1/po/ca@valencia/kaccounts-integration.po
--- 4:22.12.3-1/po/ca@valencia/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ca@valencia/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-10-29 17:53+0200\n"
 "Last-Translator: Josep M. Ferrer <txemaq@gmail.com>\n"
 "Language-Team: Catalan <kde-i18n-ca@kde.org>\n"
@@ -21,24 +21,22 @@ msgstr ""
 "X-Accelerator-Marker: &\n"
 "X-Generator: Lokalize 20.12.0\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detalls del compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Compte de %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -46,18 +44,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Canvia el nom que s'ha de mostrar del compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Utilitza este compte per a"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Elimina este compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -67,12 +65,12 @@ msgstr ""
 "No hi ha cap servei configurable per a este compte. Encara podreu canviar el "
 "nom que es mostrarà fent clic damunt de la icona d'edició de dalt."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Afig un compte nou"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -80,13 +78,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Elimina %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Encara no s'ha afegit cap compte"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -95,18 +93,18 @@ msgstr ""
 "Feu clic en el botó <interface>Afig un compte nou...</interface> que hi ha "
 "davall per a afegir-ne un"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Afig un compte nou..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Voleu eliminar el compte?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -114,7 +112,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Segur que voleu eliminar el compte «%2» de «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -122,7 +120,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Segur que voleu eliminar el compte «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -130,14 +128,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Segur que voleu eliminar este compte de «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Elimina el compte"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -145,7 +136,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Canvia el nom del compte"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -153,61 +144,59 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Introduïu el nom nou:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Indiqueu el nom del compte"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "No s'ha trobat cap compte amb la ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "No hi ha cap gestor de comptes, açò no és impressionant."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "El nom de la pantalla no pot estar buit"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "No s'ha pogut carregar el connector %1. Comproveu la instal·lació"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Cancel·lada per l'usuari"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "S'ha produït un error en provar de processar la sol·licitud: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "No s'ha pogut trobar el compte"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "No s'han pogut trobar les credencials"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "No s'ha pogut crear la sessió d'autorització"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "No s'ha pogut obrir la cartera"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Elimina el compte"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Indiqueu el nom del compte"
diff -pruN 4:22.12.3-1/po/cs/kaccounts-integration.po 4:24.02.2-1/po/cs/kaccounts-integration.po
--- 4:22.12.3-1/po/cs/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/cs/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,13 +1,13 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
 # Vít Pelčák <vit@pelcak.org>, 2014, 2015, 2017.
-# Vit Pelcak <vit@pelcak.org>, 2017, 2019, 2020, 2021, 2023.
+# SPDX-FileCopyrightText: 2017, 2019, 2020, 2021, 2023, 2024 Vit Pelcak <vit@pelcak.org>
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2023-01-04 10:29+0100\n"
 "Last-Translator: Vit Pelcak <vit@pelcak.org>\n"
 "Language-Team: Czech <kde-i18n-doc@kde.org>\n"
@@ -16,26 +16,24 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\n"
-"X-Generator: Lokalize 22.12.0\n"
+"X-Generator: Lokalize 23.08.4\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Podrobnosti o účtu"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 účet"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Změnit zobrazovaný název účtu"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Použít tento účet pro"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Odstranit tento účet"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -62,12 +60,12 @@ msgid ""
 "change its display name by clicking the edit icon above."
 msgstr ""
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Přidat nový účet"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -75,13 +73,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Odstranit %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Žádné účty zatím nebyly přidány"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -90,18 +88,18 @@ msgstr ""
 "Pro přidání klikněte na tlačítko <interface>Přidat nový účet...</interface> "
 "níže"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Přidat nový účet..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Odstranit účet"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -109,7 +107,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Opravdu si přejete odstranit  \"%1\"  účet \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -117,7 +115,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Opravdu si přejete odstranit účet \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -125,14 +123,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Určitě chcete odstranit tento \"%1\" účet?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Odstranit účet"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -140,7 +131,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Přejmenovat účet"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -148,61 +139,59 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Zadejte nový název:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Nastavit název účtu"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Název obrazovky nesmí být prázdný"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Nelze načíst zásuvný modul %1. Prosím, zkontrolujte svou instalaci"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Zrušeno uživatelem"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Nastala chyba při pokusu o zpracování žádosti: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Nelze najít účet"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Nelze najít přihlašovací údaje"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Úschovnu nelze otevřít"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Odstranit účet"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Nastavit název účtu"
diff -pruN 4:22.12.3-1/po/da/kaccounts-integration.po 4:24.02.2-1/po/da/kaccounts-integration.po
--- 4:22.12.3-1/po/da/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/da/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-09-09 21:51+0200\n"
 "Last-Translator: Martin Schlander <mschlander@opensuse.org>\n"
 "Language-Team: Danish <kde-i18n-doc@kde.org>\n"
@@ -17,24 +17,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.04.2\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Kontodetaljer"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1-konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Skift kontoens viste navn"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Brug denne konto til"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Fjern denne konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -63,12 +61,12 @@ msgstr ""
 "Der er ingen konfigurerbare tjenester tilgængelige for denne konto. Du kan "
 "stadig ændre dens viste navn ved at klikke på redigér-ikonet ovenfor."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Tilføj ny konto"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,13 +74,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Fjern %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Ingen konti tilføjet endnu"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -91,18 +89,18 @@ msgstr ""
 "Klik på knappen <interface>Tilføj ny konto...</interface> nedenfor for at "
 "tilføje en"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Tilføj ny konto..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Fjern konto?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -110,7 +108,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Vil du fjerne \"%1\"-kontoen \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -118,7 +116,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Vil du fjerne kontoen \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -126,14 +124,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Vil du fjerne denne \"%1\"-konto?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Fjern konto"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -141,7 +132,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Omdøb konto"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -149,64 +140,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Angiv nyt navn:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Angiv kontonavn"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Ingen konto fundet med id %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Ingen håndtering af konti, dette er ikke optimalt."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Det viste navn må ikke være tomt"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Kunne ikke indlæse %1-plugin. Tjek din installation"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Annulleret af brugeren"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Der opstod en fejl under forsøg på at behandle anmodningen: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Kunne ikke finde konto"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Kunne ikke finde akkreditiver"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Kunne ikke oprette auth-session"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Kan ikke åbne tegnebog"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Fjern konto"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Angiv kontonavn"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Kan ikke åbne tegnebog"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/de/kaccounts-integration.po 4:24.02.2-1/po/de/kaccounts-integration.po
--- 4:22.12.3-1/po/de/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/de/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,10 +1,11 @@
+# SPDX-FileCopyrightText: 2024 Johannes Obermayr <johannesobermayr@gmx.de>
 # Burkhard Lück <lueck@hube-lueck.de>, 2014, 2015, 2017, 2019, 2020, 2021.
 # Frederik Schwarzer <schwarzer@kde.org>, 2016.
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-04-24 10:35+0200\n"
 "Last-Translator: Burkhard Lück <lueck@hube-lueck.de>\n"
 "Language-Team: German <kde-i18n-de@kde.org>\n"
@@ -12,26 +13,25 @@ msgstr ""
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=2; plural=n != 1;\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Lokalize 24.02.0\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Zugangsdetails"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Zugang %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -39,18 +39,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Anzeigenamen des Zugangs ändern"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Diesen Zugang verwenden für"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Diesen Zugang entfernen"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -60,12 +60,12 @@ msgstr ""
 "Es gibt keine einstellbaren Dienste für diesen Zugang, sie können jedoch den "
 "angezeigten Namen ändern, indem Sie auf das Bearbeitungssymbol oben klicken."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Neuen Zugang hinzufügen"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -73,13 +73,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 entfernen"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Es wurden noch keine Zugänge hinzugefügt."
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -88,18 +88,18 @@ msgstr ""
 "Klicken Sie auf <interface>Neuen Zugang hinzufügen ...</interface> unten, um "
 "einen neuen Zugang hinzuzufügen"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Neuen Zugang hinzufügen ..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Zugang entfernen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -107,7 +107,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Möchten Sie den Zugang „%1“ für „%2“ wirklich entfernen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -115,7 +115,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Möchten Sie den Zugang „%1“ wirklich entfernen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -123,14 +123,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Möchten Sie diesen Zugang „%1“ wirklich entfernen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Zugang entfernen"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -138,7 +131,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Zugang umbenennen"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -146,30 +139,22 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Neuen Namen eingeben:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Zugangsname festlegen"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Kein Zugang mit der Kennung „%1“ gefunden"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Es wurde keine Zugangsverwaltung gefunden."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Der Anzeigename darf nicht leer sein"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
@@ -177,35 +162,44 @@ msgstr ""
 "Das Modul %1 kann nicht geladen werden, bitte überprüfen Sie Ihre "
 "Installation"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Vom Benutzer abgebrochen"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Beim Bearbeiten der Anfrage ist ein Fehler aufgetreten: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Zugang wurde nicht gefunden"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Anmeldungsdaten wurden nicht gefunden"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Autorisierungssitzung kann nicht erstellt werden"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Der Passwortspeicher kann nicht geöffnet werden"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Zugang entfernen"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Zugangsname festlegen"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Der Passwortspeicher kann nicht geöffnet werden"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/el/kaccounts-integration.po 4:24.02.2-1/po/el/kaccounts-integration.po
--- 4:22.12.3-1/po/el/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/el/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-06-04 21:52+0300\n"
 "Last-Translator: Stelios <sstavra@gmail.com>\n"
 "Language-Team: Greek <kde-i18n-el@kde.org>\n"
@@ -17,24 +17,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.04.2\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Λεπτομέρειες λογαριασμού"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 λογαριασμός"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Αλλαγή ονόματος λογαριασμού στην οθόνη"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Χρήση αυτού του λογαριασμού για"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Αφαίρεση αυτού του λογαριασμού"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "Μπορείτε όμως να αλλάξετε το όνομα με το οποίο παρουσιάζεται στην οθόνη με "
 "κλικ στο παραπάνω εικονίδιο επεξεργασίας."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Προσθήκη νέου λογαριασμού"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Αφαίρεση %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Δεν προστέθηκαν λογαριασμοί ακόμη"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Κάνετε κλικ στο παρακάτω κουμπί <interface>Προσθήκη νέου λογαριασμού...</"
 "interface> για να προσθέσετε έναν"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Προσθήκη νέου λογαριασμού..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Αφαίρεση λογαριασμού;"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Είστε βέβαιοι ότι θέλετε να αφαιρέσετε τον «%1» λογαριασμό «%2»;"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Είστε βέβαιοι ότι θέλετε να αφαιρέσετε το λογαριασμό «%1';"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Είστε βέβαιοι ότι θέλετε να αφαιρέσετε αυτόν τον «%1» λογαριασμό '%1';"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Αφαίρεση λογαριασμού"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Μετονομασία λογαριασμού"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Δώστε νέο όνομα:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Ρύθμιση ονόματος λογαριασμού"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Δε βρέθηκε λογαριασμός με αυτό το αναγνωριστικό %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Κανένας διαχειριστής λογαριασμών, αυτό δεν είναι καλό."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Το όνομα στην οθόνη δεν μπορεί να είναι κενό"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Αδυναμία φόρτωσης του πρόσθετου %1, ελέγξτε την εγκατάστασή σας"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Ακυρώθηκε από τον χρήστη"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Υπήρξε σφάλμα κατά την επεξεργασία του αιτήματος: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Αδυναμία εύρεσης λογαριασμού"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Αδυναμία εύρεσης διαπιστευτηρίων"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Αδυναμία δημιουργίας συνεδρίας ταυτοποίησης"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Αδυναμία ανοίγματος πορτοφολιού"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Αφαίρεση λογαριασμού"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Ρύθμιση ονόματος λογαριασμού"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Αδυναμία ανοίγματος πορτοφολιού"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/en_GB/kaccounts-integration.po 4:24.02.2-1/po/en_GB/kaccounts-integration.po
--- 4:22.12.3-1/po/en_GB/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/en_GB/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-04-03 15:07+0100\n"
 "Last-Translator: Steve Allewell <steve.allewell@gmail.com>\n"
 "Language-Team: British English <kde-l10n-en_gb@kde.org>\n"
@@ -17,24 +17,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.12.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Account Details"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 account"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Change Account Display Name"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Use This Account For"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Remove This Account"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -63,12 +61,12 @@ msgstr ""
 "There are no configurable services available for this account. You can still "
 "change its display name by clicking the edit icon above."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Add New Account"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,13 +74,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Remove %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "No accounts added yet"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -90,18 +88,18 @@ msgid ""
 msgstr ""
 "Click the <interface>Add New Account...</interface> button below to add one"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Add New Account..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Remove Account?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -109,7 +107,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -117,7 +115,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Are you sure you wish to remove the account \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -125,14 +123,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Are you sure you wish to remove this \"%1\" account?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Remove Account"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -140,7 +131,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Rename Account"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -148,64 +139,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Enter new name:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Set Account Name"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "No account found with the ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "No accounts manager, this is not awesome."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "The display name cannot be empty"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Could not load %1 plugin, please check your installation"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Cancelled by user"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "There was an error while trying to process the request: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Could not find account"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Could not find credentials"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Could not create auth session"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Cannot open wallet"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Remove Account"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Set Account Name"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Cannot open wallet"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/eo/kaccounts-integration.po 4:24.02.2-1/po/eo/kaccounts-integration.po
--- 4:22.12.3-1/po/eo/kaccounts-integration.po	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/po/eo/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -0,0 +1,198 @@
+# translation of kaccounts-integration.pot to esperanto
+# Copyright (C) 2022 Free Software Foundation, Inc.
+# This file is distributed under the same license as the kaccounts-integration package.
+# Oliver Kellogg <okellogg@users.sourceforge.net, 2023.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: kaccounts-integration\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
+"PO-Revision-Date: 2023-12-04 15:25+0100\n"
+"Last-Translator: Oliver Kellogg <okellogg@users.sourceforge.net>\n"
+"Language-Team: Esperanto <kde-i18n-eo@kde.org>\n"
+"Language: eo\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=n != 1;\n"
+
+#: src/kcm/ui/AccountDetails.qml:20
+#, kde-format
+msgid "Account Details"
+msgstr "Kontaj Detaloj"
+
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
+#, kde-format
+msgid "%1 (%2)"
+msgstr "%1 (%2)"
+
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
+#, kde-format
+msgid "%1 account"
+msgstr "%1 konto"
+
+#: src/kcm/ui/AccountDetails.qml:73
+#, kde-format
+msgctxt ""
+"Button which spawns a dialog allowing the user to change the displayed "
+"account's human-readable name"
+msgid "Change Account Display Name"
+msgstr "Ŝanĝi Montritan Kontonomon"
+
+#: src/kcm/ui/AccountDetails.qml:81
+#, kde-format
+msgctxt "Heading for a list of services available with this account"
+msgid "Use This Account For"
+msgstr "Uzi Ĉi tiun Konton Por"
+
+#: src/kcm/ui/AccountDetails.qml:88
+#, kde-format
+msgid "Remove This Account"
+msgstr "Forigi Ĉi tiun Konton"
+
+#: src/kcm/ui/AccountDetails.qml:110
+#, kde-format
+msgctxt "A text shown when an account has no configurable services"
+msgid ""
+"There are no configurable services available for this account. You can still "
+"change its display name by clicking the edit icon above."
+msgstr ""
+"Ne estas agordeblaj servoj disponeblaj por ĉi tiu konto. Vi ankoraŭ povas "
+"ŝanĝi ĝian montran nomon alklakante la redaktan piktogramon supre."
+
+#: src/kcm/ui/AvailableAccounts.qml:19
+#, kde-format
+msgid "Add New Account"
+msgstr "Aldoni Novan Konton"
+
+#: src/kcm/ui/main.qml:53
+#, kde-format
+msgctxt ""
+"Tooltip for an action which will offer the user to remove the mentioned "
+"account"
+msgid "Remove %1"
+msgstr "Forigi %1"
+
+#: src/kcm/ui/main.qml:70
+#, kde-format
+msgctxt "A text shown when a user has not yet added any accounts"
+msgid "No accounts added yet"
+msgstr "Ankoraŭ neniuj kontoj aldonitaj"
+
+#: src/kcm/ui/main.qml:71
+#, kde-kuit-format
+msgctxt "@info"
+msgid ""
+"Click the <interface>Add New Account...</interface> button below to add one"
+msgstr ""
+"Alklaku la suban butonon <interface>Aldoni novan konton...</interface> por "
+"aldoni unu"
+
+#: src/kcm/ui/main.qml:83
+#, kde-format
+msgid "Add New Account..."
+msgstr "Aldoni novan konton..."
+
+#: src/kcm/ui/RemoveAccountDialog.qml:22
+#, kde-format
+msgctxt "The title for a dialog which lets you remove an account"
+msgid "Remove Account?"
+msgstr "Ĉu Forigi Konton?"
+
+#: src/kcm/ui/RemoveAccountDialog.qml:40
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when both provider "
+"name and account name are available"
+msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
+msgstr "Ĉu vi certas, ke vi volas forigi la konton \"%1\" \"%2\"?"
+
+#: src/kcm/ui/RemoveAccountDialog.qml:42
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the account "
+"name is available"
+msgid "Are you sure you wish to remove the account \"%1\"?"
+msgstr "Ĉu vi certas, ke vi volas forigi la konton \"%1\"?"
+
+#: src/kcm/ui/RemoveAccountDialog.qml:44
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the "
+"provider name is available"
+msgid "Are you sure you wish to remove this \"%1\" account?"
+msgstr "Ĉu vi certas, ke vi volas forigi ĉi tiun \"%1\" konton?"
+
+#: src/kcm/ui/RenameAccountDialog.qml:17
+#, kde-format
+msgctxt ""
+"The title for a dialog which lets you set the human-readable name of an "
+"account"
+msgid "Rename Account"
+msgstr "Alinomi konton"
+
+#: src/kcm/ui/RenameAccountDialog.qml:38
+#, kde-format
+msgctxt ""
+"Label for the text field used to enter a new human-readable name for an "
+"account"
+msgid "Enter new name:"
+msgstr "Enigu novan nomon:"
+
+#: src/lib/changeaccountdisplaynamejob.cpp:74
+#, kde-format
+msgid "No account found with the ID %1"
+msgstr "Neniu konto trovita kun la ID %1"
+
+#: src/lib/changeaccountdisplaynamejob.cpp:79
+#, kde-format
+msgid "No accounts manager, this is not awesome."
+msgstr "Neniu konta administranto, ĉi tio ne estas admirinda."
+
+#: src/lib/changeaccountdisplaynamejob.cpp:84
+#, kde-format
+msgid "The display name cannot be empty"
+msgstr "La montra nomo ne povas esti malplena"
+
+#: src/lib/createaccountjob.cpp:92
+#, kde-format
+msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
+msgid "Could not load %1 plugin, please check your installation"
+msgstr "Ne eblis ŝargi %1 kromprogramon, bonvolu kontroli vian instalon"
+
+#: src/lib/createaccountjob.cpp:187
+#, kde-format
+msgid "Cancelled by user"
+msgstr "Nuligita de uzanto"
+
+#: src/lib/createaccountjob.cpp:264
+#, kde-format
+msgid "There was an error while trying to process the request: %1"
+msgstr "Okazis eraro dum provado prilabori la peton: %1"
+
+#: src/lib/getcredentialsjob.cpp:56
+#, kde-format
+msgid "Could not find account"
+msgstr "Ne eblis trovi konton"
+
+#: src/lib/getcredentialsjob.cpp:71
+#, kde-format
+msgid "Could not find credentials"
+msgstr "Ne eblis trovi akreditaĵojn"
+
+#: src/lib/getcredentialsjob.cpp:81
+#, kde-format
+msgid "Could not create auth session"
+msgstr "Ne eblis krei aŭtentikigseancon"
+
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Forigi Konton"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Agordi Kontan Nomon"
diff -pruN 4:22.12.3-1/po/es/kaccounts-integration.po 4:24.02.2-1/po/es/kaccounts-integration.po
--- 4:22.12.3-1/po/es/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/es/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-03-24 14:52+0100\n"
 "Last-Translator: Eloy Cuadra <ecuadra@eloihr.net>\n"
 "Language-Team: Spanish <kde-l10n-es@kde.org>\n"
@@ -20,24 +20,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.12.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detalles de la cuenta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Cuenta de %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -45,18 +43,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Cambiar el nombre de la cuenta a mostrar"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Usar esta cuenta para"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Eliminar esta cuenta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -66,12 +64,12 @@ msgstr ""
 "No existen servicios que se puedan configurar para esta cuenta. Puede "
 "cambiar el nombre a mostrar pulsando el icono de edición superior."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Añadir nueva cuenta"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -79,13 +77,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Eliminar %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "No se han añadido cuentas"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -94,18 +92,18 @@ msgstr ""
 "Pulse el botón <interface>Añadir nueva cuenta...</interface> inferior para "
 "añadir una"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Añadir nueva cuenta..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "¿Eliminar cuenta?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -113,7 +111,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "¿Seguro que quiere eliminar la cuenta de «%1» «%2»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -121,7 +119,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "¿Seguro que quiere eliminar la cuenta «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -129,14 +127,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "¿Seguro que quiere eliminar la cuenta de «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Eliminar cuenta"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -144,7 +135,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Cambiar nombre de la cuenta"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -152,30 +143,22 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Introduzca el nuevo nombre:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Definir nombre de la cuenta"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "No se ha encontrado ninguna cuenta con el ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "No existe ningún gestor de cuentas. Esto no es bueno."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "El nombre de a mostrar no puede estar vacío"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
@@ -183,35 +166,44 @@ msgstr ""
 "No se ha podido cargar el complemento %1. Por favor, compruebe su "
 "instalación."
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Cancelado por el usuario"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Ocurrió un error al intentar procesar la petición: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "No se ha podido encontrar la cuenta"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "No se han podido encontrar las credenciales"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "No se ha podido crear la sesión de autenticación"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "No se puede abrir la cartera"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Eliminar cuenta"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Definir nombre de la cuenta"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "No se puede abrir la cartera"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/et/kaccounts-integration.po 4:24.02.2-1/po/et/kaccounts-integration.po
--- 4:22.12.3-1/po/et/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/et/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2020-10-07 10:58+0200\n"
 "Last-Translator: Mihkel Tõnnov <mihhkel@gmail.com>\n"
 "Language-Team: Estonian <>\n"
@@ -18,24 +18,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.08.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Konto üksikasjad"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Muuda konto kuvatavat nime"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Konto kasutuskohad"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Eemalda see konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "Selle konto jaoks pole ühtegi seadistatavat teenust saadaval. Ülal paikneva "
 "muutmisikooni abil saad siiski muuta konto kuvatavat nime."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Uue konto lisamine"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,31 +75,31 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Eemalda %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Ühtegi kontot pole veel lisatud."
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
 "Click the <interface>Add New Account...</interface> button below to add one"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Lisa uus konto ..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Konto eemaldamine"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -109,7 +107,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Kas tõesti eemaldada \"%1\" konto \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -117,7 +115,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Kas tõesti eemaldada konto \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -125,14 +123,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Kas tõesti eemaldada see \"%1\" konto?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Eemalda konto"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -140,7 +131,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Konto kuvatava nime muutmine"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -148,64 +139,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Sisesta konto uus nimi:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Määra konto nimi"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Ühtegi kontot ID-ga %1 ei leitud"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Ühtegi kontohaldurit pole, see on nüüd küll vapustav."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Näidatav nimi ei tohi olla andmata"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "%1 plugina laadimine nurjus, palun kontrolli paigaldust"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Päringu töötlemisel tekkis tõrge: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Kontot ei leitud"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Kasutajatunnuseid ei leitud"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Autentimisseansi loomine nurjus"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Turvalaeka avamine nurjus"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Eemalda konto"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Määra konto nimi"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Turvalaeka avamine nurjus"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/eu/kaccounts-integration.po 4:24.02.2-1/po/eu/kaccounts-integration.po
--- 4:22.12.3-1/po/eu/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/eu/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-05-06 22:24+0200\n"
 "Last-Translator: Iñigo Salvador Azurmendi <xalba@ni.eus>\n"
 "Language-Team: Basque <kde-i18n-eu@kde.org>\n"
@@ -21,24 +21,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 "X-Generator: Lokalize 21.04.0\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Kontuaren xehetasunak"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 kontua"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -46,18 +44,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Aldatu kontuan azalduko den izena"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Erabili kontu hau"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Kendu kontu hau"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -67,12 +65,12 @@ msgstr ""
 "Ez dago kontu honetarako konfigura daitekeen zerbitzurik. Azaltzen duen "
 "izena alda dezakezu goiko editatzeko botoiari klik eginez."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Gehitu kontu berria"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -80,13 +78,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Kendu %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Ez da oraindik konturik gehitu"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -95,18 +93,18 @@ msgstr ""
 "Egin klik azpiko <interface>Gehitu kontu berria...</interface> butoian bat "
 "gehitzeko"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Gehitu kontu berria..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Kontua kendu?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -114,7 +112,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Ziur zaude «%1» «%2» kontua kendu nahi duzula?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -122,7 +120,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Ziur zaude «%1» kontua kendu nahi duzula?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -130,14 +128,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Ziur zaude «%1» kontua hau nahi duzula?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Kendu kontua"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -145,7 +136,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Berrizendatu kontua"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -153,64 +144,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Sartu izen berria:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Ezarri kontuaren izena"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Ez da aurkitu ID %1  duen konturik"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Ez dago kontu kudeatzailerik, ez da ona."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Azaldu beharreko izena ezin da hutsik egon"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Ezin izan da %1 plugina zamatu, ikuskatu zure instalazioa"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Erabiltzaileak bertan behera utzi du"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Errore bat gertatu da eskaera prozesatzen saiatzean: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Ezin izan da kontua aurkitu"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Ezin izan da egiaztagiririk aurkitu"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Ezin izan da sortu autentifikatutako saiorik"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Ezin da zorroa ireki"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Kendu kontua"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Ezarri kontuaren izena"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Ezin da zorroa ireki"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/fi/kaccounts-integration.po 4:24.02.2-1/po/fi/kaccounts-integration.po
--- 4:22.12.3-1/po/fi/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/fi/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2022-07-29 22:29+0300\n"
 "Last-Translator: Tommi Nieminen <translator@legisign.org>\n"
 "Language-Team: Finnish <kde-i18n-doc@kde.org>\n"
@@ -18,25 +18,23 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 "X-Generator: Lokalize 20.12.0\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Tilin tiedot"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
 # *** TARKISTA: Toimii, jos %1 on yksi sana, mutta ei, jos se on sanaliitto (”Google Drive”)
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1-tili"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -44,18 +42,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Muuta tilin näyttönimeä"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Käytä tätä tiliä palveluille"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Poista tämä tili"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -65,12 +63,12 @@ msgstr ""
 "Tälle tilille ei ole asetettavia palveluja. Sen näyttönimeä voi silti "
 "muuttaa napsauttamalla yllä olevaa muokkauskuvaketta."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Lisää uusi tili"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -78,13 +76,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Poista %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Tilejä ei ole asetettu"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -93,19 +91,19 @@ msgstr ""
 "Lisää tili napsauttamalla alta painiketta <interface>Lisää uusi tili…</"
 "interface>"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Lisää uusi tili…"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Poistetaanko tili?"
 
 # %1 suluissa, jotta vältetään puuttuvan sanavälin ongelma, jos se on sanaliitto (esim. ”Google Drive”)
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -113,7 +111,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Haluatko varmasti poistaa tilin ”%2” (%1)?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -121,7 +119,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Haluatko varmasti poistaa tilin ”%1”?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -129,14 +127,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Haluatko varmasti poistaa tilin ”%1”?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Poista tili"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -144,7 +135,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Muuta tilin nimeä"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -152,64 +143,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Anna uusi nimi:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Aseta tilin nimi"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Tunnistetta %1 vastaavaa tiliä ei löytynyt."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Ei tilien hallintaa: tämä ei ole hyvä."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Näyttönimi ei voi olla tyhjä"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Ei voitu ladata liitännäistä %1. Tarkista asennus."
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Käyttäjä perui"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Pyyntösi käsittelyssä tapahtui virhe: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Tiliä ei löytynyt"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Todennustietoja ei löytynyt"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Todennusistuntoa ei voitu luoda"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Lompakkoa ei voi avata"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Poista tili"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Aseta tilin nimi"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Lompakkoa ei voi avata"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/fr/kaccounts-integration.po 4:24.02.2-1/po/fr/kaccounts-integration.po
--- 4:22.12.3-1/po/fr/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/fr/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -3,14 +3,14 @@
 # Maxence Le Doré <maxence.ledore@gmail.com>, 2014, 2015.
 # Vincent Pinon <vpinon@kde.org>, 2017.
 # Simon Depiets <sdepiets@gmail.com>, 2018, 2019, 2020.
-# Xavier Besnard <xavier.besnard@neuf.fr>, 2020, 2021.
+# SPDX-FileCopyrightText: 2020, 2021, 2024 Xavier Besnard <xavier.besnard@kde.org>
+# Xavier Besnard <xavier.besnard@kde.org>, 2023.
 #
-# Xavier BESNARD <xavier.besnard]neuf.fr>, 2023.
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2023-01-05 12:15+0100\n"
 "Last-Translator: Xavier BESNARD <xavier.besnard]neuf.fr>\n"
 "Language-Team: fr\n"
@@ -19,29 +19,27 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n > 1);\n"
-"X-Generator: Lokalize 22.12.0\n"
+"X-Generator: Lokalize 23.08.4\n"
 "X-Environment: kde\n"
 "X-Accelerator-Marker: &\n"
 "X-Text-Markup: kde4\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Détails du compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -49,18 +47,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Changer le nom d'affichage du compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Utiliser ce compte pour"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Supprimer ce compte"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -71,12 +69,12 @@ msgstr ""
 "toujours modifier son nom d'affichage en cliquant sur l'icône de "
 "modification ci-dessus."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Ajouter un nouveau compte"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -84,13 +82,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Supprimer %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Aucun compte encore ajouté"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -99,18 +97,18 @@ msgstr ""
 "Cliquez sur le bouton ci-dessous <interface>Ajouter un nouveau</interface> "
 "pour en ajouter un."
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Ajouter un nouveau compte..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Supprimer le compte ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -118,7 +116,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Voulez-vous vraiment effacer le compte « %1 » « %2 » ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -126,7 +124,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Voulez-vous vraiment supprimer le compte « %1 » ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -134,14 +132,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Voulez-vous vraiment supprimer le compte « %1 » ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Supprimer le compte"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -149,7 +140,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Renommer le compte"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -157,65 +148,66 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Saisissez votre nouveau nom :"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Définir le nom du compte"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Aucun compte trouvé pour l'identifiant %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Aucun gestionnaire de comptes. Ceci est incroyable."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Le nom de l'affichage ne peut être vide"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr ""
 "Impossible de charger le module %1, veuillez vérifier votre installation"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Annulé par l'utilisateur"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Il y a une eu une erreur durant le traitement de la requête : %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Impossible de trouver de compte"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Impossible de trouver des identifiants"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Impossible de créer une session d'authentification"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Impossible d'ouvrir le portefeuille"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Supprimer le compte"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Définir le nom du compte"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Impossible d'ouvrir le portefeuille"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/gl/kaccounts-integration.po 4:24.02.2-1/po/gl/kaccounts-integration.po
--- 4:22.12.3-1/po/gl/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/gl/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,228 +1,202 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
 # Adrián Chaves Fernández <adriyetichaves@gmail.com>, 2015, 2016, 2017.
-# Adrián Chaves (Gallaecio) <adrian@chaves.io>, 2017, 2018, 2019.
+# SPDX-FileCopyrightText: 2024 Adrián Chaves (Gallaecio)
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
-"PO-Revision-Date: 2019-09-28 23:50+0200\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
+"PO-Revision-Date: 2023-06-23 22:22+0200\n"
 "Last-Translator: Adrián Chaves (Gallaecio) <adrian@chaves.io>\n"
-"Language-Team: Galician <proxecto@trasno.gal>\n"
+"Language-Team: Proxecto Trasno (proxecto@trasno.gal)\n"
 "Language: gl\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Generator: Lokalize 19.11.70\n"
+"X-Generator: Lokalize 23.08.5\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
-#, fuzzy, kde-format
-#| msgid "Account Removal"
+#: src/kcm/ui/AccountDetails.qml:20
+#, kde-format
 msgid "Account Details"
-msgstr "Eliminación de conta"
+msgstr "Detalles da conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
-msgstr ""
+msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
-#, fuzzy, kde-format
-#| msgid "Accounts"
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
+#, kde-format
 msgid "%1 account"
-msgstr "Contas"
+msgstr "Conta de %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
 "account's human-readable name"
 msgid "Change Account Display Name"
-msgstr ""
+msgstr "Cambiar o nome visual da conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
-msgstr ""
+msgstr "Usar esta conta para"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
-msgstr ""
+msgstr "Retirar esta conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
 "There are no configurable services available for this account. You can still "
 "change its display name by clicking the edit icon above."
 msgstr ""
+"Non hai servizos configurábeis dispoñíbeis para esta conta. Pero podes "
+"cambiar o seu nome visual premendo a icona de editar de enriba."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
-#, fuzzy, kde-format
-#| msgid "ownCloud account Wizard"
+#: src/kcm/ui/AvailableAccounts.qml:19
+#, kde-format
 msgid "Add New Account"
-msgstr "Asistente de contas de ownCloud"
+msgstr "Engadir unha nova conta"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
 "account"
 msgid "Remove %1"
-msgstr ""
+msgstr "Retirar %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
-msgstr ""
+msgstr "Aínda non se engadiu ningunha conta."
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
 "Click the <interface>Add New Account...</interface> button below to add one"
 msgstr ""
+"Preme o botón de <interface>Engadir unha nova conta…</interface> embaixo "
+"para engadir unha"
 
-#: src/kcm/package/contents/ui/main.qml:88
-#, fuzzy, kde-format
-#| msgid "ownCloud account Wizard"
+#: src/kcm/ui/main.qml:83
+#, kde-format
 msgid "Add New Account..."
-msgstr "Asistente de contas de ownCloud"
+msgstr "Engadir unha nova conta…"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
-#, fuzzy, kde-format
-#| msgid "Accounts"
+#: src/kcm/ui/RemoveAccountDialog.qml:22
+#, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
-msgstr "Contas"
+msgstr "Retirar a conta?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
-#, fuzzy, kde-format
-#| msgid ""
-#| "Are you sure that you want to remove the account '%1'? This cannot be "
-#| "undone."
+#: src/kcm/ui/RemoveAccountDialog.qml:40
+#, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
 "name and account name are available"
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
-msgstr ""
-"Está seguro de que quere retirar a conta «%1»? Isto non pode desfacerse."
+msgstr "Seguro que quere retirar a conta «%2» de «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
-#, fuzzy, kde-format
-#| msgid ""
-#| "Are you sure that you want to remove the account '%1'? This cannot be "
-#| "undone."
+#: src/kcm/ui/RemoveAccountDialog.qml:42
+#, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
 "name is available"
 msgid "Are you sure you wish to remove the account \"%1\"?"
-msgstr ""
-"Está seguro de que quere retirar a conta «%1»? Isto non pode desfacerse."
+msgstr "Seguro que quere retirar a conta «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
-#, fuzzy, kde-format
-#| msgid ""
-#| "Are you sure that you want to remove the account '%1'? This cannot be "
-#| "undone."
+#: src/kcm/ui/RemoveAccountDialog.qml:44
+#, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
 "provider name is available"
 msgid "Are you sure you wish to remove this \"%1\" account?"
-msgstr ""
-"Está seguro de que quere retirar a conta «%1»? Isto non pode desfacerse."
+msgstr "Seguro que quere retirar esta conta de «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, fuzzy, kde-format
-#| msgid "Accounts"
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Contas"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
-#, fuzzy, kde-format
-#| msgid "Accounts"
+#: src/kcm/ui/RenameAccountDialog.qml:17
+#, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
 "account"
 msgid "Rename Account"
-msgstr "Contas"
+msgstr "Renomear a conta"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
 "account"
 msgid "Enter new name:"
-msgstr ""
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr ""
+msgstr "Escriba o novo nome"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
-msgstr ""
+msgstr "Non se atopou ningunha conta co identificador %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
-msgstr ""
+msgstr "Non hai xestor de contas, isto non é o ideal."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
-msgstr ""
+msgstr "O nome visual non pode estar baleiro"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
-msgstr "Non se puido cargar o complemento %1. Comprobe a instalación."
+msgstr "Non foi posíbel cargar o complemento %1. Comprobe a instalación."
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
-msgstr ""
+msgstr "Cancelado pola persoa usuaria"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Produciuse un erro ao intentar procesar a solicitude: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
-msgstr ""
+msgstr "Non foi posíbel atopar a conta"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
-msgstr ""
+msgstr "Non foi posíbel atopar as credenciais"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
-msgstr ""
+msgstr "Non foi posíbel crear unha sesión de autenticación"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr ""
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Retirar a conta"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Definir o nome da conta"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/hu/kaccounts-integration.po 4:24.02.2-1/po/hu/kaccounts-integration.po
--- 4:22.12.3-1/po/hu/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/hu/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-09-20 10:03+0200\n"
 "Last-Translator: Kristof Kiszel <kiszel.kristof@gmail.com>\n"
 "Language-Team: Hungarian <kde-l10n-hu@kde.org>\n"
@@ -18,24 +18,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 "X-Generator: Lokalize 21.03.80\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Fiókadatok"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 fiók"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Megjelenített név módosítása"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "A fiókhoz csatolt szolgáltatások:"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Fiók eltávolítása"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "Nincsenek szerkeszthető szolgáltatások ehhez a fiókhoz. A megjelenített "
 "nevet ettől függetlenül módosíthatja a fenti ikonra kattintással."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Új fiók hozzáadása"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 eltávolítása"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Nincsenek fiókok hozzáadva"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Kattintson az <interface>Új fiók hozzáadása…</interface> gombra új fiók "
 "felvételéhez"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Új fiók hozzáadása…"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Fiók eltávolítása?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Biztosan szeretné eltávolítani a(z) „%2” „%1” fiókot?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Biztosan szeretné eltávolítani a(z) „%1” fiókot?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Biztosan szeretné eltávolítani ezt a(z) „%1” fiókot?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Fiók eltávolítása"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Fiók átnevezése"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Új név:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Fióknév megadása"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Nem található %1 azonosítójú fiók"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Nincs fiókkezelő, ez nagyon nincs rendben."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "A megjelenített név nem lehet üres"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "A(z) %1 bővítmény nem tölthető be, ellenőrizze a rendszert"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Felhasználói megszakítás"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Hiba történt a kérés feldolgozása során: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Nem található fiók"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Nem találhatók hitelesítési adatok"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Nem lehet létrehozni hitelesítési munkamenetet"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "A jelszókezelő nem nyitható meg"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Fiók eltávolítása"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Fióknév megadása"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "A jelszókezelő nem nyitható meg"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/ia/kaccounts-integration.po 4:24.02.2-1/po/ia/kaccounts-integration.po
--- 4:22.12.3-1/po/ia/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ia/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-03-28 23:17+0100\n"
 "Last-Translator: Giovanni Sora <g.sora@tiscali.it>\n"
 "Language-Team: Interlingua <kde-i18n-doc@kde.org>\n"
@@ -17,24 +17,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 2.0\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detalios de conto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 conto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Cambia nomine de conto de monstrar"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Usa iste conto per"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Remove iste conto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "ancora pote cambiar su nomine de monstrar per pulsar le icone de modificar "
 "de supra."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Adde un nove conto"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Remove %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Ancora necun contos addite"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Pulsa le button <interface>Adde Nove Conto...</interface> a basso per adder "
 "un"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Adde un nove conto..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Remove conto?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Tu es secur que tu vole remover le \"%1\" conto \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Tu es secur que tu vole remover le conto \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Tu es secur que tu vole remover iste \"%1\" conto ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Remove conto"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Renomina conto"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Inserta nove nomine:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Fixa Nomine de conto"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Necun cono trovate con le ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Nulle gerente de contos,isto non es belle."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Le nomine d emonstrtor non pote esser vacue"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Non pote cargar plugin %1, pro favor verifica tu installation"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Cancellate per le usator"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Il occurreva un error durante que il tentava processar le requesta: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Non pote trovar conto"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Non pote trovar credentiales"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Non pote trovar session de auth"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Non pote aperir portafolio"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Remove conto"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Fixa Nomine de conto"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Non pote aperir portafolio"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/id/kaccounts-integration.po 4:24.02.2-1/po/id/kaccounts-integration.po
--- 4:22.12.3-1/po/id/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/id/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,40 +1,39 @@
-# Copyright (C) YEAR This file is copyright:
+# Copyright (C) 2023 This file is copyright:
 # This file is distributed under the same license as the kaccounts-integration package.
 # Wantoyèk <wantoyek@gmail.com>, 2023.
+# SPDX-FileCopyrightText: 2023 Linerly <linerly@linerly.xyz>
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
-"PO-Revision-Date: 2023-01-01 21:27+0700\n"
-"Last-Translator: Wantoyèk <wantoyek@gmail.com>\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
+"PO-Revision-Date: 2023-12-03 13:14+0700\n"
+"Last-Translator: Linerly <linerly@linerly.xyz>\n"
 "Language-Team: Indonesian <kde-i18n-doc@kde.org>\n"
 "Language: id\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Lokalize 22.08.3\n"
+"X-Generator: Lokalize 23.08.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detail Akun"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 akun"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,33 +41,33 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Ubah Nama Tampilan Akun"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Gunakan Akun Ini Untuk"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Hapus Akun Ini"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
 "There are no configurable services available for this account. You can still "
 "change its display name by clicking the edit icon above."
 msgstr ""
-"Tidak ada layanan yang dapat diatur yang tersedia untuk akun ini. Kamu masih "
+"Tidak ada layanan yang dapat diatur yang tersedia untuk akun ini. Anda masih "
 "bisa mengubah nama yang ditampilkan dengan mengeklik ikon edit di atas."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Tambahkan Akun Baru"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Hapus %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Belum ada akun yang ditambahkan"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -91,49 +90,42 @@ msgstr ""
 "Klik tombol <interface>Tambahkan Akun Baru...</interface> di bawah untuk "
 "menambahkannya"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Tambahkan Akun Baru..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Hapus Akun?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
 "name and account name are available"
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
-msgstr "Apakah kamu yakin ingin menghapus akun \"%1\" \"%2\"?"
+msgstr "Apakah Anda yakin ingin menghapus akun \"%1\" \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
 "name is available"
 msgid "Are you sure you wish to remove the account \"%1\"?"
-msgstr "Apakah kamu yakin ingin menghapus akun \"%1\"?"
+msgstr "Apakah Anda yakin ingin menghapus akun \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
 "provider name is available"
 msgid "Are you sure you wish to remove this \"%1\" account?"
-msgstr "Apakah kamu yakin ingin menghapus akun \"%1\" ini?"
+msgstr "Apakah Anda yakin ingin menghapus akun \"%1\" ini?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Hapus Akun"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -141,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Ubah Nama Akun"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -149,61 +141,59 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Masukkan nama baru:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Setel Nama Akun"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Tidak ada akun yang ditemukan dengan ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Tidak ada pengelola akun, ini tidak mengagumkan."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Nama yang ditampilkan tidak boleh kosong"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Tidak bisa memuat plugin %1, silakan periksa instalanmu"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Dibatalkan oleh pengguna"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Ada sebuah galat selagi mencoba memproses permintaan: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Tidak bisa menemukan akun"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Tidak bisa menemukan kredensial"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Tidak bisa membuat sesi autentikasi"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Tidak bisa membuka wallet"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Hapus Akun"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Setel Nama Akun"
diff -pruN 4:22.12.3-1/po/it/kaccounts-integration.po 4:24.02.2-1/po/it/kaccounts-integration.po
--- 4:22.12.3-1/po/it/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/it/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,12 +1,12 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the kaccounts-integration package.
-# Luigi Toscano <luigi.toscano@tiscali.it>, 2015, 2016, 2017, 2019, 2020, 2021.
+# Luigi Toscano <luigi.toscano@tiscali.it>, 2015, 2016, 2017, 2019, 2020, 2021, 2024.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-03-26 19:57+0100\n"
 "Last-Translator: Luigi Toscano <luigi.toscano@tiscali.it>\n"
 "Language-Team: Italian <kde-i18n-it@kde.org>\n"
@@ -15,26 +15,24 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Lokalize 20.12.0\n"
+"X-Generator: Lokalize 22.12.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Dettagli dell'account"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Account %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Cambia nome pubblico dell'account"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Usa questo account per"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Rimuovi questo account"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "comunque cambiare il nome visualizzato facendo clic sull'icona di modifica "
 "sopra."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Aggiungi un nuovo account"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Rimuovi %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Nessun account è stato aggiunto"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Fai clic sul pulsante <interface>Aggiungi un nuovo account...</interface> "
 "sotto per aggiungerne uno"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Aggiungi un nuovo account..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Rimuovi account?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Sei sicuro di voler rimuovere l'account «%2» per «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Sei sicuro di voler rimuovere l'account «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Sei sicuro di voler rimuovere l'account per «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Rimuovi account"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Rinomina account"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,66 +141,67 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Inserisci il nuovo nome:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Imposta il nome dell'account"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Nessun account trovato con ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Nessun gestore degli account, questo non va bene."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Il nome visualizzato non può essere vuoto"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Impossibile caricare l'estensione %1, controlla la tua installazione"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Annullato dall'utente"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr ""
 "Si è verificato un errore durante il tentativo di elaborazione della "
 "richiesta: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Impossibile trovare l'account"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Impossibile trovare le credenziali"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Impossibile creare una sessione di autenticazione"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Impossibile aprire il portafoglio"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Rimuovi account"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Imposta il nome dell'account"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Impossibile aprire il portafoglio"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/ja/kaccounts-integration.po 4:24.02.2-1/po/ja/kaccounts-integration.po
--- 4:22.12.3-1/po/ja/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ja/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,39 +1,37 @@
-# Ryuichi Yamada <ryuichi_ya220@outlook.jp>, 2023.
+# SPDX-FileCopyrightText: 2023, 2024 Ryuichi Yamada <ryuichi_ya220@outlook.jp>
 msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2023-02-23 18:31+0900\n"
 "Last-Translator: Ryuichi Yamada <ryuichi_ya220@outlook.jp>\n"
-"Language-Team: Japanese <kde-jp@kde.org>\n"
+"Language-Team: ja\n"
 "Language: ja\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=2; plural=n != 1;\n"
+"Plural-Forms: nplurals=1; plural=0;\n"
 "X-Accelerator-Marker: &\n"
 "X-Text-Markup: kde4\n"
-"X-Generator: Lokalize 22.12.2\n"
+"X-Generator: Lokalize 23.08.5\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "アカウントの詳細"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 アカウント"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -41,18 +39,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "アカウントの表示名を変更"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "アカウントを使用するサービス"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "このアカウントを削除"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -62,12 +60,12 @@ msgstr ""
 "このアカウントのために利用できる設定可能なサービスがありません。上の編集アイ"
 "コンをクリックして、表示名を変更することは可能です。"
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "新しいアカウントを追加"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -75,13 +73,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 を削除"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "追加されたアカウントはありません"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -89,18 +87,18 @@ msgid ""
 msgstr ""
 "<interface>新しいアカウントを追加...</interface>ボタンをクリックして追加"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "新しいアカウントを追加..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "削除しますか？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -108,7 +106,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "本当に \"%1\" アカウント \"%2\" を削除しますか？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -116,7 +114,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "本当にアカウント \"%1\" を削除しますか？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -124,14 +122,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "本当にこの \"%1\" アカウントを削除しますか？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "アカウントを削除"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -139,7 +130,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "アカウントの名前を変更"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -147,30 +138,22 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "新しい名前を入力:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "アカウント名を設定"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "ID %1 を使用するアカウントが見つかりませんでした"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "アカウントマネージャがありません。"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "表示名は空にはできません"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
@@ -178,32 +161,38 @@ msgstr ""
 "プラグイン %1 を読み込めませんでした。正しくインストールされているか確認して"
 "ください"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "ユーザによってキャンセルされました"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "要求の処理中にエラーが発生しました: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "アカウントが見つかりません"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "認証情報が見つかりません"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "認証セッションを作成できません"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "ウォレットを開けません"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "アカウントを削除"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "アカウント名を設定"
diff -pruN 4:22.12.3-1/po/ka/kaccounts-integration.po 4:24.02.2-1/po/ka/kaccounts-integration.po
--- 4:22.12.3-1/po/ka/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ka/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2022-04-24 19:15+0200\n"
 "Last-Translator: Temuri Doghonadze <temuri.doghonadze@gmail.com>\n"
 "Language-Team: Georgian <kde-i18n-doc@kde.org>\n"
@@ -18,24 +18,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 "X-Generator: Poedit 3.0.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "ანგარშის დეტალები"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1-ის ანგარიში"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "ანგარიშის საჩვენებელი სახელის შეცვლა"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "ანგარიშის გამოყენებული იქნება"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "ამ ანგარიშის წაშლა"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "ამ ანგარიშს არ გააჩნია მორგებადი სერვისები. მისი საჩვენებელი სახელის მორგება "
 "ჩასწორების ხატულაზე დაწკაპუნებით შეგიძლიათ."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "ახალი ანგარიშის დამატება"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1-ის წაშლა"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "ანგარიშები დამატებული არაა"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "დასამატებლად დააწკაპუნეთ <interface>ახალი ანგარიშის დამატება...</interface>-"
 "ზე ქვემოთ"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "ახალი ანგარიშის დამატება..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "წავშალო ანგარიში?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "დარწმუნებული ბრძანდებით, რომ გნებავთ %1-ის ანგარიშის %2-ის წაშლა?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "დარწმუნებული ბრძანდებით, რომ გნებავთ ამ ანგარიშის (%1) წაშლა?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "დარწმუნებული ბრძანდებით, რომ გნებავთ ამ ანგარიშის (%1) წაშლა?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "ანგარიშის წაშლა"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "ანგარიშის სახელის გადარქმევა"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "შეიყვანეთ ახალი სახელი:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "შეიყვანეთ ანგარიშის სახელი"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "ID-ით %1 ანგარიში ნაპოვნი არაა"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "ანგარიშების მმართველის გარეშე. ეს კარგი არაა."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "საჩვენებელი სახელი ცარიელი არ შეიძლება იყოს"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "დამატება %1-ის ჩატვირთვა შეუძლებელია. შეამოწმეთ თქვენი ინსტალაცია"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "გაუქმებულია მომხმარებლის მიერ"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "შეცდომა მოთხოვნის დამუშავებისას: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "ანგარიშის პოვნა შეუძლებელია"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "მომხმარებლის/პაროლის პოვნა შეუძლებელია"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "ავთენტიკაციის სესიის შექმნა შეუძლებელია"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "საფულის გახსნის შეცდომა"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "ანგარიშის წაშლა"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "შეიყვანეთ ანგარიშის სახელი"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "საფულის გახსნის შეცდომა"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/ko/kaccounts-integration.po 4:24.02.2-1/po/ko/kaccounts-integration.po
--- 4:22.12.3-1/po/ko/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ko/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,12 +1,12 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
-# Shinjo Park <kde@peremen.name>, 2015, 2016, 2017, 2019, 2020, 2021, 2022.
+# SPDX-FileCopyrightText: 2015, 2016, 2017, 2019, 2020, 2021, 2022, 2024 Shinjo Park <kde@peremen.name>
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2022-04-16 22:45+0200\n"
 "Last-Translator: Shinjo Park <kde@peremen.name>\n"
 "Language-Team: Korean <kde-kr@kde.org>\n"
@@ -15,26 +15,24 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
-"X-Generator: Lokalize 21.08.1\n"
+"X-Generator: Lokalize 23.08.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "계정 정보"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1(%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 계정"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "계정 표시 이름 변경"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "다음에 이 계정 사용"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "이 계정 삭제"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -63,12 +61,12 @@ msgstr ""
 "이 계정에서 설정할 수 있는 서비스가 없습니다. 위에 있는 아이콘을 클릭해서 표"
 "시 이름을 바꿀 수 있습니다."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "새 계정 추가"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,13 +74,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 삭제"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "추가한 계정 없음"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -91,18 +89,18 @@ msgstr ""
 "아래에 있는 <interface>새 계정 추가...</interface> 단추를 클릭해서 계정을 추"
 "가하십시오"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "새 계정 추가..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "계정을 삭제하시겠습니까?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -110,7 +108,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "\"%1\" 계정 \"%2\"을(를) 삭제하시겠습니까?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -118,7 +116,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "\"%1\" 계정을 삭제하시겠습니까?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -126,14 +124,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "\"%1\" 계정을 삭제하시겠습니까?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "계정 삭제"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -141,7 +132,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "계정 이름 바꾸기"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -149,64 +140,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "새 이름 입력:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "계정 이름 설정"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "ID가 %1인 계정 없음"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "계정 관리자가 없습니다. 무언가 잘못되었습니다."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "표시 이름을 비워둘 수 없음"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "%1 플러그인을 불러올 수 없습니다. 설치 상태를 확인하십시오"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "사용자가 취소함"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "요청을 처리하는 중 오류 발생: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "계정을 찾을 수 없음"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "인증 정보를 찾을 수 없음"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "인증 세션을 만들 수 없음"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "지갑을 열 수 없음"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "계정 삭제"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "계정 이름 설정"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "지갑을 열 수 없음"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/lt/kaccounts-integration.po 4:24.02.2-1/po/lt/kaccounts-integration.po
--- 4:22.12.3-1/po/lt/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/lt/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,8 +7,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: trunk-kf 5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
-"PO-Revision-Date: 2021-06-15 22:46+0300\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
+"PO-Revision-Date: 2024-02-02 16:11+0200\n"
 "Last-Translator: Moo\n"
 "Language-Team: lt\n"
 "Language: lt\n"
@@ -17,26 +17,24 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=4; plural=(n==1 ? 0 : n%10>=2 && (n%100<10 || n"
 "%100>=20) ? 1 : n%10==0 || (n%100>10 && n%100<20) ? 2 : 3);\n"
-"X-Generator: Poedit 3.0\n"
+"X-Generator: Poedit 3.0.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Informacija apie paskyrą"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 paskyra"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -44,18 +42,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Keisti rodomą paskyros pavadinimą"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Kam naudoti šią paskyrą:"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Šalinti šią paskyrą"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -65,12 +63,12 @@ msgstr ""
 "Šiai paskyrai nėra prieinamų konfigūruojamų paslaugų. Vis dėlto, galite "
 "pakeisti rodomą jos pavadinimą, aukščiau spusteldami taisymo mygtuką."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Pridėti naują paskyrą"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -78,13 +76,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Šalinti %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Kol kas nėra pridėta jokių paskyrų"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -93,18 +91,18 @@ msgstr ""
 "Norėdami pridėti paskyrą, spustelėkite žemiau mygtuką <interface>Pridėti "
 "naują paskyrą...</interface>"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Pridėti naują paskyrą..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Šalinti paskyrą?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -112,7 +110,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Ar tikrai norite pašalinti „%1“ paskyrą „%2“?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -120,7 +118,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Ar tikrai norite pašalinti paskyrą „%1“?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -128,14 +126,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Ar tikrai norite pašalinti šią „%1“ paskyrą?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Šalinti paskyrą"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -143,7 +134,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Pervadinti paskyrą"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -151,64 +142,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Įveskite naują pavadinimą:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Nustatyti paskyros pavadinimą"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Nerasta jokios paskyros su ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Nėra paskyrų tvarkytuvės, nuostabu."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Rodomas vardas negali būti tuščias"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
-msgstr "Nepavyko įkelti %1 priedo, patikrinkite savo diegimą"
+msgstr "Nepavyko įkelti %1 įskiepio, patikrinkite savo diegimą"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Naudotojas atsisakė"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Bandant apdoroti užklausą, įvyko klaida: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Nepavyko rasti paskyros"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Nepavyko rasti prisijungimo duomenų"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Nepavyko sukurti tapatybės nustatymo seanso"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Nepavyksta atverti slaptažodinės"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Šalinti paskyrą"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Nustatyti paskyros pavadinimą"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Nepavyksta atverti slaptažodinės"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/nl/kaccounts-integration.po 4:24.02.2-1/po/nl/kaccounts-integration.po
--- 4:22.12.3-1/po/nl/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/nl/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-03-24 09:52+0100\n"
 "Last-Translator: Freek de Kruijf <freekdekruijf@kde.nl>\n"
 "Language-Team: Dutch <kde-i18n-nl@kde.org>\n"
@@ -17,24 +17,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.12.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Accountdetails"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 account"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Schermnaam van account wijzigen"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Dit account gebruiken voor"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Dit account verwijderen"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "toch zijn schermnaam wijzigen door te klikken op het bovenstaande pictogram "
 "Bewerken."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Een nieuw account toevoegen"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 verwijderen"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Nog geen accounts toegevoegd"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Op de onderstaande knop <interface>Nieuw account toevoegen...</interface> "
 "klikken om er een toe te voegen"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Nieuw account toevoegen..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Account verwijderen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Wilt u het \"%1\"-account '%2' verwijderen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Wilt u het account '%1' verwijderen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Wilt u dit account \"%1\"-verwijderen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Account verwijderen"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Account hernoemen"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Nieuwe naam invoeren:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Accountnaam instellen"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Geen account gevonden met het ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Geen beheerder van accounts, dit is niet geweldig."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "De schermnaam mag niet leeg zijn"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Kan de plug-in %1 niet laden, controleer uw installatie"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Geannuleerd door de gebruiker"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Er was een fout bij het proberen om het verzoek te verwerken: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Kon account niet vinden "
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Kon credentials niet vinden"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Kon autorisatiesessie niet aanmaken"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Kan portefeuille niet openen"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Account verwijderen"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Accountnaam instellen"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Kan portefeuille niet openen"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/nn/kaccounts-integration.po 4:24.02.2-1/po/nn/kaccounts-integration.po
--- 4:22.12.3-1/po/nn/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/nn/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-12-15 12:43+0100\n"
 "Last-Translator: Oystein Steffensen-Alvaervik <ystein@posteo.net>\n"
 "Language-Team: Norwegian Nynorsk <l10n-no@lister.huftis.org>\n"
@@ -20,24 +20,22 @@ msgstr ""
 "X-Accelerator-Marker: &\n"
 "X-Text-Markup: kde4\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Konto­detaljar"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1-konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -45,18 +43,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Byt visingsnamn for konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Bruk kontoen for"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Fjern kontoen"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -66,12 +64,12 @@ msgstr ""
 "Det finst ingen tenester som kan setjast opp for denne kontoen. Du kan "
 "framleis endra visings­namnet, ved å trykkja på redigerings­ikonet ovanfor."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Legg til konto"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -79,13 +77,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Fjern %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Ingen kontoar er lagde til"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -93,18 +91,18 @@ msgid ""
 msgstr ""
 "Trykk <interface>Legg til konto …</interface> for å leggja til ein ny konto"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Legg til konto …"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Fjerna kontoen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -112,7 +110,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Er du sikker på at du vil fjerna «%1»-kontoen «%2»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -120,7 +118,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Er du sikker på at du vil fjerna kontoen «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -128,14 +126,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Er du sikker på at du vil fjerna denne «%1»-kontoen?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Fjern konto"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -143,7 +134,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Endra namn på konto"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -151,61 +142,48 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Skriv inn nytt namn:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Vel kontonamn"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Fann ikkje nokon konto med ID-en %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Manglar kontohandsamar. Dette er ikkje bra."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Visiningsnamnet kan ikkje vera tomt"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Klarte ikkje lasta tillegget %1. Kontroller at alt er rett installert."
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Avbroten av brukar"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Det oppstod ein feil ved handsaming av førespurnaden: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Fann ikkje kontoen"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Fann ikkje brukarinformasjon"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Klarte ikkje starta autentiseringsøkt"
-
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Klarte ikkje opna lommeboka"
diff -pruN 4:22.12.3-1/po/pa/kaccounts-integration.po 4:24.02.2-1/po/pa/kaccounts-integration.po
--- 4:22.12.3-1/po/pa/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/pa/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-04-25 13:07-0700\n"
 "Last-Translator: A S Alam <aalam@satluj.org>\n"
 "Language-Team: Punjabi <punjabi-users@lists.sf.net>\n"
@@ -17,24 +17,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.08.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "ਖਾਤੇ ਦੇ ਵੇਰਵੇ"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 ਖਾਤਾ"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "ਆਪਣਾ ਖਾਤੇ ਲਈ ਦਿਖਾਵਾ ਨਾਂ ਬਦਲੋ"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "ਇਹ ਖਾਤੇ ਨੂੰ ਇਸ ਲਈ ਵਰਤੋਂ"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "ਇਹ ਖਾਤੇ ਨੂੰ ਹਟਾਓ"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -61,12 +59,12 @@ msgid ""
 "change its display name by clicking the edit icon above."
 msgstr ""
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "ਨਵਾਂ ਖਾਤਾ ਜੋੜੋ"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -74,31 +72,31 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 ਨੂੰ ਹਟਾਓ"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "ਹਾਲੇ ਕੋਈ ਖਾਤਾ ਨਹੀਂ ਜੋੜਿਆ"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
 "Click the <interface>Add New Account...</interface> button below to add one"
 msgstr "ਨਵਾਂ ਜੋੜਨ ਲਈ <interface>...ਨਵਾਂ ਖਾਤਾ ਜੋੜੋ</interface> ਬਟਨ ਨੂੰ ਦਬਾਓ"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "...ਨਵਾਂ ਖਾਤਾ ਜੋੜੋ"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "ਖਾਤੇ ਨੂੰ ਹਟਾਉਣਾ ਹੈ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -106,7 +104,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "ਕੀ ਤੁਸੀਂ \"%1\" ਖਾਤੇ \"%2\" ਨੂੰ ਹਟਾਉਣਾ ਚਾਹੁੰਦੇ ਹੋ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -114,7 +112,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "ਕੀ ਤੁਸੀਂ \"%1\" ਖਾਤੇ ਨੂੰ ਹਟਾਉਣਾ ਚਾਹੁੰਦੇ ਹੋ?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -122,14 +120,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "ਖਾਤੇ ਨੂੰ ਹਟਾਓ"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -137,7 +128,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "ਖਾਤੇ ਦਾ ਨਾਂ ਬਦਲੋ"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -145,64 +136,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "ਨਵਾਂ ਨਾਂ ਦਿਓ:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "ਖਾਤੇ ਨੂੰ ਨਾਂ ਦਿਓ"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "ਵਰਤੋਂਕਾਰ ਵਲੋਂ ਰੱਦ ਕੀਤਾ"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "ਵਾਲੇਟ ਨੂੰ ਖੋਲ੍ਹਿਆ ਨਹੀਂ ਜਾ ਸਕਦਾ"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "ਖਾਤੇ ਨੂੰ ਹਟਾਓ"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "ਖਾਤੇ ਨੂੰ ਨਾਂ ਦਿਓ"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "ਵਾਲੇਟ ਨੂੰ ਖੋਲ੍ਹਿਆ ਨਹੀਂ ਜਾ ਸਕਦਾ"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/pl/kaccounts-integration.po 4:24.02.2-1/po/pl/kaccounts-integration.po
--- 4:22.12.3-1/po/pl/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/pl/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-04-05 08:04+0200\n"
 "Last-Translator: Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>\n"
 "Language-Team: Polish <kde-i18n-doc@kde.org>\n"
@@ -18,24 +18,22 @@ msgstr ""
 "|| n%100>=20) ? 1 : 2);\n"
 "X-Generator: Lokalize 20.12.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Szczegóły konta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Konto %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Zmień wyświetlaną nazwę konta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Użyj tego konta dla"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Usuń to konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "Dla tego konta nie są dostępne żadne usługi, które można ustawić. Nadal "
 "możesz zmienić jego wyświetlaną nazwę naciskając na ikonie zmiany powyżej."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Dodaj nowe konto"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Usuń %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Nie dodano jeszcze żadnego konta"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Naciśnij przycisk <interface>Dodaj nowe konto...</interface>, aby dodać nowe "
 "konto"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Dodaj nowe konto..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Usunąć konto?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Czy na pewno chcesz usunąć konto \"%1\" \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Czy na pewno chcesz usunąć konto \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Czy na pewno chcesz usunąć konto \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Usuń konto"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Przemianuj konto"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Wpisz nową nazwę:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Ustaw nazwę konta"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Nie znaleziono konta o ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Brak programu do zarządzania kontami, niefajnie."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Wyświetlana nazwa nie może być pusta"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Nie można wczytać wtyczki %1, sprawdź czy wszystko wgrałeś"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Porzucone przez użytkownika"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Wystąpił błąd podczas przetwarzania żądania: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Nie można znaleźć konta"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Nie można znaleźć danych dostępowych"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Nie można utworzyć sesji uwierzytelnionej"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Nie można otworzyć portfela"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Usuń konto"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Ustaw nazwę konta"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Nie można otworzyć portfela"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/pt/kaccounts-integration.po 4:24.02.2-1/po/pt/kaccounts-integration.po
--- 4:22.12.3-1/po/pt/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/pt/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-03-24 12:39+0000\n"
 "Last-Translator: José Nuno Coelho Pires <zepires@gmail.com>\n"
 "Language-Team: Portuguese <kde-i18n-pt@kde.org>\n"
@@ -21,24 +21,22 @@ msgstr ""
 "X-POFile-SpellExtra: ktp accounts kaccounts Sebastian Kügler Turthra\n"
 "X-POFile-SpellExtra: Jensen Leinir\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detalhes da Conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Conta do %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -46,18 +44,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Modificar o Nome Visível da Conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Usar esta Conta para"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Remover esta Conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -67,12 +65,12 @@ msgstr ""
 "Não estão disponíveis serviços configuráveis para esta conta. Poderá à mesma "
 "mudar o seu nome visível se carregar no ícone de edição acima."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Adicionar uma Nova Conta"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -80,13 +78,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Remover a %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Nenhuma conta adicionada"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -95,18 +93,18 @@ msgstr ""
 "Carregue no botão <interface>Adicionar uma Nova Conta...</interface> em "
 "baixo para criar uma"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Adicionar uma Nova Conta..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Remover a Conta?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -114,7 +112,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Tem a certeza que deseja remover a conta \"%2\" do \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -122,7 +120,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Tem a certeza que deseja remover a conta \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -130,14 +128,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Tem a certeza que deseja remover esta conta do \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Remover a Conta"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -145,7 +136,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Mudar o Nome da Conta"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -153,65 +144,66 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Indique o novo nome:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Modificar o Nome da Conta"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Não foi encontrada nenhuma conta com o ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Não existe nenhum gestor de contas, o que não é bom."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "O nome visível não poderá estar em branco"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr ""
 "Não foi possível carregar o 'plugin' %1; verifique por favor a sua instalação"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Cancelado pelo utilizador"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Ocorreu um erro ao tentar processar o pedido: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Não foi possível encontrar a conta"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Não foi possível encontrar as credenciais"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Não foi possível criar uma sessão de autenticação"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Não é possível abrir a carteira"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Remover a Conta"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Modificar o Nome da Conta"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Não é possível abrir a carteira"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/pt_BR/kaccounts-integration.po 4:24.02.2-1/po/pt_BR/kaccounts-integration.po
--- 4:22.12.3-1/po/pt_BR/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/pt_BR/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-04-06 14:38-0300\n"
 "Last-Translator: Luiz Fernando Ranghetti <elchevive@opensuse.org>\n"
 "Language-Team: Brazilian Portuguese <kde-i18n-pt_BR@kde.org>\n"
@@ -19,24 +19,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=(n > 1);\n"
 "X-Generator: Lokalize 20.04.2\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detalhes da conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Conta %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -44,18 +42,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Alterar o nome de exibição da conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Usar esta conta para"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Remover esta conta"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -65,12 +63,12 @@ msgstr ""
 "Não existem serviços configuráveis disponíveis para esta conta. Você ainda "
 "pode alterar o nome de exibição clicando no ícone de edição acima."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Adicionar nova conta"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -78,13 +76,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Remover %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Nenhuma conta adicionada ainda"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -93,18 +91,18 @@ msgstr ""
 "Clique no botão <interface>Adicionar nova conta...</interface> abaixo para "
 "adicionar uma"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Adicionar nova conta..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Remover conta?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -112,7 +110,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Deseja realmente remover a conta \"%1\" \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -120,7 +118,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Deseja realmente remover a conta \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -128,14 +126,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Deseja realmente remover esta conta \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Remover conta"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -143,7 +134,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Renomear conta"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -151,64 +142,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Digite o novo nome:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Definir o nome da conta"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Nenhuma conta encontrada com o ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Nenhum gerenciador de contas, isto não é legal."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "O nome de exibição não pode esta vazio"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Não foi possível carregar o plugin %1, verifique sua instalação"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Cancelado pelo usuário"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Ocorreu um erro ao tentar processar a solicitação: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Não foi possível encontrar a conta"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Não foi possível encontrar as credenciais"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Não foi possível criar a sessão de autenticação"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Não foi possível abrir a carteira"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Remover conta"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Definir o nome da conta"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Não foi possível abrir a carteira"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/ro/kaccounts-integration.po 4:24.02.2-1/po/ro/kaccounts-integration.po
--- 4:22.12.3-1/po/ro/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ro/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -1,41 +1,39 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
-# Sergiu Bivol <sergiu@cip.md>, 2015, 2020, 2021.
+# Sergiu Bivol <sergiu@cip.md>, 2015, 2020, 2021, 2024.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-06-02 20:51+0100\n"
 "Last-Translator: Sergiu Bivol <sergiu@cip.md>\n"
-"Language-Team: Romanian\n"
+"Language-Team: Romanian <kde-i18n-ro@kde.org>\n"
 "Language: ro\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < "
 "20)) ? 1 : 2;\n"
-"X-Generator: Lokalize 19.12.3\n"
+"X-Generator: Lokalize 21.12.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Detalii cont"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Cont %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Schimbă numele afișat al contului"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Folosește acest cont pentru"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Elimină acest cont"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "Nu sunt servicii configurabile pentru acest cont. Îi puteți schimba numele "
 "afișat apăsând pe pictograma de redactare de mai sus."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Adaugă cont nou"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Elimină %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Încă nu au fost adăugate conturi"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Apăsați butonul <interface>Adaugă cont nou...</interface> de mai jos pentru "
 "a adăuga unul"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Adaugă cont nou..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Eliminați contul?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Sigur doriți să eliminați contul „%2” din „%1”?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Sigur doriți să eliminați contul „%1”?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Sigur doriți să eliminați acest cont „%1”?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Elimină contul"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Redenumește contul"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Introduceți noua denumire:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Stabilește denumirea contului"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Nu s-a găsit niciun cont cu identificatorul %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Niciun gestionar de conturi, asta nu e bine."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Numele afișat nu poate fi gol"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Extensia %1 nu poate fi încărcată, verificați instalarea"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Anulat de utilizator"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "A avut loc o eroare la încercarea de a prelucra cererea: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Contul nu poate fi găsit"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Acreditările nu pot fi găsite"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Sesiunea de autentificare nu poate fi creată"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Portofelul nu poate fi deschis"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Elimină contul"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Stabilește denumirea contului"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Portofelul nu poate fi deschis"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/ru/kaccounts-integration.po 4:24.02.2-1/po/ru/kaccounts-integration.po
--- 4:22.12.3-1/po/ru/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/ru/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-04-17 21:46+0300\n"
 "Last-Translator: Alexander Yavorsky <kekcuha@gmail.com>\n"
 "Language-Team: Russian <kde-russian@lists.kde.ru>\n"
@@ -19,24 +19,22 @@ msgstr ""
 "%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 "X-Generator: Lokalize 20.12.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Сведения об учётной записи"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Учётная запись %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -44,18 +42,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Изменение отображаемого имени учётной записи"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Использовать ресурсы учётной записи:"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Удалить учётную запись"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -65,12 +63,12 @@ msgstr ""
 "Для этой учётной записи отсутствуют службы, которые могут быть настроены. "
 "Для изменения её отображаемого имени нажмите на значок, расположенный выше."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Добавление учётной записи"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -78,13 +76,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Удалить %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Пока не добавлено ни одной учётной записи"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -93,18 +91,18 @@ msgstr ""
 "Для добавления учётной записи нажмите кнопку <interface>Добавить учётную "
 "запись...</interface>"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Добавить учётную запись..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Удалить учётную запись?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -112,7 +110,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Удалить учётную запись «%2», используемую для %1?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -120,7 +118,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Удалить учётную запись «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -128,14 +126,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Удалить учётную запись «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Удалить учётную запись"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -143,7 +134,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Переименовать учётную запись"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -151,64 +142,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Введите новое имя:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Переименовать"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Отсутствует учётная запись с идентификатором %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Отсутствует диспетчер учётных записей."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Отображаемое имя не может быть пустым"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Не удалось загрузить модуль %1. Проверьте правильность установки."
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Отменено пользователем"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "При обработке запроса произошла ошибка: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Не удалось найти учётную"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Не удалось найти учётные данные "
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Не удалось начать проверку подлинности"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Не удалось открыть бумажник"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Удалить учётную запись"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Переименовать"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Не удалось открыть бумажник"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/sk/kaccounts-integration.po 4:24.02.2-1/po/sk/kaccounts-integration.po
--- 4:22.12.3-1/po/sk/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/sk/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -5,7 +5,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2019-11-05 20:12+0100\n"
 "Last-Translator: Matej Mrenica <matejm98mthw@gmail.com>\n"
 "Language-Team: Slovak <kde-i18n-doc@kde.org>\n"
@@ -16,26 +16,24 @@ msgstr ""
 "X-Generator: Lokalize 19.08.2\n"
 "Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, fuzzy, kde-format
 #| msgid "Account Removal"
 msgid "Account Details"
 msgstr "Odstránenie účtu"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, fuzzy, kde-format
 #| msgid "Accounts"
 msgid "%1 account"
 msgstr "Účty"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr ""
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -62,13 +60,13 @@ msgid ""
 "change its display name by clicking the edit icon above."
 msgstr ""
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, fuzzy, kde-format
 #| msgid "ownCloud account Wizard"
 msgid "Add New Account"
 msgstr "Sprievodca účtom ownCloud"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,33 +74,33 @@ msgctxt ""
 msgid "Remove %1"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
 "Click the <interface>Add New Account...</interface> button below to add one"
 msgstr ""
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, fuzzy, kde-format
 #| msgid "ownCloud account Wizard"
 msgid "Add New Account..."
 msgstr "Sprievodca účtom ownCloud"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, fuzzy, kde-format
 #| msgid "Accounts"
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Účty"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, fuzzy, kde-format
 #| msgid ""
 #| "Are you sure that you want to remove the account '%1'? This cannot be "
@@ -113,7 +111,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Určite chcete odstrániť účet '%1'? Toto sa nedá vrátiť späť."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, fuzzy, kde-format
 #| msgid ""
 #| "Are you sure that you want to remove the account '%1'? This cannot be "
@@ -124,7 +122,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Určite chcete odstrániť účet '%1'? Toto sa nedá vrátiť späť."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, fuzzy, kde-format
 #| msgid ""
 #| "Are you sure that you want to remove the account '%1'? This cannot be "
@@ -135,15 +133,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Určite chcete odstrániť účet '%1'? Toto sa nedá vrátiť späť."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, fuzzy, kde-format
-#| msgid "Accounts"
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Účty"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, fuzzy, kde-format
 #| msgid "Accounts"
 msgctxt ""
@@ -152,7 +142,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Účty"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -160,64 +150,58 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr ""
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr ""
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Nemôžem načítať plugin %1, prosím skontrolujte si inštaláciu"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Nastala chyba počas pokusu o spracovanie požiadavky: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr ""
+#, fuzzy
+#~| msgid "Accounts"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Účty"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/sl/kaccounts-integration.po 4:24.02.2-1/po/sl/kaccounts-integration.po
--- 4:22.12.3-1/po/sl/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/sl/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-10-14 22:45+0200\n"
 "Last-Translator: Matjaž Jeran <matjaz.jeran@amis.net>\n"
 "Language-Team: Slovenian <lugos-slo@lugos.si>\n"
@@ -21,24 +21,22 @@ msgstr ""
 "%100==4 ? 3 : 0);\n"
 "X-Generator: Lokalize 20.12.2\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Podrobnosti računa"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 račun"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -46,18 +44,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Spremeni prikazano ime računa"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Uporabi ta račun za"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Odstrani ta račun"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -67,12 +65,12 @@ msgstr ""
 "Za ta račun ni na voljo nastavljivih storitev. Še vedno lahko spremenite "
 "prikazano ime s klikom na zgornjo ikono za urejanje."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Dodaj nov račun"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -80,13 +78,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Odstrani %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Nobenega računa še ni dodanega"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -94,18 +92,18 @@ msgid ""
 msgstr ""
 "Kliknite gumb <interface>Dodaj nov račun...</interface> za dodajanje novega"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Dodaj nov račun..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Odstrani račun?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -113,7 +111,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Ali ste prepričani, da želite odstraniti \"%1\" račun \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -121,7 +119,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Ali ste prepričani, da želite odstraniti račun \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -129,14 +127,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Ali ste prepričani, da želite odstraniti ta račun \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Odstrani račun"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -144,7 +135,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Preimenuj račun"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -152,64 +143,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Vnesite novo ime:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Nastavite ime računa"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Ni mogoče najti računa za ID %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Ni skrbnika računov, to pa ni dobro."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Ime ne more biti prazno"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Ni bilo mogoče naložiti vtičnika %1. Prosim, preverite vašo namestitev"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Preklicano od uporabnika"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Prišlo je do napake med poskusom obdelovanja zahteve: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Ni mogoče najti računa"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Ni mogoče najti poverilnic"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Ni mogoče ustvariti avtorske seje"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Ni mogoče odpreti listnice"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Odstrani račun"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Nastavite ime računa"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Ni mogoče odpreti listnice"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/sr/kaccounts-integration.po 4:24.02.2-1/po/sr/kaccounts-integration.po
--- 4:22.12.3-1/po/sr/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/sr/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -4,7 +4,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2020-04-11 03:03+0200\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2017-10-30 23:08+0100\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -18,74 +18,185 @@ msgstr ""
 "X-Text-Markup: kde4\n"
 "X-Environment: kde\n"
 
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:20
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Account Details"
+msgstr "налози"
+
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
+#, kde-format
+msgid "%1 (%2)"
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "%1 account"
+msgstr "налози"
+
+#: src/kcm/ui/AccountDetails.qml:73
+#, kde-format
+msgctxt ""
+"Button which spawns a dialog allowing the user to change the displayed "
+"account's human-readable name"
+msgid "Change Account Display Name"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
-msgctxt "NAME OF TRANSLATORS"
-msgid "Your names"
+msgctxt "Heading for a list of services available with this account"
+msgid "Use This Account For"
 msgstr ""
 
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
-msgctxt "EMAIL OF TRANSLATORS"
-msgid "Your emails"
+msgid "Remove This Account"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:110
+#, kde-format
+msgctxt "A text shown when an account has no configurable services"
+msgid ""
+"There are no configurable services available for this account. You can still "
+"change its display name by clicking the edit icon above."
 msgstr ""
 
 # >> @title:column
-#: src/kcm/accounts.cpp:32
+#: src/kcm/ui/AvailableAccounts.qml:19
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Add New Account"
+msgstr "налози"
+
+#: src/kcm/ui/main.qml:53
 #, kde-format
-msgid "Accounts"
+msgctxt ""
+"Tooltip for an action which will offer the user to remove the mentioned "
+"account"
+msgid "Remove %1"
+msgstr ""
+
+#: src/kcm/ui/main.qml:70
+#, kde-format
+msgctxt "A text shown when a user has not yet added any accounts"
+msgid "No accounts added yet"
+msgstr ""
+
+#: src/kcm/ui/main.qml:71
+#, kde-kuit-format
+msgctxt "@info"
+msgid ""
+"Click the <interface>Add New Account...</interface> button below to add one"
+msgstr ""
+
+#: src/kcm/ui/main.qml:83
+#, kde-format
+msgid "Add New Account..."
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/RemoveAccountDialog.qml:22
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt "The title for a dialog which lets you remove an account"
+msgid "Remove Account?"
 msgstr "налози"
 
-#: src/kcm/accounts.cpp:34
+#: src/kcm/ui/RemoveAccountDialog.qml:40
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when both provider "
+"name and account name are available"
+msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:42
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the account "
+"name is available"
+msgid "Are you sure you wish to remove the account \"%1\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
-msgid "Sebastian Kügler"
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the "
+"provider name is available"
+msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr ""
 
-#: src/kcm/accounts.cpp:35
+# >> @title:column
+#: src/kcm/ui/RenameAccountDialog.qml:17
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt ""
+"The title for a dialog which lets you set the human-readable name of an "
+"account"
+msgid "Rename Account"
+msgstr "налози"
+
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
-msgid "Dan Leinir Turthra Jensen"
+msgctxt ""
+"Label for the text field used to enter a new human-readable name for an "
+"account"
+msgid "Enter new name:"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:77
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:82
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:87
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:104
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Не могу да учитам прикључак „%1“, проверите инсталацију."
 
-#: src/lib/createaccountjob.cpp:231
+#: src/lib/createaccountjob.cpp:187
+#, kde-format
+msgid "Cancelled by user"
+msgstr ""
+
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Дошло је до грешке при покушају обраде захтева: %1"
 
-#: src/lib/getcredentialsjob.cpp:66
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:81
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:91
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:63
-#, kde-format
-msgid "Can't open wallet"
-msgstr ""
+# >> @title:column
+#, fuzzy
+#~| msgid "Accounts"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "налози"
diff -pruN 4:22.12.3-1/po/sr@ijekavian/kaccounts-integration.po 4:24.02.2-1/po/sr@ijekavian/kaccounts-integration.po
--- 4:22.12.3-1/po/sr@ijekavian/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/sr@ijekavian/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -4,7 +4,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2020-04-11 03:03+0200\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2017-10-30 23:08+0100\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -18,74 +18,185 @@ msgstr ""
 "X-Text-Markup: kde4\n"
 "X-Environment: kde\n"
 
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:20
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Account Details"
+msgstr "налози"
+
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
+#, kde-format
+msgid "%1 (%2)"
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "%1 account"
+msgstr "налози"
+
+#: src/kcm/ui/AccountDetails.qml:73
+#, kde-format
+msgctxt ""
+"Button which spawns a dialog allowing the user to change the displayed "
+"account's human-readable name"
+msgid "Change Account Display Name"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
-msgctxt "NAME OF TRANSLATORS"
-msgid "Your names"
+msgctxt "Heading for a list of services available with this account"
+msgid "Use This Account For"
 msgstr ""
 
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
-msgctxt "EMAIL OF TRANSLATORS"
-msgid "Your emails"
+msgid "Remove This Account"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:110
+#, kde-format
+msgctxt "A text shown when an account has no configurable services"
+msgid ""
+"There are no configurable services available for this account. You can still "
+"change its display name by clicking the edit icon above."
 msgstr ""
 
 # >> @title:column
-#: src/kcm/accounts.cpp:32
+#: src/kcm/ui/AvailableAccounts.qml:19
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Add New Account"
+msgstr "налози"
+
+#: src/kcm/ui/main.qml:53
 #, kde-format
-msgid "Accounts"
+msgctxt ""
+"Tooltip for an action which will offer the user to remove the mentioned "
+"account"
+msgid "Remove %1"
+msgstr ""
+
+#: src/kcm/ui/main.qml:70
+#, kde-format
+msgctxt "A text shown when a user has not yet added any accounts"
+msgid "No accounts added yet"
+msgstr ""
+
+#: src/kcm/ui/main.qml:71
+#, kde-kuit-format
+msgctxt "@info"
+msgid ""
+"Click the <interface>Add New Account...</interface> button below to add one"
+msgstr ""
+
+#: src/kcm/ui/main.qml:83
+#, kde-format
+msgid "Add New Account..."
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/RemoveAccountDialog.qml:22
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt "The title for a dialog which lets you remove an account"
+msgid "Remove Account?"
 msgstr "налози"
 
-#: src/kcm/accounts.cpp:34
+#: src/kcm/ui/RemoveAccountDialog.qml:40
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when both provider "
+"name and account name are available"
+msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:42
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the account "
+"name is available"
+msgid "Are you sure you wish to remove the account \"%1\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
-msgid "Sebastian Kügler"
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the "
+"provider name is available"
+msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr ""
 
-#: src/kcm/accounts.cpp:35
+# >> @title:column
+#: src/kcm/ui/RenameAccountDialog.qml:17
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt ""
+"The title for a dialog which lets you set the human-readable name of an "
+"account"
+msgid "Rename Account"
+msgstr "налози"
+
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
-msgid "Dan Leinir Turthra Jensen"
+msgctxt ""
+"Label for the text field used to enter a new human-readable name for an "
+"account"
+msgid "Enter new name:"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:77
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:82
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:87
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:104
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Не могу да учитам прикључак „%1“, проверите инсталацију."
 
-#: src/lib/createaccountjob.cpp:231
+#: src/lib/createaccountjob.cpp:187
+#, kde-format
+msgid "Cancelled by user"
+msgstr ""
+
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Дошло је до грешке при покушају обраде захтјева: %1"
 
-#: src/lib/getcredentialsjob.cpp:66
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:81
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:91
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:63
-#, kde-format
-msgid "Can't open wallet"
-msgstr ""
+# >> @title:column
+#, fuzzy
+#~| msgid "Accounts"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "налози"
diff -pruN 4:22.12.3-1/po/sr@ijekavianlatin/kaccounts-integration.po 4:24.02.2-1/po/sr@ijekavianlatin/kaccounts-integration.po
--- 4:22.12.3-1/po/sr@ijekavianlatin/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/sr@ijekavianlatin/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -4,7 +4,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2020-04-11 03:03+0200\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2017-10-30 23:08+0100\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -18,74 +18,185 @@ msgstr ""
 "X-Text-Markup: kde4\n"
 "X-Environment: kde\n"
 
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:20
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Account Details"
+msgstr "nalozi"
+
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
+#, kde-format
+msgid "%1 (%2)"
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "%1 account"
+msgstr "nalozi"
+
+#: src/kcm/ui/AccountDetails.qml:73
+#, kde-format
+msgctxt ""
+"Button which spawns a dialog allowing the user to change the displayed "
+"account's human-readable name"
+msgid "Change Account Display Name"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
-msgctxt "NAME OF TRANSLATORS"
-msgid "Your names"
+msgctxt "Heading for a list of services available with this account"
+msgid "Use This Account For"
 msgstr ""
 
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
-msgctxt "EMAIL OF TRANSLATORS"
-msgid "Your emails"
+msgid "Remove This Account"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:110
+#, kde-format
+msgctxt "A text shown when an account has no configurable services"
+msgid ""
+"There are no configurable services available for this account. You can still "
+"change its display name by clicking the edit icon above."
 msgstr ""
 
 # >> @title:column
-#: src/kcm/accounts.cpp:32
+#: src/kcm/ui/AvailableAccounts.qml:19
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Add New Account"
+msgstr "nalozi"
+
+#: src/kcm/ui/main.qml:53
 #, kde-format
-msgid "Accounts"
+msgctxt ""
+"Tooltip for an action which will offer the user to remove the mentioned "
+"account"
+msgid "Remove %1"
+msgstr ""
+
+#: src/kcm/ui/main.qml:70
+#, kde-format
+msgctxt "A text shown when a user has not yet added any accounts"
+msgid "No accounts added yet"
+msgstr ""
+
+#: src/kcm/ui/main.qml:71
+#, kde-kuit-format
+msgctxt "@info"
+msgid ""
+"Click the <interface>Add New Account...</interface> button below to add one"
+msgstr ""
+
+#: src/kcm/ui/main.qml:83
+#, kde-format
+msgid "Add New Account..."
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/RemoveAccountDialog.qml:22
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt "The title for a dialog which lets you remove an account"
+msgid "Remove Account?"
 msgstr "nalozi"
 
-#: src/kcm/accounts.cpp:34
+#: src/kcm/ui/RemoveAccountDialog.qml:40
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when both provider "
+"name and account name are available"
+msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:42
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the account "
+"name is available"
+msgid "Are you sure you wish to remove the account \"%1\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
-msgid "Sebastian Kügler"
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the "
+"provider name is available"
+msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr ""
 
-#: src/kcm/accounts.cpp:35
+# >> @title:column
+#: src/kcm/ui/RenameAccountDialog.qml:17
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt ""
+"The title for a dialog which lets you set the human-readable name of an "
+"account"
+msgid "Rename Account"
+msgstr "nalozi"
+
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
-msgid "Dan Leinir Turthra Jensen"
+msgctxt ""
+"Label for the text field used to enter a new human-readable name for an "
+"account"
+msgid "Enter new name:"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:77
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:82
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:87
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:104
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Ne mogu da učitam priključak „%1“, proverite instalaciju."
 
-#: src/lib/createaccountjob.cpp:231
+#: src/lib/createaccountjob.cpp:187
+#, kde-format
+msgid "Cancelled by user"
+msgstr ""
+
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Došlo je do greške pri pokušaju obrade zahtjeva: %1"
 
-#: src/lib/getcredentialsjob.cpp:66
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:81
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:91
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:63
-#, kde-format
-msgid "Can't open wallet"
-msgstr ""
+# >> @title:column
+#, fuzzy
+#~| msgid "Accounts"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "nalozi"
diff -pruN 4:22.12.3-1/po/sr@latin/kaccounts-integration.po 4:24.02.2-1/po/sr@latin/kaccounts-integration.po
--- 4:22.12.3-1/po/sr@latin/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/sr@latin/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -4,7 +4,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2020-04-11 03:03+0200\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2017-10-30 23:08+0100\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -18,74 +18,185 @@ msgstr ""
 "X-Text-Markup: kde4\n"
 "X-Environment: kde\n"
 
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:20
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Account Details"
+msgstr "nalozi"
+
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
+#, kde-format
+msgid "%1 (%2)"
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "%1 account"
+msgstr "nalozi"
+
+#: src/kcm/ui/AccountDetails.qml:73
+#, kde-format
+msgctxt ""
+"Button which spawns a dialog allowing the user to change the displayed "
+"account's human-readable name"
+msgid "Change Account Display Name"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
-msgctxt "NAME OF TRANSLATORS"
-msgid "Your names"
+msgctxt "Heading for a list of services available with this account"
+msgid "Use This Account For"
 msgstr ""
 
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
-msgctxt "EMAIL OF TRANSLATORS"
-msgid "Your emails"
+msgid "Remove This Account"
+msgstr ""
+
+#: src/kcm/ui/AccountDetails.qml:110
+#, kde-format
+msgctxt "A text shown when an account has no configurable services"
+msgid ""
+"There are no configurable services available for this account. You can still "
+"change its display name by clicking the edit icon above."
 msgstr ""
 
 # >> @title:column
-#: src/kcm/accounts.cpp:32
+#: src/kcm/ui/AvailableAccounts.qml:19
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgid "Add New Account"
+msgstr "nalozi"
+
+#: src/kcm/ui/main.qml:53
 #, kde-format
-msgid "Accounts"
+msgctxt ""
+"Tooltip for an action which will offer the user to remove the mentioned "
+"account"
+msgid "Remove %1"
+msgstr ""
+
+#: src/kcm/ui/main.qml:70
+#, kde-format
+msgctxt "A text shown when a user has not yet added any accounts"
+msgid "No accounts added yet"
+msgstr ""
+
+#: src/kcm/ui/main.qml:71
+#, kde-kuit-format
+msgctxt "@info"
+msgid ""
+"Click the <interface>Add New Account...</interface> button below to add one"
+msgstr ""
+
+#: src/kcm/ui/main.qml:83
+#, kde-format
+msgid "Add New Account..."
+msgstr ""
+
+# >> @title:column
+#: src/kcm/ui/RemoveAccountDialog.qml:22
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt "The title for a dialog which lets you remove an account"
+msgid "Remove Account?"
 msgstr "nalozi"
 
-#: src/kcm/accounts.cpp:34
+#: src/kcm/ui/RemoveAccountDialog.qml:40
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when both provider "
+"name and account name are available"
+msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:42
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the account "
+"name is available"
+msgid "Are you sure you wish to remove the account \"%1\"?"
+msgstr ""
+
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
-msgid "Sebastian Kügler"
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the "
+"provider name is available"
+msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr ""
 
-#: src/kcm/accounts.cpp:35
+# >> @title:column
+#: src/kcm/ui/RenameAccountDialog.qml:17
+#, fuzzy, kde-format
+#| msgid "Accounts"
+msgctxt ""
+"The title for a dialog which lets you set the human-readable name of an "
+"account"
+msgid "Rename Account"
+msgstr "nalozi"
+
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
-msgid "Dan Leinir Turthra Jensen"
+msgctxt ""
+"Label for the text field used to enter a new human-readable name for an "
+"account"
+msgid "Enter new name:"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:77
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:82
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr ""
 
-#: src/lib/changeaccountdisplaynamejob.cpp:87
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr ""
 
-#: src/lib/createaccountjob.cpp:104
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Ne mogu da učitam priključak „%1“, proverite instalaciju."
 
-#: src/lib/createaccountjob.cpp:231
+#: src/lib/createaccountjob.cpp:187
+#, kde-format
+msgid "Cancelled by user"
+msgstr ""
+
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Došlo je do greške pri pokušaju obrade zahteva: %1"
 
-#: src/lib/getcredentialsjob.cpp:66
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:81
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr ""
 
-#: src/lib/getcredentialsjob.cpp:91
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr ""
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:63
-#, kde-format
-msgid "Can't open wallet"
-msgstr ""
+# >> @title:column
+#, fuzzy
+#~| msgid "Accounts"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "nalozi"
diff -pruN 4:22.12.3-1/po/sv/kaccounts-integration.po 4:24.02.2-1/po/sv/kaccounts-integration.po
--- 4:22.12.3-1/po/sv/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/sv/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-03-24 07:31+0100\n"
 "Last-Translator: Stefan Asserhäll <stefan.asserhall@bredband.net>\n"
 "Language-Team: Swedish <kde-i18n-doc@kde.org>\n"
@@ -17,24 +17,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: Lokalize 20.08.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Kontoinformation"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 konto"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -42,18 +40,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Ändra kontots visade namn"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Använd kontot för"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Ta bort kontot"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "fortfarande ändra dess visade namn genom att klicka på redigeringsikonen "
 "ovan."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Lägg till nytt konto"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Ta bort %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Inga konton ännu tillagda"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Klicka på knappen <interface>Lägg till nytt konto...</interface> nedan för "
 "att lägga till ett"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Lägg till nytt konto..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Ta bort konto?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Är du säker på att du vill ta bort kontot \"%1\" \"%2\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Är du säker på att du vill ta bort kontot \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Är du säker på att du vill ta bort det här kontot \"%1\"?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Ta bort konto"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Byt namn på konto"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Ange nytt namn:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Ange kontonamn"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Inget konto hittades med id %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Ingen kontohanterare, det är inte så bra."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Skärmnamnet kan inte vara tomt"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "Kunde inte ladda insticksprogrammet %1. Kontrollera installationen."
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Avbruten av användaren"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Ett fel uppstod när begäran skulle behandlas: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Kunde inte hitta konto"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Kunde inte hitta inloggningsinformation"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Kunde inte skapa auth-session"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Kan inte öppna plånbok"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Ta bort konto"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Ange kontonamn"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Kan inte öppna plånbok"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/ta/kaccounts-integration.po 4:24.02.2-1/po/ta/kaccounts-integration.po
--- 4:22.12.3-1/po/ta/kaccounts-integration.po	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/po/ta/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -0,0 +1,198 @@
+# Copyright (C) 2023 This file is copyright:
+# This file is distributed under the same license as the kaccounts-integration package.
+#
+# SPDX-FileCopyrightText: 2023 Kishore G <kishore96@gmail.com>
+msgid ""
+msgstr ""
+"Project-Id-Version: kaccounts-integration\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
+"PO-Revision-Date: 2023-12-17 17:02+0530\n"
+"Last-Translator: Kishore G <kishore96@gmail.com>\n"
+"Language-Team: Tamil <kde-i18n-doc@kde.org>\n"
+"Language: ta\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=n != 1;\n"
+"X-Generator: Lokalize 23.08.4\n"
+
+#: src/kcm/ui/AccountDetails.qml:20
+#, kde-format
+msgid "Account Details"
+msgstr "கணக்கின் விவரங்கள்"
+
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
+#, kde-format
+msgid "%1 (%2)"
+msgstr "%1 (%2)"
+
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
+#, kde-format
+msgid "%1 account"
+msgstr "%1 கணக்கு"
+
+#: src/kcm/ui/AccountDetails.qml:73
+#, kde-format
+msgctxt ""
+"Button which spawns a dialog allowing the user to change the displayed "
+"account's human-readable name"
+msgid "Change Account Display Name"
+msgstr "கணக்கின் காட்சிப்பெயரை மாற்று"
+
+#: src/kcm/ui/AccountDetails.qml:81
+#, kde-format
+msgctxt "Heading for a list of services available with this account"
+msgid "Use This Account For"
+msgstr "இக்கணக்கை இவற்றிற்கு பயன்படுத்து"
+
+#: src/kcm/ui/AccountDetails.qml:88
+#, kde-format
+msgid "Remove This Account"
+msgstr "இக்கணக்கை நீக்கு"
+
+#: src/kcm/ui/AccountDetails.qml:110
+#, kde-format
+msgctxt "A text shown when an account has no configurable services"
+msgid ""
+"There are no configurable services available for this account. You can still "
+"change its display name by clicking the edit icon above."
+msgstr ""
+"இந்த கணக்கில் அமைக்கக்கூடிய சேவைகள் ஏதுமில்லை. அதன் காட்சிப்பெயரை மேலுள்ள திருத்தல் "
+"சின்னத்தை கிளிக் செய்து அமைக்கலாம்."
+
+#: src/kcm/ui/AvailableAccounts.qml:19
+#, kde-format
+msgid "Add New Account"
+msgstr "புதிய கணக்கை சேர்"
+
+#: src/kcm/ui/main.qml:53
+#, kde-format
+msgctxt ""
+"Tooltip for an action which will offer the user to remove the mentioned "
+"account"
+msgid "Remove %1"
+msgstr "%1 தனை நீக்கு"
+
+#: src/kcm/ui/main.qml:70
+#, kde-format
+msgctxt "A text shown when a user has not yet added any accounts"
+msgid "No accounts added yet"
+msgstr "எந்த கணக்கும் சேர்க்கப்படவில்லை"
+
+#: src/kcm/ui/main.qml:71
+#, kde-kuit-format
+msgctxt "@info"
+msgid ""
+"Click the <interface>Add New Account...</interface> button below to add one"
+msgstr ""
+"புதிய கணக்கை சேர்க்க, கீழுள்ள <interface>புதிய கணக்கை சேர்…</interface> பட்டனை "
+"அழுத்தவும்"
+
+#: src/kcm/ui/main.qml:83
+#, kde-format
+msgid "Add New Account..."
+msgstr "புதிய கணக்கை சேர்..."
+
+#: src/kcm/ui/RemoveAccountDialog.qml:22
+#, kde-format
+msgctxt "The title for a dialog which lets you remove an account"
+msgid "Remove Account?"
+msgstr "கணக்கை நீக்கலாமா?"
+
+#: src/kcm/ui/RemoveAccountDialog.qml:40
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when both provider "
+"name and account name are available"
+msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
+msgstr "\"%2\" எனும் \"%1\" கணக்கை உறுதியாக நீக்கலாமா?"
+
+#: src/kcm/ui/RemoveAccountDialog.qml:42
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the account "
+"name is available"
+msgid "Are you sure you wish to remove the account \"%1\"?"
+msgstr "\"%1\" எனும் கணக்கை உறுதியாக நீக்கலாமா?"
+
+#: src/kcm/ui/RemoveAccountDialog.qml:44
+#, kde-format
+msgctxt ""
+"The text for a dialog which lets you remove an account when only the "
+"provider name is available"
+msgid "Are you sure you wish to remove this \"%1\" account?"
+msgstr "இந்த \"%1\" கணக்கை உறுதியாக நீக்க வேண்டுமா?"
+
+#: src/kcm/ui/RenameAccountDialog.qml:17
+#, kde-format
+msgctxt ""
+"The title for a dialog which lets you set the human-readable name of an "
+"account"
+msgid "Rename Account"
+msgstr "கணக்குக்கு மறுபெயரிடு"
+
+#: src/kcm/ui/RenameAccountDialog.qml:38
+#, kde-format
+msgctxt ""
+"Label for the text field used to enter a new human-readable name for an "
+"account"
+msgid "Enter new name:"
+msgstr "புதிய பெயரை உள்ளிடுக"
+
+#: src/lib/changeaccountdisplaynamejob.cpp:74
+#, kde-format
+msgid "No account found with the ID %1"
+msgstr "%1 எனும் அடையாளத்துடன் எந்த கணக்கும் கண்டுபிடிக்கபடவில்லை"
+
+#: src/lib/changeaccountdisplaynamejob.cpp:79
+#, kde-format
+msgid "No accounts manager, this is not awesome."
+msgstr "கணக்கு மேலாளியைக் கண்டுபிடிக்க முடியவில்லை."
+
+#: src/lib/changeaccountdisplaynamejob.cpp:84
+#, kde-format
+msgid "The display name cannot be empty"
+msgstr "காட்சிப்பெயர் காலியாக இருக்கக்கூடாது"
+
+#: src/lib/createaccountjob.cpp:92
+#, kde-format
+msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
+msgid "Could not load %1 plugin, please check your installation"
+msgstr "%1 செருகுநிரலை ஏற்ற முடியவில்லை, உங்கள் நிறுவலை சரிபாருங்கள்"
+
+#: src/lib/createaccountjob.cpp:187
+#, kde-format
+msgid "Cancelled by user"
+msgstr "பயனர் ரத்துசெய்தார்"
+
+#: src/lib/createaccountjob.cpp:264
+#, kde-format
+msgid "There was an error while trying to process the request: %1"
+msgstr "கோரிக்கையை நிறைவேற்றுவதில் சிக்கல் நேர்ந்தது: %1"
+
+#: src/lib/getcredentialsjob.cpp:56
+#, kde-format
+msgid "Could not find account"
+msgstr "கணக்கைக் கண்டுபிடிக்க முடியவில்லை"
+
+#: src/lib/getcredentialsjob.cpp:71
+#, kde-format
+msgid "Could not find credentials"
+msgstr "சான்றுகளை கண்டுபிடிக்க முடியவில்லை"
+
+#: src/lib/getcredentialsjob.cpp:81
+#, kde-format
+msgid "Could not create auth session"
+msgstr "உறுதிப்பாட்டு அமர்வை உருவாக்க முடியவில்லை"
+
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "கணக்கை நீக்கு"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "கணக்குப்பெயரை அமை"
diff -pruN 4:22.12.3-1/po/tr/kaccounts-integration.po 4:24.02.2-1/po/tr/kaccounts-integration.po
--- 4:22.12.3-1/po/tr/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/tr/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2022-03-26 13:37+0300\n"
 "Last-Translator: Emir SARI <emir_sari@icloud.com>\n"
 "Language-Team: Turkish <kde-l10n-tr@kde.org>\n"
@@ -18,24 +18,22 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=(n > 1);\n"
 "X-Generator: Lokalize 21.12.3\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Hesap Ayrıntıları"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 hesabı"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Hesap Görüntüleme Adını Değiştir"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Bu Hesabı Şunun için Kullan"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Bu Hesabı Kaldır"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -64,12 +62,12 @@ msgstr ""
 "Bu hesap için yapılandırılabilir hizmetler yok. Görüntüleme adını yukarıdaki "
 "düzenle simgesine tıklayarak değiştirebilirsiniz."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Yeni Hesap Ekle"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -77,13 +75,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "%1 Kaldır"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Henüz bir hesap eklenmedi"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -92,18 +90,18 @@ msgstr ""
 "Eklemek için aşağıdaki <interface>Yeni Hesap Ekle...</interface> düğmesine "
 "tıklayın"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Yeni Hesap Ekle..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Hesabı Kaldır?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -111,7 +109,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "\"%1\" \"%2\" hesabını kaldırmak istediğinizden emin misiniz?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -119,7 +117,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "\"%1\" hesabını kaldırmak istediğinizden emin misiniz?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -127,14 +125,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Bu \"%1\" hesabını kaldırmak istediğinizden emin misiniz?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Hesabı Kaldır"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -142,7 +133,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Hesabı Yeniden Adlandır"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -150,64 +141,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Yeni ad girin:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Hesap Adı Ayarlayın"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "%1 kimliği ile bir hesap bulunamadı"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "Hesap yöneticisi yok, bu iyi değil."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Görüntüleme adı boş olamaz"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "%1 eklentisi yüklenemedi, lütfen kurulumunuzu denetleyin"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Kullanıcı tarafından iptal edildi"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "İstek işlenmeye çalışılırken bir hata oluştu: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Hesap bulunamadı"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Oturum açma bilgileri bulunamadı"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Kimlik doğrulama oturumu oluşturulamadı"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Cüzdan açılamıyor"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Hesabı Kaldır"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Hesap Adı Ayarlayın"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Cüzdan açılamıyor"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/uk/kaccounts-integration.po 4:24.02.2-1/po/uk/kaccounts-integration.po
--- 4:22.12.3-1/po/uk/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/uk/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kaccounts-integration\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2021-03-24 08:38+0200\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <kde-i18n-uk@kde.org>\n"
@@ -20,24 +20,22 @@ msgstr ""
 "%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 "X-Generator: Lokalize 20.11.70\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "Параметри рахунка"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "Обліковий запис %1"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -45,18 +43,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "Змінити екранне ім'я облікового запису"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "Використовувати цей обліковий запис для"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "Вилучити цей обліковий запис"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -66,12 +64,12 @@ msgstr ""
 "Для цього облікового запису немає придатних до налаштовування служб. Втім, "
 "ви можете змінити його екранне ім'я натисканням піктограми редагування вище."
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "Додати новий обліковий запис"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -79,13 +77,13 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "Вилучити %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "Жодного облікового запису ще не додано"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
@@ -94,18 +92,18 @@ msgstr ""
 "Натисніть розташовану нижче кнопку <interface>Додати новий обліковий запис…</"
 "interface>, щоб додати його"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "Додати новий обліковий запис…"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "Вилучити обліковий запис?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -113,7 +111,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "Ви справді хочете вилучити обліковий запис «%2» «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -121,7 +119,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "Ви справді хочете вилучити обліковий запис «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -129,14 +127,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "Ви справді хочете вилучити цей обліковий запис «%1»?"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "Вилучити обліковий запис"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -144,7 +135,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "Перейменування облікового запису"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -152,30 +143,22 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "Введіть нову назву:"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "Встановити назву облікового запису"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "Не знайдено облікових записів із ідентифікатором %1"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "На жаль, немає засобу керування обліковими записами."
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "Показане ім'я не може бути порожнім."
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
@@ -183,35 +166,44 @@ msgstr ""
 "Не вдалося завантажити додаток %1. Перевірте, чи правильно встановлено "
 "систему."
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "Скасовано користувачем"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "Під час спроби обробки запиту сталася помилка: %1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "Не вдалося знайти обліковий запис"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "Не вдалося знайти реєстраційні дані"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "Не вдалося створити сеанс розпізнавання"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "Не вдалося відкрити торбинку"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "Вилучити обліковий запис"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "Встановити назву облікового запису"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "Не вдалося відкрити торбинку"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/po/zh_CN/kaccounts-integration.po 4:24.02.2-1/po/zh_CN/kaccounts-integration.po
--- 4:22.12.3-1/po/zh_CN/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/zh_CN/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -2,8 +2,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdeorg\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
-"PO-Revision-Date: 2023-02-24 12:58\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
+"PO-Revision-Date: 2024-03-30 19:38\n"
 "Last-Translator: \n"
 "Language-Team: Chinese Simplified\n"
 "Language: zh_CN\n"
@@ -14,28 +14,26 @@ msgstr ""
 "X-Crowdin-Project: kdeorg\n"
 "X-Crowdin-Project-ID: 269464\n"
 "X-Crowdin-Language: zh-CN\n"
-"X-Crowdin-File: /kf5-stable/messages/kaccounts-integration/kaccounts-"
+"X-Crowdin-File: /kf6-stable/messages/kaccounts-integration/kaccounts-"
 "integration.pot\n"
-"X-Crowdin-File-ID: 3400\n"
+"X-Crowdin-File-ID: 51642\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "账户详细信息"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 账户"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -43,18 +41,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "修改账户显示名称"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "将此账户用于"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "删除此账户"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -63,12 +61,12 @@ msgid ""
 msgstr ""
 "此账户没有可配置的服务。您仍然可以通过点击上面的编辑图标来更改显示名称。"
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "添加新账户"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -76,31 +74,31 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "删除 %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "尚未添加任何账户"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
 "Click the <interface>Add New Account...</interface> button below to add one"
-msgstr "请点击下方的<interface>添加新账户</interface>按钮来添加账户"
+msgstr "请点击下方的<interface>添加新账户…</interface>按钮来添加账户"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "添加新账户..."
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "要删除账户吗？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -108,7 +106,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "您确定要删除“%1”账户“%2”吗？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -116,7 +114,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "您确定要删除账户“%1”吗？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -124,14 +122,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "您确定要移除此“%1”账户吗？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "删除账户"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -139,7 +130,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "账户更名"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -147,61 +138,48 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "输入新名称："
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "设置账户名称"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "未找到 ID 为 %1 的账户"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "没有账户管理器，这可不妙。"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "显示名称不能为空"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "无法加载 %1 插件，请检查您的安装。"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "已被用户取消"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "处理请求时出错：%1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "找不到账号"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "找不到凭据"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "无法创建认证会话"
-
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "无法打开密码库"
diff -pruN 4:22.12.3-1/po/zh_TW/kaccounts-integration.po 4:24.02.2-1/po/zh_TW/kaccounts-integration.po
--- 4:22.12.3-1/po/zh_TW/kaccounts-integration.po	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/po/zh_TW/kaccounts-integration.po	2024-04-08 15:00:12.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2022-09-19 00:44+0000\n"
+"POT-Creation-Date: 2024-03-19 02:29+0000\n"
 "PO-Revision-Date: 2022-06-08 17:09+0900\n"
 "Last-Translator: Kisaragi Hiu <mail@kisaragi-hiu.com>\n"
 "Language-Team: Chinese <kde-i18n-doc@kde.org>\n"
@@ -20,24 +20,22 @@ msgstr ""
 "Plural-Forms: nplurals=1; plural=0;\n"
 "X-Generator: Lokalize 22.04.1\n"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:20
+#: src/kcm/ui/AccountDetails.qml:20
 #, kde-format
 msgid "Account Details"
 msgstr "帳號資訊"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:59
-#: src/kcm/package/contents/ui/main.qml:47
+#: src/kcm/ui/AccountDetails.qml:59 src/kcm/ui/main.qml:40
 #, kde-format
 msgid "%1 (%2)"
 msgstr "%1 (%2)"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:63
-#: src/kcm/package/contents/ui/main.qml:51
+#: src/kcm/ui/AccountDetails.qml:63 src/kcm/ui/main.qml:44
 #, kde-format
 msgid "%1 account"
 msgstr "%1 帳號"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:73
+#: src/kcm/ui/AccountDetails.qml:73
 #, kde-format
 msgctxt ""
 "Button which spawns a dialog allowing the user to change the displayed "
@@ -45,18 +43,18 @@ msgctxt ""
 msgid "Change Account Display Name"
 msgstr "變更帳號顯示名稱"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:81
+#: src/kcm/ui/AccountDetails.qml:81
 #, kde-format
 msgctxt "Heading for a list of services available with this account"
 msgid "Use This Account For"
 msgstr "使用本帳號於"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:88
+#: src/kcm/ui/AccountDetails.qml:88
 #, kde-format
 msgid "Remove This Account"
 msgstr "移除此帳號"
 
-#: src/kcm/package/contents/ui/AccountDetails.qml:110
+#: src/kcm/ui/AccountDetails.qml:110
 #, kde-format
 msgctxt "A text shown when an account has no configurable services"
 msgid ""
@@ -65,12 +63,12 @@ msgid ""
 msgstr ""
 "這個帳號沒有可調整設定的服務。您仍然可以點擊上方編輯按鈕來變更它的顯示名稱。"
 
-#: src/kcm/package/contents/ui/AvailableAccounts.qml:19
+#: src/kcm/ui/AvailableAccounts.qml:19
 #, kde-format
 msgid "Add New Account"
 msgstr "新增帳號"
 
-#: src/kcm/package/contents/ui/main.qml:58
+#: src/kcm/ui/main.qml:53
 #, kde-format
 msgctxt ""
 "Tooltip for an action which will offer the user to remove the mentioned "
@@ -78,31 +76,31 @@ msgctxt ""
 msgid "Remove %1"
 msgstr "移除 %1"
 
-#: src/kcm/package/contents/ui/main.qml:75
+#: src/kcm/ui/main.qml:70
 #, kde-format
 msgctxt "A text shown when a user has not yet added any accounts"
 msgid "No accounts added yet"
 msgstr "尚未新增任何帳號"
 
-#: src/kcm/package/contents/ui/main.qml:76
+#: src/kcm/ui/main.qml:71
 #, kde-kuit-format
 msgctxt "@info"
 msgid ""
 "Click the <interface>Add New Account...</interface> button below to add one"
 msgstr "點擊下方的 <interface>新增帳號…</interface> 按鈕來新增一個"
 
-#: src/kcm/package/contents/ui/main.qml:88
+#: src/kcm/ui/main.qml:83
 #, kde-format
 msgid "Add New Account..."
 msgstr "新增帳號…"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:20
+#: src/kcm/ui/RemoveAccountDialog.qml:22
 #, kde-format
 msgctxt "The title for a dialog which lets you remove an account"
 msgid "Remove Account?"
 msgstr "移除帳號？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:23
+#: src/kcm/ui/RemoveAccountDialog.qml:40
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when both provider "
@@ -110,7 +108,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the \"%1\" account \"%2\"?"
 msgstr "您確定要移除 \"%1\" 帳號 \"%2\"？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:25
+#: src/kcm/ui/RemoveAccountDialog.qml:42
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the account "
@@ -118,7 +116,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove the account \"%1\"?"
 msgstr "您確定要移除帳號 \"%1\"？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:27
+#: src/kcm/ui/RemoveAccountDialog.qml:44
 #, kde-format
 msgctxt ""
 "The text for a dialog which lets you remove an account when only the "
@@ -126,14 +124,7 @@ msgctxt ""
 msgid "Are you sure you wish to remove this \"%1\" account?"
 msgstr "您確定要移除此 \"%1\" 帳號？"
 
-#: src/kcm/package/contents/ui/RemoveAccountDialog.qml:32
-#, kde-format
-msgctxt ""
-"The label for a button which will cause the removal of a specified account"
-msgid "Remove Account"
-msgstr "移除帳號"
-
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:17
+#: src/kcm/ui/RenameAccountDialog.qml:17
 #, kde-format
 msgctxt ""
 "The title for a dialog which lets you set the human-readable name of an "
@@ -141,7 +132,7 @@ msgctxt ""
 msgid "Rename Account"
 msgstr "變更帳號名稱"
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:31
+#: src/kcm/ui/RenameAccountDialog.qml:38
 #, kde-format
 msgctxt ""
 "Label for the text field used to enter a new human-readable name for an "
@@ -149,64 +140,65 @@ msgctxt ""
 msgid "Enter new name:"
 msgstr "輸入新名稱："
 
-#: src/kcm/package/contents/ui/RenameAccountDialog.qml:37
-#, kde-format
-msgctxt ""
-"Text of a button which will cause the human-readable name of an account to "
-"be set to a text specified by the user"
-msgid "Set Account Name"
-msgstr "設定帳號名稱"
-
-#: src/lib/changeaccountdisplaynamejob.cpp:71
+#: src/lib/changeaccountdisplaynamejob.cpp:74
 #, kde-format
 msgid "No account found with the ID %1"
 msgstr "找不到 ID %1 的帳號"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:76
+#: src/lib/changeaccountdisplaynamejob.cpp:79
 #, kde-format
 msgid "No accounts manager, this is not awesome."
 msgstr "沒有帳號管理員，這不優喔。"
 
-#: src/lib/changeaccountdisplaynamejob.cpp:81
+#: src/lib/changeaccountdisplaynamejob.cpp:84
 #, kde-format
 msgid "The display name cannot be empty"
 msgstr "顯示名稱不能空白"
 
-#: src/lib/createaccountjob.cpp:89
+#: src/lib/createaccountjob.cpp:92
 #, kde-format
 msgctxt "The %1 is for plugin name, eg. Could not load UI plugin"
 msgid "Could not load %1 plugin, please check your installation"
 msgstr "無法載入 %1 外掛程式。請檢查您的安裝。"
 
-#: src/lib/createaccountjob.cpp:147
+#: src/lib/createaccountjob.cpp:187
 #, kde-format
 msgid "Cancelled by user"
 msgstr "使用者已取消"
 
-#: src/lib/createaccountjob.cpp:224
+#: src/lib/createaccountjob.cpp:264
 #, kde-format
 msgid "There was an error while trying to process the request: %1"
 msgstr "試著進行此要求時發生錯誤：%1"
 
-#: src/lib/getcredentialsjob.cpp:53
+#: src/lib/getcredentialsjob.cpp:56
 #, kde-format
 msgid "Could not find account"
 msgstr "找不到帳號"
 
-#: src/lib/getcredentialsjob.cpp:68
+#: src/lib/getcredentialsjob.cpp:71
 #, kde-format
 msgid "Could not find credentials"
 msgstr "找不到憑證"
 
-#: src/lib/getcredentialsjob.cpp:78
+#: src/lib/getcredentialsjob.cpp:81
 #, kde-format
 msgid "Could not create auth session"
 msgstr "無法建立驗證階段"
 
-#: src/plugins/kio-webdav/removenetattachjob.cpp:51
-#, kde-format
-msgid "Can't open wallet"
-msgstr "無法開啟錢包"
+#~ msgctxt ""
+#~ "The label for a button which will cause the removal of a specified account"
+#~ msgid "Remove Account"
+#~ msgstr "移除帳號"
+
+#~ msgctxt ""
+#~ "Text of a button which will cause the human-readable name of an account "
+#~ "to be set to a text specified by the user"
+#~ msgid "Set Account Name"
+#~ msgstr "設定帳號名稱"
+
+#~ msgid "Can't open wallet"
+#~ msgstr "無法開啟錢包"
 
 #~ msgctxt "NAME OF TRANSLATORS"
 #~ msgid "Your names"
diff -pruN 4:22.12.3-1/src/CMakeLists.txt 4:24.02.2-1/src/CMakeLists.txt
--- 4:22.12.3-1/src/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -1,7 +1,10 @@
 add_definitions(-DTRANSLATION_DOMAIN="kaccounts-integration")
 
-add_subdirectory(kded)
 add_subdirectory(lib)
 add_subdirectory(declarative)
-add_subdirectory(kcm)
-add_subdirectory(plugins)
+
+if(NOT KF6_COMPAT_BUILD)
+    add_subdirectory(plugins)
+    add_subdirectory(kcm)
+    add_subdirectory(kded)
+endif()
diff -pruN 4:22.12.3-1/src/declarative/CMakeLists.txt 4:24.02.2-1/src/declarative/CMakeLists.txt
--- 4:22.12.3-1/src/declarative/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/declarative/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -2,8 +2,8 @@ ecm_add_qml_module(kaccountsdeclarativep
 
 target_sources(kaccountsdeclarativeplugin PRIVATE kaccountsdeclarativeplugin.cpp kaccountsdeclarativeplugin.h)
 
-target_link_libraries(kaccountsdeclarativeplugin Qt::Qml
-                                                 KF5::I18n
+target_link_libraries(kaccountsdeclarativeplugin PRIVATE Qt::Qml
+                                                 KF${QT_MAJOR_VERSION}::I18n
                                                  kaccounts
                                                  )
 
diff -pruN 4:22.12.3-1/src/declarative/kaccountsdeclarativeplugin.cpp 4:24.02.2-1/src/declarative/kaccountsdeclarativeplugin.cpp
--- 4:22.12.3-1/src/declarative/kaccountsdeclarativeplugin.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/declarative/kaccountsdeclarativeplugin.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -22,19 +22,19 @@ void KAccountsDeclarativePlugin::registe
 {
     // Version 1.0
     // Consider this registration deprecated - use the one named ...Job below instead
-    qmlRegisterType<CreateAccountJob>(uri, 1, 0, "CreateAccount");
+    qmlRegisterType<KAccounts::CreateAccountJob>(uri, 1, 0, "CreateAccount");
 
     // Version 1.1
     // Consider this registration deprecated - use the one named ...Job below instead
-    qmlRegisterType<AccountServiceToggleJob>(uri, 1, 1, "AccountServiceToggle");
+    qmlRegisterType<KAccounts::AccountServiceToggleJob>(uri, 1, 1, "AccountServiceToggle");
 
     // Version 1.2
-    qmlRegisterType<AccountsModel>(uri, 1, 2, "AccountsModel");
-    qmlRegisterType<ProvidersModel>(uri, 1, 2, "ProvidersModel");
-    qmlRegisterType<ServicesModel>(uri, 1, 2, "ServicesModel");
+    qmlRegisterType<KAccounts::AccountsModel>(uri, 1, 2, "AccountsModel");
+    qmlRegisterType<KAccounts::ProvidersModel>(uri, 1, 2, "ProvidersModel");
+    qmlRegisterType<KAccounts::ServicesModel>(uri, 1, 2, "ServicesModel");
 
-    qmlRegisterType<AccountServiceToggleJob>(uri, 1, 2, "AccountServiceToggleJob");
-    qmlRegisterType<ChangeAccountDisplayNameJob>(uri, 1, 2, "ChangeAccountDisplayNameJob");
-    qmlRegisterType<CreateAccountJob>(uri, 1, 2, "CreateAccountJob");
-    qmlRegisterType<RemoveAccountJob>(uri, 1, 2, "RemoveAccountJob");
+    qmlRegisterType<KAccounts::AccountServiceToggleJob>(uri, 1, 2, "AccountServiceToggleJob");
+    qmlRegisterType<KAccounts::ChangeAccountDisplayNameJob>(uri, 1, 2, "ChangeAccountDisplayNameJob");
+    qmlRegisterType<KAccounts::CreateAccountJob>(uri, 1, 2, "CreateAccountJob");
+    qmlRegisterType<KAccounts::RemoveAccountJob>(uri, 1, 2, "RemoveAccountJob");
 }
diff -pruN 4:22.12.3-1/src/kcm/CMakeLists.txt 4:24.02.2-1/src/kcm/CMakeLists.txt
--- 4:22.12.3-1/src/kcm/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -1,12 +1,8 @@
-add_library(kcm_kaccounts MODULE accounts.cpp accounts.h)
+kcmutils_add_qml_kcm(kcm_kaccounts SOURCES accounts.cpp accounts.h)
 
-target_link_libraries(kcm_kaccounts
+target_link_libraries(kcm_kaccounts PRIVATE
     Qt::Core
-    KF5::CoreAddons
-    KF5::I18n
-    KF5::QuickAddons
-    )
-
-install(TARGETS kcm_kaccounts DESTINATION ${KDE_INSTALL_PLUGINDIR}/plasma/kcms/systemsettings)
-
-kpackage_install_package(package kcm_kaccounts kcms)
+    KF6::CoreAddons
+    KF6::I18n
+    KF6::KCMUtils
+)
diff -pruN 4:22.12.3-1/src/kcm/accounts.cpp 4:24.02.2-1/src/kcm/accounts.cpp
--- 4:22.12.3-1/src/kcm/accounts.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/accounts.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -12,9 +12,17 @@
 K_PLUGIN_CLASS_WITH_JSON(AccountsSettings, "kcm_kaccounts.json")
 
 AccountsSettings::AccountsSettings(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : KQuickAddons::ConfigModule(parent, data, args)
+#else
+    : KQuickConfigModule(parent, data)
+#endif
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setButtons(KQuickAddons::ConfigModule::NoAdditionalButton);
+#else
+    setButtons(KQuickConfigModule::NoAdditionalButton);
+#endif
 }
 
 #include "accounts.moc"
diff -pruN 4:22.12.3-1/src/kcm/accounts.h 4:24.02.2-1/src/kcm/accounts.h
--- 4:22.12.3-1/src/kcm/accounts.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/accounts.h	2024-04-08 15:00:12.000000000 +0000
@@ -7,11 +7,20 @@
 #ifndef ACCOUNTSSETTINGS_H
 #define ACCOUNTSSETTINGS_H
 
-#include <KQuickAddons/ConfigModule>
 #include <QObject>
 #include <QVariant>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <KQuickAddons/ConfigModule>
+#else
+#include <KQuickConfigModule>
+#endif
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class AccountsSettings : public KQuickAddons::ConfigModule
+#else
+class AccountsSettings : public KQuickConfigModule
+#endif
 {
     Q_OBJECT
 
diff -pruN 4:22.12.3-1/src/kcm/kcm_kaccounts.json 4:24.02.2-1/src/kcm/kcm_kaccounts.json
--- 4:22.12.3-1/src/kcm/kcm_kaccounts.json	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/kcm_kaccounts.json	2024-04-08 15:00:12.000000000 +0000
@@ -2,7 +2,8 @@
     "KPlugin": {
         "BugReportUrl": "https://bugs.kde.org/enter_bug.cgi?product=systemsettings&component=kcm_kaccounts",
         "Description": "Configure your internet accounts such as Google, Live, Owncloud",
-        "Description[ar]": "اضبط حساباتك على الإنترنت كغوغل، لايڤ وسحابتك \"Owncloud\"",
+        "Description[ar]": "اضبط حساباتك على الإنترنت كغوغل، لايف وسحابتك \"Owncloud\"",
+        "Description[az]": "Google, Live, Owncloud kimi kimi hesabları ayarla",
         "Description[bg]": "Настройване на интернет акаунти като Google, Live, Owncloud",
         "Description[ca@valencia]": "Configura els vostres comptes d'Internet com Google, Live, Owncloud",
         "Description[ca]": "Configura els vostres comptes d'Internet com Google, Live, Owncloud",
@@ -10,20 +11,26 @@
         "Description[de]": "Verwalten Sie Ihre Internet-Zugänge wie Google, Live und Owncloud",
         "Description[el]": "Διαμόρφωση διαδικτυακών λογαριασμών όπως Google, Live, Owncloud",
         "Description[en_GB]": "Configure your internet accounts such as Google, Live, Owncloud",
+        "Description[eo]": "Agordu viajn interretajn kontojn kiel ekz. Google, Live, Owncloud",
         "Description[es]": "Configurar sus cuentas de internet, como Google, Live, Owncloud",
         "Description[eu]": "Konfiguratu zure interneteko kontuak, Google, Live, Owncloud eta halakoak",
+        "Description[fi]": "Aseta internettilit kuten Google, Live, Owncloud",
         "Description[fr]": "Configurer vos comptes Internet, comme par exemple sur Google, Live, OwnCloud",
+        "Description[gl]": "Configurar as túas contas de Internet como a de Google, Live ou Owncloud.",
+        "Description[hu]": "Internetes fiókok, például Google, Live, Owncloud beállítása",
         "Description[ia]": "Configura tu contos de internet tall como Google, Live, OwnCloud",
         "Description[id]": "Atur akun internet Anda seperti Google, Live, Owncloud",
         "Description[it]": "Configura i tuoi account internet come Google, Live, ownCloud",
         "Description[ja]": "Google, Live, Owncloud などのアカウントを設定",
         "Description[ka]": "დაამატეთ თქვენი ინტერნეტ-ანგარიშები. მაგ: Google, Live, Owncloud",
         "Description[ko]": "Google, Live, Owncloud 등 인터넷 계정 설정",
+        "Description[lt]": "Konfigūruoti internetines paskyras, tokias kaip „Google“, „Live“, „Owncloud“",
         "Description[nl]": "Stel uw internetaccounts in zoals Google, Live, Owncloud",
         "Description[nn]": "Set opp nettkontoar, for eksempel for Google, Live eller ownCloud",
         "Description[pl]": "Tutaj ustaw swoje konto na: Google, Live, Owncloud",
         "Description[pt]": "Configura as as suas contas na Internet, como o Google, Live, Owncloud",
         "Description[pt_BR]": "Configure suas contas na Internet, como Google, Live, Owncloud",
+        "Description[ro]": "Configurați conturile Internet cum sunt Google, Live, Owncloud",
         "Description[ru]": "Настройка учётных записей Google, Facebook, Jabber и других",
         "Description[sl]": "Konfigurirajte vašem spletne račune kot so Google, Live, Owncloud",
         "Description[sv]": "Anpassa Internetkonton såsom Google, Live, Owncloud",
@@ -41,30 +48,38 @@
         "Icon": "preferences-online-accounts",
         "Name": "Online Accounts",
         "Name[ar]": "حسابات الإنترنت",
+        "Name[az]": "Onlayn istifadəçi hesabları",
         "Name[bg]": "Онлайн акаунти",
         "Name[ca@valencia]": "Comptes en línia",
         "Name[ca]": "Comptes en línia",
         "Name[cs]": "Účty online",
         "Name[de]": "Online-Zugänge",
-        "Name[el]": "Επιγραμμικοί λογαριασμοί",
+        "Name[el]": "Διαδικτυακοί λογαριασμοί",
         "Name[en_GB]": "Online Accounts",
+        "Name[eo]": "Enretaj kontoj",
         "Name[es]": "Cuentas en línea",
         "Name[eu]": "Lerroko kontuak",
+        "Name[fi]": "Verkkotilit",
         "Name[fr]": "Comptes en ligne",
+        "Name[gl]": "Contas de Internet",
+        "Name[hu]": "Online fiókok",
         "Name[ia]": "Contos in linea",
         "Name[id]": "Akun Daring",
         "Name[it]": "Account in linea",
         "Name[ja]": "オンラインアカウント",
         "Name[ka]": "ონლაინ ანგარიშები",
         "Name[ko]": "온라인 계정",
+        "Name[lt]": "Internetinės paskyros",
         "Name[nl]": "Online accounts",
         "Name[nn]": "Nett­kontoar",
         "Name[pl]": "Konta sieciowe",
         "Name[pt]": "Contas 'Online'",
         "Name[pt_BR]": "Contas online",
+        "Name[ro]": "Conturi online",
         "Name[ru]": "Учётные записи в Интернете",
         "Name[sl]": "Spletni računi",
         "Name[sv]": "Nätkonton",
+        "Name[ta]": "இணைய கணக்குகள்",
         "Name[tr]": "Çevrimiçi Hesaplar",
         "Name[uk]": "Облікові записи в інтернеті",
         "Name[x-test]": "xxOnline Accountsxx",
@@ -105,6 +120,6 @@
     "X-KDE-Keywords[uk]": "network,google,live,owncloud,sync,online,accounts,synchronization,opendesktop,nextcloud,youtube,drive,hangouts,gmail,google calendar,мережа,гугл,лайв,аунклауд,синхронізація,синхронізувати,інтернет,обліковий запис,записи,оупендесктоп,некстклауд,ютюб,диск,хенгаутс,жмейл,календар гугл",
     "X-KDE-Keywords[x-test]": "xxnetworkxx,xxgooglexx,xxlivexx,xxowncloudxx,xxsyncxx,xxonlinexx,xxaccountsxx,xxsynchronizationxx,xxopendesktopxx,xxnextcloudxx,xxyoutubexx,xxdrivexx,xxhangoutsxx,xxgmailxx,xxgoogle calendarxx",
     "X-KDE-Keywords[zh_CN]": "network,google,live,owncloud,sync,online,accounts,synchronization,opendesktop,nextcloud,youtube,drive,hangouts,gmail,google calendar,网络,同步,在线服务,账号,网络驱动器,网盘,日历,邮件",
-    "X-KDE-ParentApp": "kcontrol",
-    "X-KDE-System-Settings-Parent-Category": "personalization"
+    "X-KDE-System-Settings-Parent-Category": "network",
+    "X-KDE-Weight": 20
 }
diff -pruN 4:22.12.3-1/src/kcm/package/contents/ui/AccountDetails.qml 4:24.02.2-1/src/kcm/package/contents/ui/AccountDetails.qml
--- 4:22.12.3-1/src/kcm/package/contents/ui/AccountDetails.qml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/package/contents/ui/AccountDetails.qml	1970-01-01 00:00:00.000000000 +0000
@@ -1,130 +0,0 @@
-/*
- *   SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
- *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
- *
- *   SPDX-License-Identifier: LGPL-2.0-or-later
- */
-
-import QtQuick 2.12
-import QtQuick.Controls 2.12 as Controls
-import QtQuick.Layouts 1.12
-
-import org.kde.kirigami 2.14 as Kirigami
-import org.kde.kcm 1.2
-
-import org.kde.kaccounts 1.2 as KAccounts
-
-ScrollViewKCM {
-    id: component;
-
-    title: i18nd("kaccounts-integration", "Account Details")
-
-    property alias model: servicesList.model
-
-    RemoveAccountDialog {
-        id: accountRemover
-        parent: component
-        accountId: servicesList.model.accountId
-        displayName: servicesList.model.accountDisplayName
-        providerName: servicesList.model.accountProviderName
-        onAccountRemoved: kcm.pop()
-    }
-
-    RenameAccountDialog {
-        id: accountRenamer
-        parent: component
-        accountId: servicesList.model.accountId
-        currentDisplayName: servicesList.model.accountDisplayName
-    }
-
-    Component {
-        id: serviceToggleJob
-        KAccounts.AccountServiceToggleJob { }
-    }
-
-    header: ColumnLayout {
-        RowLayout {
-            Layout.fillWidth: true
-            Layout.margins: Kirigami.Units.smallSpacing
-            spacing: Kirigami.Units.smallSpacing
-            Kirigami.Icon {
-                source: model.accountIconName
-                Layout.preferredWidth: Kirigami.Units.iconSizes.large
-                Layout.preferredHeight: Kirigami.Units.iconSizes.large
-            }
-            Controls.Label {
-                Layout.fillWidth: true
-                text: {
-                    if (model.accountDisplayName.length > 0 && model.accountProviderName.length > 0) {
-                        return i18nd("kaccounts-integration", "%1 (%2)", model.accountDisplayName, model.accountProviderName)
-                    } else if (model.accountDisplayName.length > 0) {
-                        return model.accountDisplayName
-                    } else {
-                        return i18nd("kaccounts-integration", "%1 account", model.accountProviderName)
-                    }
-                }
-            }
-            Controls.ToolButton {
-                icon.name: "edit-entry"
-                Layout.preferredHeight: Kirigami.Units.iconSizes.large
-                Layout.preferredWidth: Kirigami.Units.iconSizes.large
-                onClicked: accountRenamer.open();
-                Controls.ToolTip {
-                    text: i18ndc("kaccounts-integration", "Button which spawns a dialog allowing the user to change the displayed account's human-readable name", "Change Account Display Name")
-                }
-            }
-        }
-        Kirigami.Heading {
-            leftPadding: Kirigami.Units.smallSpacing
-            visible: servicesList.count > 0
-            level: 3
-            text: i18ndc("kaccounts-integration", "Heading for a list of services available with this account", "Use This Account For")
-        }
-    }
-
-    footer: RowLayout {
-        Controls.Button {
-            Layout.alignment: Qt.AlignRight
-            text: i18nd("kaccounts-integration", "Remove This Account")
-            icon.name: "edit-delete-remove"
-            onClicked: accountRemover.open();
-        }
-    }
-
-    view: ListView {
-        id: servicesList
-
-        clip: true
-
-        ColumnLayout {
-            anchors.fill: parent
-            spacing: Kirigami.Units.smallSpacing
-            Controls.Label {
-                visible: servicesList.count === 0
-                Layout.fillWidth: true
-                Layout.minimumHeight: component.height / 3
-                enabled: false
-                verticalAlignment: Text.AlignVCenter
-                horizontalAlignment: Text.AlignHCenter
-                wrapMode: Text.Wrap
-                text: i18ndc("kaccounts-integration", "A text shown when an account has no configurable services", "There are no configurable services available for this account. You can still change its display name by clicking the edit icon above.")
-            }
-        }
-
-        delegate: Kirigami.CheckableListItem {
-            icon: undefined
-            text: model.displayName
-            subtitle: model.description
-
-            checked: model.enabled
-
-            action: Controls.Action {
-                onTriggered: {
-                    checked = !checked;
-                    const job = serviceToggleJob.createObject(component, { "accountId": servicesList.model.accountId, "serviceId": model.name, "serviceEnabled": !model.enabled });
-                    job.start();
-                }
-            }
-        }
-    }
-}
diff -pruN 4:22.12.3-1/src/kcm/package/contents/ui/AvailableAccounts.qml 4:24.02.2-1/src/kcm/package/contents/ui/AvailableAccounts.qml
--- 4:22.12.3-1/src/kcm/package/contents/ui/AvailableAccounts.qml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/package/contents/ui/AvailableAccounts.qml	1970-01-01 00:00:00.000000000 +0000
@@ -1,125 +0,0 @@
-/*
- *   SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
- *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
- *
- *   SPDX-License-Identifier: LGPL-2.0-or-later
- */
-
-import QtQuick 2.12
-import QtQuick.Controls 2.12 as Controls
-import QtQuick.Layouts 1.12
-
-import org.kde.kirigami 2.4 as Kirigami
-import org.kde.kcm 1.2
-
-import org.kde.kaccounts 1.2 as KAccounts
-
-ScrollViewKCM {
-    id: root
-    title: i18nd("kaccounts-integration", "Add New Account")
-
-    header: Kirigami.InlineMessage {
-        id: errorMessage
-        type: Kirigami.MessageType.Error
-        showCloseButton: true
-        visible: false
-    }
-
-    view: ListView {
-
-        id: accountListView
-        clip: true
-        currentIndex: -1
-
-        model: KAccounts.ProvidersModel {}
-        delegate: Kirigami.AbstractListItem {
-            id: accountDelegate
-            width: ListView.view.width
-            enabled: model.supportsMultipleAccounts === true || model.accountsCount === 0
-
-            contentItem: RowLayout {
-                implicitWidth: accountDelegate.ListView.view.width
-                implicitHeight: Kirigami.Units.iconSizes.large + Kirigami.Units.smallSpacing * 2
-                spacing: Kirigami.Units.smallSpacing
-                Kirigami.Icon {
-                    source: model.iconName
-                    Layout.preferredWidth: Kirigami.Units.iconSizes.large
-                    Layout.preferredHeight: Kirigami.Units.iconSizes.large
-                    Item {
-                        visible: model.accountsCount > 0
-                        anchors {
-                            bottom: parent.bottom
-                            right: parent.right
-                        }
-                        height: parent.height / 3
-                        width: height
-                        Rectangle {
-                            anchors.fill: parent
-                            radius: height / 2
-                            color: Kirigami.Theme.highlightColor
-                            border {
-                                width: 1
-                                color: Kirigami.Theme.highlightedTextColor
-                            }
-                        }
-                        Controls.Label {
-                            anchors.fill: parent
-                            horizontalAlignment: Text.AlignHCenter
-                            verticalAlignment: Text.AlignVCenter
-                            color: Kirigami.Theme.highlightedTextColor
-                            text: model.accountsCount
-                        }
-                    }
-                }
-
-                ColumnLayout {
-                    spacing: 0
-                    Layout.fillWidth: true
-                    Layout.alignment: Qt.AlignVCenter
-
-                    Controls.Label {
-                        Layout.fillWidth: true
-                        text: model.displayName
-                        color: accountDelegate.pressed || accountDelegate.highlighted ? accountDelegate.activeTextColor : accountDelegate.textColor
-                        elide: Text.ElideRight
-                    }
-
-                    Controls.Label {
-                        Layout.fillWidth: true
-                        text: model.description
-                        color: accountDelegate.pressed || accountDelegate.highlighted ? accountDelegate.activeTextColor : accountDelegate.textColor
-                        elide: Text.ElideRight
-                        font: Kirigami.Theme.smallFont
-                        opacity: 0.7
-                        visible: text.length > 0
-                    }
-                }
-            }
-            onClicked: {
-                var job = jobComponent.createObject(root, { "providerName": model.name })
-                job.start()
-                accountListView.currentIndex = -1
-            }
-        }
-    }
-
-    Component {
-        id: jobComponent
-        KAccounts.CreateAccountJob {
-            onFinished: {
-                // Don't close when there is an error to show an error message
-                if (error == 0) {
-                    kcm.pop()
-                } else {
-
-                    if (error === 1) { // KJob::KilledJobError, cancelled by user
-                        return
-                    }
-
-                    errorMessage.text = errorText
-                    errorMessage.visible = true
-                }
-            }
-        }
-    }
-}
diff -pruN 4:22.12.3-1/src/kcm/package/contents/ui/MessageBoxSheet.qml 4:24.02.2-1/src/kcm/package/contents/ui/MessageBoxSheet.qml
--- 4:22.12.3-1/src/kcm/package/contents/ui/MessageBoxSheet.qml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/package/contents/ui/MessageBoxSheet.qml	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-/*
- *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
- *
- *   SPDX-License-Identifier: LGPL-2.0-or-later
- */
-
-import QtQuick 2.12
-import QtQuick.Controls 2.12 as QtControls
-import QtQuick.Layouts 1.12 as QtLayouts
-
-import org.kde.kirigami 2.7 as Kirigami
-
-Kirigami.OverlaySheet {
-    id: component
-
-    property alias title: headerLabel.text
-    property alias text: messageLabel.text
-    property list<QtObject> actions
-
-    showCloseButton: true
-    header: Kirigami.Heading {
-        id: headerLabel
-        QtLayouts.Layout.fillWidth: true
-        elide: Text.ElideRight
-    }
-    contentItem: QtControls.Label {
-        id: messageLabel
-        QtLayouts.Layout.preferredWidth: Kirigami.Units.gridUnit * 10
-        QtLayouts.Layout.margins: Kirigami.Units.largeSpacing
-        wrapMode: Text.Wrap
-    }
-    footer: QtLayouts.RowLayout {
-        Item { QtLayouts.Layout.fillWidth: true }
-        Repeater {
-            model: component.actions;
-            QtControls.Button {
-                action: modelData
-                Connections {
-                    target: action
-                    function onTriggered() { component.close(); }
-                }
-            }
-        }
-    }
-}
diff -pruN 4:22.12.3-1/src/kcm/package/contents/ui/RemoveAccountDialog.qml 4:24.02.2-1/src/kcm/package/contents/ui/RemoveAccountDialog.qml
--- 4:22.12.3-1/src/kcm/package/contents/ui/RemoveAccountDialog.qml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/package/contents/ui/RemoveAccountDialog.qml	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-/*
- *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
- *
- *   SPDX-License-Identifier: LGPL-2.0-or-later
- */
-
-import QtQuick 2.12
-import QtQuick.Layouts 1.12
-
-import org.kde.kirigami 2.7 as Kirigami
-
-import org.kde.kaccounts 1.2 as KAccounts
-
-MessageBoxSheet {
-    id: component
-    property int accountId
-    property string displayName
-    property string providerName
-    signal accountRemoved()
-    title: i18ndc("kaccounts-integration", "The title for a dialog which lets you remove an account", "Remove Account?")
-    text: {
-        if (displayName.length > 0 && providerName.length > 0) {
-            return i18ndc("kaccounts-integration", "The text for a dialog which lets you remove an account when both provider name and account name are available", "Are you sure you wish to remove the \"%1\" account \"%2\"?", providerName, displayName)
-        } else if (displayName.length > 0) {
-            return i18ndc("kaccounts-integration", "The text for a dialog which lets you remove an account when only the account name is available", "Are you sure you wish to remove the account \"%1\"?", displayName)
-        } else {
-            return i18ndc("kaccounts-integration", "The text for a dialog which lets you remove an account when only the provider name is available", "Are you sure you wish to remove this \"%1\" account?", providerName)
-        }
-    }
-    actions: [
-        Kirigami.Action {
-            text: i18ndc("kaccounts-integration", "The label for a button which will cause the removal of a specified account", "Remove Account")
-            onTriggered: {
-                var job = accountRemovalJob.createObject(component, { "accountId": component.accountId });
-                job.start();
-            }
-            Component {
-                id: accountRemovalJob
-                KAccounts.RemoveAccountJob {
-                    onFinished: component.accountRemoved()
-                }
-            }
-        }
-    ]
-}
diff -pruN 4:22.12.3-1/src/kcm/package/contents/ui/RenameAccountDialog.qml 4:24.02.2-1/src/kcm/package/contents/ui/RenameAccountDialog.qml
--- 4:22.12.3-1/src/kcm/package/contents/ui/RenameAccountDialog.qml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/package/contents/ui/RenameAccountDialog.qml	1970-01-01 00:00:00.000000000 +0000
@@ -1,50 +0,0 @@
-/*
- *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
- *
- *   SPDX-License-Identifier: LGPL-2.0-or-later
- */
-
-import QtQuick 2.12
-import QtQuick.Controls 2.12 as Controls
-import QtQuick.Layouts 1.12
-
-import org.kde.kirigami 2.7 as Kirigami
-
-import org.kde.kaccounts 1.2 as KAccounts
-
-MessageBoxSheet {
-    id: component
-    title: i18ndc("kaccounts-integration", "The title for a dialog which lets you set the human-readable name of an account", "Rename Account")
-    property int accountId
-    property string currentDisplayName
-    signal accountRenamed()
-    onSheetOpenChanged: {
-        if (sheetOpen === true) {
-            newAccountDisplayName.text = currentDisplayName;
-        }
-    }
-    contentItem: Kirigami.FormLayout {
-        Layout.preferredWidth: Kirigami.Units.gridUnit * 10
-        Layout.margins: Kirigami.Units.largeSpacing
-        Controls.TextField {
-            id: newAccountDisplayName
-            Kirigami.FormData.label: i18ndc("kaccounts-integration", "Label for the text field used to enter a new human-readable name for an account", "Enter new name:")
-        }
-    }
-    actions: [
-        Kirigami.Action {
-            enabled: newAccountDisplayName.text.length > 0 && newAccountDisplayName.text !== component.currentDisplayName
-            text: i18ndc("kaccounts-integration", "Text of a button which will cause the human-readable name of an account to be set to a text specified by the user", "Set Account Name")
-            onTriggered: {
-                var job = accountDisplayNameJob.createObject(component, { "accountId": component.accountId, "displayName": newAccountDisplayName.text })
-                job.start();
-            }
-            Component {
-                id: accountDisplayNameJob
-                KAccounts.ChangeAccountDisplayNameJob {
-                    onFinished: component.accountRenamed()
-                }
-            }
-        }
-    ]
-}
diff -pruN 4:22.12.3-1/src/kcm/package/contents/ui/main.qml 4:24.02.2-1/src/kcm/package/contents/ui/main.qml
--- 4:22.12.3-1/src/kcm/package/contents/ui/main.qml	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kcm/package/contents/ui/main.qml	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-/*
- *   SPDX-FileCopyrightText: 2015 Martin Klapetek <mklapetek@kde.org>
- *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
- *
- *   SPDX-License-Identifier: LGPL-2.0-or-later
- */
-
-import QtQuick 2.12
-import QtQuick.Controls 2.12 as Controls
-import QtQuick.Layouts 1.12
-
-import org.kde.kirigami 2.12 as Kirigami
-import org.kde.kcm 1.2
-
-import org.kde.kaccounts 1.2 as KAccounts
-
-ScrollViewKCM {
-    id: kaccountsRoot
-
-    implicitHeight: Kirigami.Units.gridUnit * 28
-    implicitWidth: Kirigami.Units.gridUnit * 28
-
-    // Existing accounts
-    view: ListView {
-
-        clip: true
-
-        model: KAccounts.AccountsModel { }
-
-        delegate: Kirigami.SwipeListItem {
-            id: accountDelegate
-            width: ListView.view.width
-
-            contentItem: RowLayout {
-                implicitWidth: accountDelegate.ListView.view.width
-                implicitHeight: Kirigami.Units.iconSizes.large + Kirigami.Units.smallSpacing * 2
-                spacing: Kirigami.Units.smallSpacing
-                Kirigami.Icon {
-                    source: model.iconName
-                    Layout.preferredWidth: Kirigami.Units.iconSizes.large
-                    Layout.preferredHeight: Kirigami.Units.iconSizes.large
-                }
-                Controls.Label {
-                    Layout.fillWidth: true
-                    text: {
-                        if (model.displayName.length > 0 && model.providerName.length > 0) {
-                            return i18nd("kaccounts-integration", "%1 (%2)", model.displayName, model.providerDisplayName)
-                        } else if (model.displayName.length > 0) {
-                            return model.displayName
-                        } else {
-                            return i18nd("kaccounts-integration", "%1 account", model.providerName)
-                        }
-                    }
-                }
-            }
-            actions: [
-                Kirigami.Action {
-                    text: i18ndc("kaccounts-integration", "Tooltip for an action which will offer the user to remove the mentioned account", "Remove %1", accountDelegate.contentItem.text)
-                    iconName: "edit-delete-remove"
-                    onTriggered: {
-                        accountRemover.accountId = model.id;
-                        accountRemover.displayName = model.displayName;
-                        accountRemover.providerName = model.providerName;
-                        accountRemover.open();
-                    }
-                }
-            ]
-            onClicked: kcm.push("AccountDetails.qml", {model: model.services})
-        }
-
-        Kirigami.PlaceholderMessage {
-            visible: view.count === 0
-            anchors.centerIn: parent
-            width: parent.width - (Kirigami.Units.largeSpacing * 4)
-            text: i18ndc("kaccounts-integration", "A text shown when a user has not yet added any accounts", "No accounts added yet")
-            explanation: xi18ndc("kaccounts-integration", "@info", "Click the <interface>Add New Account...</interface> button below to add one")
-        }
-    }
-
-    RemoveAccountDialog {
-        id: accountRemover
-        parent: kaccountsRoot
-    }
-
-    footer: RowLayout {
-        Controls.Button {
-            Layout.alignment: Qt.AlignRight
-            text: i18nd("kaccounts-integration", "Add New Account...")
-            icon.name: "contact-new"
-            onClicked: kcm.push("AvailableAccounts.qml")
-        }
-    }
-}
diff -pruN 4:22.12.3-1/src/kcm/ui/AccountDetails.qml 4:24.02.2-1/src/kcm/ui/AccountDetails.qml
--- 4:22.12.3-1/src/kcm/ui/AccountDetails.qml	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/src/kcm/ui/AccountDetails.qml	2024-04-08 15:00:12.000000000 +0000
@@ -0,0 +1,130 @@
+/*
+ *   SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
+ *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
+ *
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
+ */
+
+import QtQuick
+import QtQuick.Controls as Controls
+import QtQuick.Layouts
+
+import org.kde.kirigami as Kirigami
+import org.kde.kcmutils as KCM
+
+import org.kde.kaccounts as KAccounts
+
+KCM.ScrollViewKCM {
+    id: component;
+
+    title: i18nd("kaccounts-integration", "Account Details")
+
+    property alias model: servicesList.model
+
+    RemoveAccountDialog {
+        id: accountRemover
+        parent: component
+        accountId: servicesList.model.accountId
+        displayName: servicesList.model.accountDisplayName
+        providerName: servicesList.model.accountProviderName
+        onAccountRemoved: kcm.pop()
+    }
+
+    RenameAccountDialog {
+        id: accountRenamer
+        parent: component
+        accountId: servicesList.model.accountId
+        currentDisplayName: servicesList.model.accountDisplayName
+    }
+
+    Component {
+        id: serviceToggleJob
+        KAccounts.AccountServiceToggleJob { }
+    }
+
+    header: ColumnLayout {
+        RowLayout {
+            Layout.fillWidth: true
+            Layout.margins: Kirigami.Units.smallSpacing
+            spacing: Kirigami.Units.smallSpacing
+            Kirigami.Icon {
+                source: model.accountIconName
+                Layout.preferredWidth: Kirigami.Units.iconSizes.large
+                Layout.preferredHeight: Kirigami.Units.iconSizes.large
+            }
+            Controls.Label {
+                Layout.fillWidth: true
+                text: {
+                    if (model.accountDisplayName.length > 0 && model.accountProviderName.length > 0) {
+                        return i18nd("kaccounts-integration", "%1 (%2)", model.accountDisplayName, model.accountProviderName)
+                    } else if (model.accountDisplayName.length > 0) {
+                        return model.accountDisplayName
+                    } else {
+                        return i18nd("kaccounts-integration", "%1 account", model.accountProviderName)
+                    }
+                }
+            }
+            Controls.ToolButton {
+                icon.name: "edit-entry"
+                Layout.preferredHeight: Kirigami.Units.iconSizes.large
+                Layout.preferredWidth: Kirigami.Units.iconSizes.large
+                onClicked: accountRenamer.open();
+                Controls.ToolTip {
+                    text: i18ndc("kaccounts-integration", "Button which spawns a dialog allowing the user to change the displayed account's human-readable name", "Change Account Display Name")
+                }
+            }
+        }
+        Kirigami.Heading {
+            leftPadding: Kirigami.Units.smallSpacing
+            visible: servicesList.count > 0
+            level: 3
+            text: i18ndc("kaccounts-integration", "Heading for a list of services available with this account", "Use This Account For")
+        }
+    }
+
+    footer: RowLayout {
+        Controls.Button {
+            Layout.alignment: Qt.AlignRight
+            text: i18nd("kaccounts-integration", "Remove This Account")
+            icon.name: "edit-delete-remove"
+            onClicked: accountRemover.open();
+        }
+    }
+
+    view: ListView {
+        id: servicesList
+
+        clip: true
+
+        ColumnLayout {
+            anchors.fill: parent
+            spacing: Kirigami.Units.smallSpacing
+            Controls.Label {
+                visible: servicesList.count === 0
+                Layout.fillWidth: true
+                Layout.minimumHeight: component.height / 3
+                enabled: false
+                verticalAlignment: Text.AlignVCenter
+                horizontalAlignment: Text.AlignHCenter
+                wrapMode: Text.Wrap
+                text: i18ndc("kaccounts-integration", "A text shown when an account has no configurable services", "There are no configurable services available for this account. You can still change its display name by clicking the edit icon above.")
+            }
+        }
+
+        delegate: Kirigami.CheckSubtitleDelegate {
+            width: ListView.view.width
+            text: model.displayName
+            checked: model.enabled
+            subtitle: model.description
+            icon.width: 0
+
+            action: Controls.Action {
+                onTriggered: {
+                    checked = !checked;
+                    const job = serviceToggleJob.createObject(component, { "accountId": servicesList.model.accountId, "serviceId": model.name, "serviceEnabled": !model.enabled });
+                    job.start();
+                }
+            }
+        }
+    }
+}
diff -pruN 4:22.12.3-1/src/kcm/ui/AvailableAccounts.qml 4:24.02.2-1/src/kcm/ui/AvailableAccounts.qml
--- 4:22.12.3-1/src/kcm/ui/AvailableAccounts.qml	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/src/kcm/ui/AvailableAccounts.qml	2024-04-08 15:00:12.000000000 +0000
@@ -0,0 +1,70 @@
+/*
+ *   SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
+ *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
+ *
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
+ */
+
+import QtQuick
+import QtQuick.Controls as Controls
+import QtQuick.Layouts
+
+import org.kde.kirigami as Kirigami
+import org.kde.kcmutils as KCM
+
+import org.kde.kaccounts as KAccounts
+
+KCM.ScrollViewKCM {
+    id: root
+    title: i18nd("kaccounts-integration", "Add New Account")
+
+    header: Kirigami.InlineMessage {
+        id: errorMessage
+        type: Kirigami.MessageType.Error
+        showCloseButton: true
+        visible: false
+    }
+
+    view: ListView {
+
+        id: accountListView
+        clip: true
+
+        model: KAccounts.ProvidersModel {}
+
+        delegate: Kirigami.SubtitleDelegate {
+            width: ListView.view.width
+
+            icon.name: model.iconName
+            text: model.displayName
+            subtitle: model.description
+            enabled: model.supportsMultipleAccounts === true || model.accountsCount === 0
+
+            onClicked: {
+                var job = jobComponent.createObject(root, { "providerName": model.name })
+                job.start()
+                accountListView.currentIndex = -1
+            }
+        }
+    }
+
+    Component {
+        id: jobComponent
+        KAccounts.CreateAccountJob {
+            onFinished: {
+                // Don't close when there is an error to show an error message
+                if (error == 0) {
+                    kcm.pop()
+                } else {
+
+                    if (error === 1) { // KJob::KilledJobError, cancelled by user
+                        return
+                    }
+
+                    errorMessage.text = errorText
+                    errorMessage.visible = true
+                }
+            }
+        }
+    }
+}
diff -pruN 4:22.12.3-1/src/kcm/ui/RemoveAccountDialog.qml 4:24.02.2-1/src/kcm/ui/RemoveAccountDialog.qml
--- 4:22.12.3-1/src/kcm/ui/RemoveAccountDialog.qml	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/src/kcm/ui/RemoveAccountDialog.qml	2024-04-08 15:00:12.000000000 +0000
@@ -0,0 +1,47 @@
+/*
+ *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
+ *
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
+ */
+
+import QtQuick
+import QtQuick.Layouts
+import QtQuick.Controls as QQC2
+
+import org.kde.kirigami as Kirigami
+
+import org.kde.kaccounts as KAccounts
+
+Kirigami.PromptDialog {
+    id: component
+    property int accountId
+    property string displayName
+    property string providerName
+    signal accountRemoved()
+
+    title: i18ndc("kaccounts-integration", "The title for a dialog which lets you remove an account", "Remove Account?")
+
+    padding: Kirigami.Units.largeSpacing
+    standardButtons: Kirigami.Dialog.Ok | Kirigami.Dialog.Cancel
+
+    onAccepted: {
+        var job = accountRemovalJob.createObject(component, { "accountId": component.accountId });
+        job.start();
+    }
+
+    property var accountRemovalJob: Component {
+        KAccounts.RemoveAccountJob {
+            onFinished: component.accountRemoved()
+        }
+    }
+
+    subtitle: {
+        if (displayName.length > 0 && providerName.length > 0) {
+            return i18ndc("kaccounts-integration", "The text for a dialog which lets you remove an account when both provider name and account name are available", "Are you sure you wish to remove the \"%1\" account \"%2\"?", providerName, displayName)
+        } else if (displayName.length > 0) {
+            return i18ndc("kaccounts-integration", "The text for a dialog which lets you remove an account when only the account name is available", "Are you sure you wish to remove the account \"%1\"?", displayName)
+        } else {
+            return i18ndc("kaccounts-integration", "The text for a dialog which lets you remove an account when only the provider name is available", "Are you sure you wish to remove this \"%1\" account?", providerName)
+        }
+    }
+}
diff -pruN 4:22.12.3-1/src/kcm/ui/RenameAccountDialog.qml 4:24.02.2-1/src/kcm/ui/RenameAccountDialog.qml
--- 4:22.12.3-1/src/kcm/ui/RenameAccountDialog.qml	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/src/kcm/ui/RenameAccountDialog.qml	2024-04-08 15:00:12.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
+ *
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
+ */
+
+import QtQuick
+import QtQuick.Controls as Controls
+import QtQuick.Layouts
+
+import org.kde.kirigami as Kirigami
+
+import org.kde.kaccounts as KAccounts
+
+Kirigami.PromptDialog {
+    id: component
+    title: i18ndc("kaccounts-integration", "The title for a dialog which lets you set the human-readable name of an account", "Rename Account")
+    property int accountId
+    property string currentDisplayName
+    signal accountRenamed()
+    onVisibleChanged: {
+        if (visible === true) {
+            newAccountDisplayName.text = currentDisplayName;
+        }
+    }
+
+    padding: Kirigami.Units.largeSpacing
+    standardButtons: Kirigami.Dialog.Ok | Kirigami.Dialog.Cancel
+
+    onAccepted: {
+        var job = accountDisplayNameJob.createObject(component, { "accountId": component.accountId, "displayName": newAccountDisplayName.text })
+        job.start();
+    }
+
+    Kirigami.FormLayout {
+        Controls.TextField {
+            id: newAccountDisplayName
+            Kirigami.FormData.label: i18ndc("kaccounts-integration", "Label for the text field used to enter a new human-readable name for an account", "Enter new name:")
+        }
+    }
+    property var accountDisplayNameJob: Component {
+        KAccounts.ChangeAccountDisplayNameJob {
+            onFinished: component.accountRenamed()
+        }
+    }
+}
diff -pruN 4:22.12.3-1/src/kcm/ui/main.qml 4:24.02.2-1/src/kcm/ui/main.qml
--- 4:22.12.3-1/src/kcm/ui/main.qml	1970-01-01 00:00:00.000000000 +0000
+++ 4:24.02.2-1/src/kcm/ui/main.qml	2024-04-08 15:00:12.000000000 +0000
@@ -0,0 +1,88 @@
+/*
+ *   SPDX-FileCopyrightText: 2015 Martin Klapetek <mklapetek@kde.org>
+ *   SPDX-FileCopyrightText: 2020 Dan Leinir Turthra Jensen <admin@leinir.dk>
+ *
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
+ */
+
+import QtQuick
+import QtQuick.Controls as Controls
+import QtQuick.Layouts
+
+import org.kde.kirigami as Kirigami
+import org.kde.kcmutils as KCM
+
+import org.kde.kaccounts as KAccounts
+
+KCM.ScrollViewKCM {
+    id: kaccountsRoot
+
+    implicitHeight: Kirigami.Units.gridUnit * 28
+    implicitWidth: Kirigami.Units.gridUnit * 28
+
+    // Existing accounts
+    view: ListView {
+
+        clip: true
+
+        model: KAccounts.AccountsModel { }
+
+        delegate: Kirigami.SwipeListItem {
+            id: delegate
+            width: ListView.view.width
+
+            contentItem: Kirigami.IconTitleSubtitle {
+                Layout.fillWidth: true
+
+                icon.name: model.iconName
+                title: {
+                    if (model.displayName.length > 0 && model.providerName.length > 0) {
+                        return i18nd("kaccounts-integration", "%1 (%2)", model.displayName, model.providerDisplayName)
+                    } else if (model.displayName.length > 0) {
+                        return model.displayName
+                    } else {
+                        return i18nd("kaccounts-integration", "%1 account", model.providerName)
+                    }
+                }
+                selected: delegate.highlighted
+                font: delegate.font
+            }
+
+            actions: [
+                Kirigami.Action {
+                    text: i18ndc("kaccounts-integration", "Tooltip for an action which will offer the user to remove the mentioned account", "Remove %1", delegate.contentItem.text)
+                    icon.name: "edit-delete-remove"
+                    onTriggered: {
+                        accountRemover.accountId = model.id;
+                        accountRemover.displayName = model.displayName;
+                        accountRemover.providerName = model.providerName;
+                        accountRemover.open();
+                    }
+                }
+            ]
+            onClicked: kcm.push("AccountDetails.qml", {model: model.services})
+        }
+
+        Kirigami.PlaceholderMessage {
+            visible: view.count === 0
+            anchors.centerIn: parent
+            width: parent.width - (Kirigami.Units.largeSpacing * 4)
+            text: i18ndc("kaccounts-integration", "A text shown when a user has not yet added any accounts", "No accounts added yet")
+            explanation: xi18ndc("kaccounts-integration", "@info", "Click the <interface>Add New Account...</interface> button below to add one")
+        }
+    }
+
+    RemoveAccountDialog {
+        id: accountRemover
+        parent: kaccountsRoot
+    }
+
+    footer: RowLayout {
+        Controls.Button {
+            Layout.alignment: Qt.AlignRight
+            text: i18nd("kaccounts-integration", "Add New Account...")
+            icon.name: "contact-new"
+            onClicked: kcm.push("AvailableAccounts.qml")
+        }
+    }
+}
diff -pruN 4:22.12.3-1/src/kded/CMakeLists.txt 4:24.02.2-1/src/kded/CMakeLists.txt
--- 4:22.12.3-1/src/kded/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kded/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -1,11 +1,11 @@
 kcoreaddons_add_plugin(
     kded_accounts
     SOURCES kded_accounts.cpp kded_accounts.h
-    INSTALL_NAMESPACE "kf5/kded"
+    INSTALL_NAMESPACE "kf${QT_MAJOR_VERSION}/kded"
 )
 
 target_link_libraries(kded_accounts
     Qt::Core
-    KF5::DBusAddons
+    KF${QT_MAJOR_VERSION}::DBusAddons
     kaccounts
 )
diff -pruN 4:22.12.3-1/src/kded/kded_accounts.cpp 4:24.02.2-1/src/kded/kded_accounts.cpp
--- 4:22.12.3-1/src/kded/kded_accounts.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kded/kded_accounts.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -36,7 +36,7 @@ KDEDAccounts::KDEDAccounts(QObject *pare
             continue;
         }
 
-        const auto result = KPluginFactory::instantiatePlugin<KAccountsDPlugin>(metadata, this, {});
+        const auto result = KPluginFactory::instantiatePlugin<KAccounts::KAccountsDPlugin>(metadata, this, {});
 
         if (!result) {
             qDebug() << "Error loading plugin" << metadata.name() << result.errorString;
@@ -82,7 +82,7 @@ void KDEDAccounts::accountCreated(const
     const Accounts::Account *acc = KAccounts::accountsManager()->account(id);
     const Accounts::ServiceList services = acc->enabledServices();
 
-    for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
+    for (KAccounts::KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
         plugin->onAccountCreated(id, services);
     }
 }
@@ -91,7 +91,7 @@ void KDEDAccounts::accountRemoved(const
 {
     qDebug() << id;
 
-    for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
+    for (KAccounts::KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
         plugin->onAccountRemoved(id);
     }
 }
@@ -108,11 +108,11 @@ void KDEDAccounts::enabledChanged(const
 
     const Accounts::Service service = KAccounts::accountsManager()->service(serviceName);
     if (!enabled) {
-        for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
+        for (KAccounts::KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
             plugin->onServiceDisabled(accId, service);
         }
     } else {
-        for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
+        for (KAccounts::KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
             plugin->onServiceEnabled(accId, service);
         }
     }
diff -pruN 4:22.12.3-1/src/kded/kded_accounts.h 4:24.02.2-1/src/kded/kded_accounts.h
--- 4:22.12.3-1/src/kded/kded_accounts.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kded/kded_accounts.h	2024-04-08 15:00:12.000000000 +0000
@@ -11,7 +11,10 @@
 
 #include <Accounts/Account>
 
+namespace KAccounts
+{
 class KAccountsDPlugin;
+};
 
 class KDEDAccounts : public KDEDModule
 {
@@ -31,7 +34,7 @@ public Q_SLOTS:
 private:
     void monitorAccount(const Accounts::AccountId id);
 
-    QList<KAccountsDPlugin *> m_plugins;
+    QList<KAccounts::KAccountsDPlugin *> m_plugins;
 };
 
 #endif /*ACCOUNTS_DAEMON_H*/
diff -pruN 4:22.12.3-1/src/kded/kded_accounts.json 4:24.02.2-1/src/kded/kded_accounts.json
--- 4:22.12.3-1/src/kded/kded_accounts.json	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/kded/kded_accounts.json	2024-04-08 15:00:12.000000000 +0000
@@ -11,6 +11,7 @@
         "Description[de]": "Zugangsverwaltung",
         "Description[el]": "Διαχείριση λογαριασμών",
         "Description[en_GB]": "Accounts management",
+        "Description[eo]": "Mastrumado de kontoj",
         "Description[es]": "Gestión de cuentas",
         "Description[et]": "Kontohaldus",
         "Description[eu]": "Kontu kudeaketa",
@@ -36,6 +37,7 @@
         "Description[sk]": "Správa účtov",
         "Description[sl]": "Upravljanje računov",
         "Description[sv]": "Kontohantering",
+        "Description[ta]": "கணக்கு மேலாண்மை",
         "Description[tr]": "Hesaplar yönetimi",
         "Description[uk]": "Керування обліковими записами",
         "Description[x-test]": "xxAccounts managementxx",
@@ -52,6 +54,7 @@
         "Name[de]": "Zugänge",
         "Name[el]": "Λογαριασμοί",
         "Name[en_GB]": "Accounts",
+        "Name[eo]": "Kontoj",
         "Name[es]": "Cuentas",
         "Name[et]": "Kontod",
         "Name[eu]": "Kontuak",
@@ -77,6 +80,7 @@
         "Name[sk]": "Účty",
         "Name[sl]": "Accounts",
         "Name[sv]": "Konton",
+        "Name[ta]": "கணக்குகள்",
         "Name[tr]": "Hesaplar",
         "Name[uk]": "Облікові записи",
         "Name[x-test]": "xxAccountsxx",
diff -pruN 4:22.12.3-1/src/lib/CMakeLists.txt 4:24.02.2-1/src/lib/CMakeLists.txt
--- 4:22.12.3-1/src/lib/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -1,9 +1,15 @@
-set(CMAKECONFIG_INSTALL_DIR "${KDE_INSTALL_CMAKEPACKAGEDIR}/KAccounts")
+if(QT_MAJOR_VERSION STREQUAL "5")
+  set(KACCOUNTS_SUFFIX "")
+else()
+  set(KACCOUNTS_SUFFIX "6")
+endif()
+
+set(CMAKECONFIG_INSTALL_DIR "${KDE_INSTALL_CMAKEPACKAGEDIR}/KAccounts${KACCOUNTS_SUFFIX}")
 
 ecm_setup_version(${KACCOUNTS_VERSION}
   VARIABLE_PREFIX KACCOUNTS
   VERSION_HEADER "${CMAKE_CURRENT_BINARY_DIR}/kaccounts_version.h"
-  PACKAGE_VERSION_FILE "${CMAKE_CURRENT_BINARY_DIR}/KAccountsConfigVersion.cmake"
+  PACKAGE_VERSION_FILE "${CMAKE_CURRENT_BINARY_DIR}/KAccounts${KACCOUNTS_SUFFIX}ConfigVersion.cmake"
   SOVERSION ${KACCOUNTS_SOVERSION})
 
 set (kaccountslib_SRCS
@@ -36,22 +42,43 @@ set (kaccountslib_SRCS
      removeaccountjob.h
 )
 
-ecm_generate_headers(kaccountslib_HEADERS
-  HEADER_NAMES
-  AccountsModel
-  Core
-  KAccountsUiPlugin
-  KAccountsDPlugin
-  ProvidersModel
-  ServicesModel
-
-  AccountServiceToggleJob
-  ChangeAccountDisplayNameJob
-  CreateAccountJob
-  GetCredentialsJob
-  RemoveAccountJob
-  REQUIRED_HEADERS kaccountslib_HEADERS
-)
+# For the Qt5 build keep the old header layout for compatibility
+if(QT_MAJOR_VERSION STREQUAL "5")
+  ecm_generate_headers(kaccountslib_HEADERS
+    HEADER_NAMES
+    AccountsModel
+    Core
+    KAccountsUiPlugin
+    KAccountsDPlugin
+    ProvidersModel
+    ServicesModel
+
+    AccountServiceToggleJob
+    ChangeAccountDisplayNameJob
+    CreateAccountJob
+    GetCredentialsJob
+    RemoveAccountJob
+    REQUIRED_HEADERS kaccountslib_HEADERS
+  )
+else()
+  ecm_generate_headers(kaccountslib_CamelCase_HEADERS
+    HEADER_NAMES
+    AccountsModel
+    Core
+    KAccountsUiPlugin
+    KAccountsDPlugin
+    ProvidersModel
+    ServicesModel
+
+    AccountServiceToggleJob
+    ChangeAccountDisplayNameJob
+    CreateAccountJob
+    GetCredentialsJob
+    RemoveAccountJob
+    PREFIX KAccounts
+    REQUIRED_HEADERS kaccountslib_HEADERS
+  )
+endif()
 
 add_library(kaccounts ${kaccountslib_SRCS})
 
@@ -64,8 +91,8 @@ target_compile_definitions(kaccounts
 generate_export_header(kaccounts BASE_NAME kaccounts)
 target_link_libraries (kaccounts
     PUBLIC
-        KF5::CoreAddons
-        KF5::I18n
+        KF${QT_MAJOR_VERSION}::CoreAddons
+        KF${QT_MAJOR_VERSION}::I18n
         ${ACCOUNTSQT_LIBRARIES}
         Qt::Xml
         Qt::Gui
@@ -73,33 +100,60 @@ target_link_libraries (kaccounts
         ${SIGNONQT_LIBRARIES}
 )
 
-target_include_directories(kaccounts INTERFACE "$<INSTALL_INTERFACE:${KDE_INSTALL_INCLUDEDIR}/KAccounts>" PUBLIC "${ACCOUNTSQT_INCLUDE_DIRS}" PRIVATE "${SIGNONQT_INCLUDE_DIRS}")
+target_include_directories(kaccounts
+    INTERFACE "$<INSTALL_INTERFACE:${KDE_INSTALL_INCLUDEDIR}/KAccounts${KACCOUNTS_SUFFIX}>"
+)
+
+target_include_directories(kaccounts SYSTEM
+    PUBLIC "${ACCOUNTSQT_INCLUDE_DIRS}"
+    PRIVATE "${SIGNONQT_INCLUDE_DIRS}"
+)
 set_target_properties(kaccounts PROPERTIES VERSION   ${KACCOUNTS_VERSION}
                                            SOVERSION ${KACCOUNTS_SOVERSION}
-                                           EXPORT_NAME KAccounts
+                                           EXPORT_NAME KAccounts${KACCOUNTS_SUFFIX}
+                                           LIBRARY_OUTPUT_NAME kaccounts${KACCOUNTS_SUFFIX}
 )
 
 configure_package_config_file(
   "${CMAKE_CURRENT_SOURCE_DIR}/KAccountsConfig.cmake.in"
-  "${CMAKE_CURRENT_BINARY_DIR}/KAccountsConfig.cmake"
+  "${CMAKE_CURRENT_BINARY_DIR}/KAccounts${KACCOUNTS_SUFFIX}Config.cmake"
   INSTALL_DESTINATION  ${CMAKECONFIG_INSTALL_DIR}
 )
 
 install(FILES
   "KAccountsMacros.cmake"
-  "${CMAKE_CURRENT_BINARY_DIR}/KAccountsConfig.cmake"
-  "${CMAKE_CURRENT_BINARY_DIR}/KAccountsConfigVersion.cmake"
+  "${CMAKE_CURRENT_BINARY_DIR}/KAccounts${KACCOUNTS_SUFFIX}Config.cmake"
+  "${CMAKE_CURRENT_BINARY_DIR}/KAccounts${KACCOUNTS_SUFFIX}ConfigVersion.cmake"
   DESTINATION "${CMAKECONFIG_INSTALL_DIR}"
   COMPONENT Devel
 )
 
-install(TARGETS kaccounts EXPORT KAccountsTargets ${KDE_INSTALL_TARGETS_DEFAULT_ARGS})
+install(TARGETS kaccounts EXPORT KAccounts${KACCOUNTS_SUFFIX}Targets ${KDE_INSTALL_TARGETS_DEFAULT_ARGS})
 
-install(EXPORT KAccountsTargets DESTINATION "${CMAKECONFIG_INSTALL_DIR}" FILE KAccountsTargets.cmake ) #NAMESPACE KF5::
+install(EXPORT KAccounts${KACCOUNTS_SUFFIX}Targets DESTINATION "${CMAKECONFIG_INSTALL_DIR}" FILE KAccounts${KACCOUNTS_SUFFIX}Targets.cmake ) #NAMESPACE KF${QT_MAJOR_VERSION}::
 
-install (FILES
+if(QT_MAJOR_VERSION STREQUAL "5")
+  install (FILES
         ${CMAKE_CURRENT_BINARY_DIR}/kaccounts_export.h
         ${kaccountslib_HEADERS}
         ${CMAKE_CURRENT_BINARY_DIR}/kaccounts_version.h
         DESTINATION ${KDE_INSTALL_INCLUDEDIR}/KAccounts COMPONENT Devel
-)
+  )
+
+else()
+  install (FILES
+          ${CMAKE_CURRENT_BINARY_DIR}/kaccounts_export.h
+          ${CMAKE_CURRENT_BINARY_DIR}/kaccounts_version.h
+          DESTINATION ${KDE_INSTALL_INCLUDEDIR}/KAccounts${KACCOUNTS_SUFFIX} COMPONENT Devel
+  )
+
+  install (FILES
+          ${kaccountslib_HEADERS}
+          DESTINATION ${KDE_INSTALL_INCLUDEDIR}/KAccounts${KACCOUNTS_SUFFIX}/kaccounts COMPONENT Devel
+  )
+
+  install (FILES
+          ${kaccountslib_CamelCase_HEADERS}
+          DESTINATION ${KDE_INSTALL_INCLUDEDIR}/KAccounts${KACCOUNTS_SUFFIX}/KAccounts COMPONENT Devel
+  )
+endif()
diff -pruN 4:22.12.3-1/src/lib/KAccountsConfig.cmake.in 4:24.02.2-1/src/lib/KAccountsConfig.cmake.in
--- 4:22.12.3-1/src/lib/KAccountsConfig.cmake.in	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/KAccountsConfig.cmake.in	2024-04-08 15:00:12.000000000 +0000
@@ -2,12 +2,12 @@
 
 include(CMakeFindDependencyMacro)
 
-find_dependency(Qt5Widgets @QT_REQUIRED_VERSION@)
-find_dependency(KF5CoreAddons @KF5_MIN_VERSION@)
-find_dependency(AccountsQt5 @ACCOUNTSQT_DEP_VERSION@)
-find_dependency(SignOnQt5 @SIGNONQT_DEP_VERSION@)
+find_dependency(Qt@QT_MAJOR_VERSION@Widgets @QT_REQUIRED_VERSION@)
+find_dependency(KF@QT_MAJOR_VERSION@CoreAddons @KF5_MIN_VERSION@)
+find_dependency(AccountsQt@QT_MAJOR_VERSION@ @ACCOUNTSQT_DEP_VERSION@)
+find_dependency(SignOnQt@QT_MAJOR_VERSION@ @SIGNONQT_DEP_VERSION@)
 
-include("${CMAKE_CURRENT_LIST_DIR}/KAccountsTargets.cmake")
+include("${CMAKE_CURRENT_LIST_DIR}/KAccounts@KACCOUNTS_SUFFIX@Targets.cmake")
 include("${CMAKE_CURRENT_LIST_DIR}/KAccountsMacros.cmake")
 
 set(KACCOUNTS_MACROS_PATH "${CMAKE_CURRENT_LIST_DIR}")
diff -pruN 4:22.12.3-1/src/lib/accountservicetogglejob.cpp 4:24.02.2-1/src/lib/accountservicetogglejob.cpp
--- 4:22.12.3-1/src/lib/accountservicetogglejob.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/accountservicetogglejob.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -10,6 +10,9 @@
 #include <Accounts/Manager>
 #include <QDebug>
 
+namespace KAccounts
+{
+
 class AccountServiceToggleJob::Private
 {
 public:
@@ -129,3 +132,4 @@ void AccountServiceToggleJob::start()
         emitResult();
     }
 }
+}
diff -pruN 4:22.12.3-1/src/lib/accountservicetogglejob.h 4:24.02.2-1/src/lib/accountservicetogglejob.h
--- 4:22.12.3-1/src/lib/accountservicetogglejob.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/accountservicetogglejob.h	2024-04-08 15:00:12.000000000 +0000
@@ -13,6 +13,9 @@
 
 #include <QStringList>
 
+namespace KAccounts
+{
+
 /**
  * @brief A job used to change the enabled state of a specific service on a specific account
  */
@@ -46,4 +49,7 @@ private:
     class Private;
     Private *d;
 };
+
+};
+
 #endif // ACCOUNTSERVICETOGGLE_H
diff -pruN 4:22.12.3-1/src/lib/accountsmodel.cpp 4:24.02.2-1/src/lib/accountsmodel.cpp
--- 4:22.12.3-1/src/lib/accountsmodel.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/accountsmodel.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -20,6 +20,9 @@
 #include <Accounts/Account>
 #include <Accounts/Manager>
 
+namespace KAccounts
+{
+
 class AccountsModel::Private : public QObject
 {
 public:
@@ -179,3 +182,5 @@ QVariant AccountsModel::data(const QMode
 
     return data;
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/accountsmodel.h 4:24.02.2-1/src/lib/accountsmodel.h
--- 4:22.12.3-1/src/lib/accountsmodel.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/accountsmodel.h	2024-04-08 15:00:12.000000000 +0000
@@ -14,6 +14,9 @@
 
 #include <Accounts/Account>
 
+namespace KAccounts
+{
+
 /**
  * @brief A model representing all the accounts registered on a system
  *
@@ -59,4 +62,6 @@ private:
     Private *d;
 };
 
+};
+
 #endif // ACCOUNTS_MODEL_H
diff -pruN 4:22.12.3-1/src/lib/changeaccountdisplaynamejob.cpp 4:24.02.2-1/src/lib/changeaccountdisplaynamejob.cpp
--- 4:22.12.3-1/src/lib/changeaccountdisplaynamejob.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/changeaccountdisplaynamejob.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -11,6 +11,9 @@
 #include <KLocalizedString>
 #include <QDebug>
 
+namespace KAccounts
+{
+
 class ChangeAccountDisplayNameJob::Private
 {
 public:
@@ -82,3 +85,5 @@ void ChangeAccountDisplayNameJob::start(
         emitResult();
     }
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/changeaccountdisplaynamejob.h 4:24.02.2-1/src/lib/changeaccountdisplaynamejob.h
--- 4:22.12.3-1/src/lib/changeaccountdisplaynamejob.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/changeaccountdisplaynamejob.h	2024-04-08 15:00:12.000000000 +0000
@@ -13,6 +13,9 @@
 
 #include <QStringList>
 
+namespace KAccounts
+{
+
 /**
  * @brief A job used to change the human-readable name of a specified account
  *
@@ -42,4 +45,7 @@ private:
     class Private;
     Private *d;
 };
+
+};
+
 #endif // CHANGEACCOUNTDISPLAYNAMEJOB_H
diff -pruN 4:22.12.3-1/src/lib/createaccountjob.cpp 4:24.02.2-1/src/lib/createaccountjob.cpp
--- 4:22.12.3-1/src/lib/createaccountjob.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/createaccountjob.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -21,6 +21,9 @@
 
 #include <KLocalizedString>
 
+namespace KAccounts
+{
+
 CreateAccountJob::CreateAccountJob(QObject *parent)
     : CreateAccountJob(QString(), parent)
 {
@@ -93,11 +96,48 @@ void CreateAccountJob::loadPluginAndShow
     connect(ui, &KAccountsUiPlugin::success, this, &CreateAccountJob::pluginFinished, Qt::UniqueConnection);
     connect(ui, &KAccountsUiPlugin::error, this, &CreateAccountJob::pluginError, Qt::UniqueConnection);
     connect(ui, &KAccountsUiPlugin::canceled, this, &CreateAccountJob::pluginCancelled, Qt::UniqueConnection);
+    connect(ui, &KAccountsUiPlugin::startAuthSession, this, &CreateAccountJob::startAuthSession, Qt::UniqueConnection);
 
     ui->setProviderName(m_providerName);
     ui->init(KAccountsUiPlugin::NewAccountDialog);
 }
 
+void CreateAccountJob::startAuthSession(const QVariantMap &data)
+{
+    SignOn::IdentityInfo info;
+    info.setCaption(m_providerName);
+    info.setAccessControlList({QStringLiteral("*")});
+    info.setType(SignOn::IdentityInfo::Application);
+    info.setStoreSecret(true);
+
+    m_identity = SignOn::Identity::newIdentity(info, this);
+    m_identity->storeCredentials();
+
+    connect(m_identity, &SignOn::Identity::info, this, &CreateAccountJob::info);
+    connect(m_identity, &SignOn::Identity::error, [=](const SignOn::Error &err) {
+        qDebug() << "Error storing identity:" << err.message();
+    });
+
+    auto i = data.constBegin();
+    while (i != data.constEnd()) {
+        m_account->setValue(i.key(), i.value());
+        ++i;
+    }
+
+    m_account->syncAndBlock();
+
+    QVariantMap authData = m_accInfo->authData().parameters();
+    authData.insert(QStringLiteral("Embedded"), false);
+
+    SignOn::SessionData sessionData(authData);
+    SignOn::AuthSessionP session = m_identity->createSession(m_accInfo->authData().method());
+    qDebug() << "Starting auth session with" << m_accInfo->authData().method();
+    connect(session, &SignOn::AuthSession::error, this, &CreateAccountJob::sessionError);
+    connect(session, &SignOn::AuthSession::response, this, &CreateAccountJob::sessionResponse);
+
+    session->process(sessionData, m_accInfo->authData().mechanism());
+}
+
 void CreateAccountJob::pluginFinished(const QString &screenName, const QString &secret, const QVariantMap &data)
 {
     // Set up the new identity
@@ -232,3 +272,5 @@ void CreateAccountJob::setProviderName(c
         Q_EMIT providerNameChanged();
     }
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/createaccountjob.h 4:24.02.2-1/src/lib/createaccountjob.h
--- 4:22.12.3-1/src/lib/createaccountjob.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/createaccountjob.h	2024-04-08 15:00:12.000000000 +0000
@@ -27,6 +27,9 @@ class SessionData;
 class IdentityInfo;
 }
 
+namespace KAccounts
+{
+
 /**
  * @brief Create a new account for the specified provider
  */
@@ -53,6 +56,7 @@ private Q_SLOTS:
     void pluginFinished(const QString &screenName, const QString &secret, const QVariantMap &map);
     void pluginError(const QString &error);
     void pluginCancelled();
+    void startAuthSession(const QVariantMap &data);
 
 Q_SIGNALS:
     void providerNameChanged();
@@ -68,4 +72,7 @@ private:
     SignOn::Identity *m_identity = nullptr;
     bool m_done = false;
 };
+
+};
+
 #endif // CREATE_ACCOUNT_JOB_H
diff -pruN 4:22.12.3-1/src/lib/getcredentialsjob.cpp 4:24.02.2-1/src/lib/getcredentialsjob.cpp
--- 4:22.12.3-1/src/lib/getcredentialsjob.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/getcredentialsjob.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -17,6 +17,9 @@
 #include <QDebug>
 #include <QTimer>
 
+namespace KAccounts
+{
+
 class GetCredentialsJob::Private
 {
 public:
@@ -139,7 +142,12 @@ Accounts::AccountId GetCredentialsJob::a
 
 QVariantMap GetCredentialsJob::credentialsData() const
 {
-    return d->sessionData.toMap().unite(d->authData);
+    auto data = d->sessionData.toMap();
+    data.insert(d->authData);
+
+    return data;
+}
+
 }
 
 #include "moc_getcredentialsjob.cpp"
diff -pruN 4:22.12.3-1/src/lib/getcredentialsjob.h 4:24.02.2-1/src/lib/getcredentialsjob.h
--- 4:22.12.3-1/src/lib/getcredentialsjob.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/getcredentialsjob.h	2024-04-08 15:00:12.000000000 +0000
@@ -17,6 +17,9 @@ namespace Accounts
 class Manager;
 }
 
+namespace KAccounts
+{
+
 /**
  * @brief A KJob for obtaining user's credentials for the given Accounts::AccountId
  */
@@ -80,4 +83,6 @@ private:
     Q_PRIVATE_SLOT(d, void getCredentials())
 };
 
+};
+
 #endif // GET_CREDENTIALS_JOB_H
diff -pruN 4:22.12.3-1/src/lib/kaccountsdplugin.cpp 4:24.02.2-1/src/lib/kaccountsdplugin.cpp
--- 4:22.12.3-1/src/lib/kaccountsdplugin.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/kaccountsdplugin.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -7,6 +7,9 @@
 
 #include "kaccountsdplugin.h"
 
+namespace KAccounts
+{
+
 KAccountsDPlugin::KAccountsDPlugin(QObject *parent, const QVariantList & /*args*/)
     : QObject(parent)
 {
@@ -15,3 +18,5 @@ KAccountsDPlugin::KAccountsDPlugin(QObje
 KAccountsDPlugin::~KAccountsDPlugin()
 {
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/kaccountsdplugin.h 4:24.02.2-1/src/lib/kaccountsdplugin.h
--- 4:22.12.3-1/src/lib/kaccountsdplugin.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/kaccountsdplugin.h	2024-04-08 15:00:12.000000000 +0000
@@ -14,6 +14,9 @@
 #include <Accounts/Service>
 #include <QObject>
 
+namespace KAccounts
+{
+
 /**
  * Plugin for KAccounts daemon
  *
@@ -76,4 +79,6 @@ public Q_SLOTS:
     virtual void onServiceDisabled(const Accounts::AccountId accountId, const Accounts::Service &service) = 0;
 };
 
+};
+
 #endif // KACCOUNTSDPLUGIN_H
diff -pruN 4:22.12.3-1/src/lib/kaccountsuiplugin.cpp 4:24.02.2-1/src/lib/kaccountsuiplugin.cpp
--- 4:22.12.3-1/src/lib/kaccountsuiplugin.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/kaccountsuiplugin.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -10,6 +10,9 @@
 #include <QVariant>
 #include <QWindow>
 
+namespace KAccounts
+{
+
 KAccountsUiPlugin::KAccountsUiPlugin(QObject *parent)
     : QObject(parent)
 {
@@ -24,4 +27,6 @@ QWindow *KAccountsUiPlugin::transientPar
     return property("transientParent").value<QWindow *>();
 }
 
+};
+
 #include "moc_kaccountsuiplugin.cpp"
diff -pruN 4:22.12.3-1/src/lib/kaccountsuiplugin.h 4:24.02.2-1/src/lib/kaccountsuiplugin.h
--- 4:22.12.3-1/src/lib/kaccountsuiplugin.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/kaccountsuiplugin.h	2024-04-08 15:00:12.000000000 +0000
@@ -14,6 +14,9 @@
 
 class QWindow;
 
+namespace KAccounts
+{
+
 class KACCOUNTS_EXPORT KAccountsUiPlugin : public QObject
 {
     Q_OBJECT
@@ -77,6 +80,12 @@ Q_SIGNALS:
     void success(const QString &username, const QString &password, const QVariantMap &additionalData);
 
     /**
+     * Emit this to start an auth session. Any values in data are passed to the started session.
+     * This is useful e.g. when doing oauth login but you need to show a UI to get some data before.
+     */
+    void startAuthSession(const QVariantMap &data);
+
+    /**
      * Emitted when there has been an error during the authentication
      *
      * @param errorString The error that has occurred
@@ -89,6 +98,8 @@ Q_SIGNALS:
     void canceled();
 };
 
-Q_DECLARE_INTERFACE(KAccountsUiPlugin, "org.kde.kaccounts.UiPlugin")
+};
+
+Q_DECLARE_INTERFACE(KAccounts::KAccountsUiPlugin, "org.kde.kaccounts.UiPlugin")
 
 #endif // KACCOUNTSUIPLUGIN_H
diff -pruN 4:22.12.3-1/src/lib/providersmodel.cpp 4:24.02.2-1/src/lib/providersmodel.cpp
--- 4:22.12.3-1/src/lib/providersmodel.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/providersmodel.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -10,6 +10,9 @@
 #include <Accounts/Manager>
 #include <Accounts/Provider>
 
+namespace KAccounts
+{
+
 class ProvidersModel::Private
 {
 public:
@@ -94,7 +97,7 @@ QVariant ProvidersModel::data(const QMod
                         ++i;
                     }
                 }
-                data.setValue<int>(i);
+                data.setValue(i);
                 break;
             }
             default:
@@ -105,3 +108,5 @@ QVariant ProvidersModel::data(const QMod
     }
     return data;
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/providersmodel.h 4:24.02.2-1/src/lib/providersmodel.h
--- 4:22.12.3-1/src/lib/providersmodel.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/providersmodel.h	2024-04-08 15:00:12.000000000 +0000
@@ -11,6 +11,9 @@
 
 #include <QAbstractListModel>
 
+namespace KAccounts
+{
+
 /**
  * @brief A model which represents the available providers
  *
@@ -49,4 +52,6 @@ private:
     Private *d;
 };
 
+};
+
 #endif // PROVIDERS_MODEL_H
diff -pruN 4:22.12.3-1/src/lib/removeaccountjob.cpp 4:24.02.2-1/src/lib/removeaccountjob.cpp
--- 4:22.12.3-1/src/lib/removeaccountjob.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/removeaccountjob.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -11,6 +11,9 @@
 #include <QDebug>
 #include <SignOn/Identity>
 
+namespace KAccounts
+{
+
 class RemoveAccountJob::Private
 {
 public:
@@ -71,3 +74,5 @@ void RemoveAccountJob::start()
         emitResult();
     }
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/removeaccountjob.h 4:24.02.2-1/src/lib/removeaccountjob.h
--- 4:22.12.3-1/src/lib/removeaccountjob.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/removeaccountjob.h	2024-04-08 15:00:12.000000000 +0000
@@ -13,6 +13,9 @@
 
 #include <QString>
 
+namespace KAccounts
+{
+
 /**
  * @brief A job which will attempt to remove the specified account
  */
@@ -34,4 +37,7 @@ private:
     class Private;
     Private *d;
 };
+
+};
+
 #endif // REMOVEACCOUNT_H
diff -pruN 4:22.12.3-1/src/lib/servicesmodel.cpp 4:24.02.2-1/src/lib/servicesmodel.cpp
--- 4:22.12.3-1/src/lib/servicesmodel.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/servicesmodel.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -18,6 +18,9 @@
 #include <Accounts/Account>
 #include <Accounts/Manager>
 
+namespace KAccounts
+{
+
 class ServicesModel::Private : public QObject
 {
 public:
@@ -80,11 +83,9 @@ QVariant ServicesModel::data(const QMode
                 data.setValue(service.name());
                 break;
             case DescriptionRole:
-#if ACCOUNTSQT5_VERSION_MAJOR == 1 && ACCOUNTSQT5_VERSION_MINOR >= 16
                 // Not all services have descriptions and UIs should be designed with that in mind.
                 // Consequently, we can accept not having a fallback for this.
                 data.setValue(service.description());
-#endif
                 break;
             case DisplayNameRole:
                 data.setValue(service.displayName());
@@ -181,3 +182,5 @@ QString ServicesModel::accountIconName()
     }
     return QString::fromLatin1("user-identity");
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/servicesmodel.h 4:24.02.2-1/src/lib/servicesmodel.h
--- 4:22.12.3-1/src/lib/servicesmodel.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/servicesmodel.h	2024-04-08 15:00:12.000000000 +0000
@@ -12,6 +12,9 @@
 
 #include <QAbstractListModel>
 
+namespace KAccounts
+{
+
 /**
  * @brief A model which represents the services in a single account
  *
@@ -87,4 +90,6 @@ private:
     Private *d;
 };
 
+};
+
 #endif // SERVICES_MODEL_H
diff -pruN 4:22.12.3-1/src/lib/uipluginsmanager.cpp 4:24.02.2-1/src/lib/uipluginsmanager.cpp
--- 4:22.12.3-1/src/lib/uipluginsmanager.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/uipluginsmanager.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -18,7 +18,8 @@
 #include <QStringList>
 #include <QWindow>
 
-using namespace KAccounts;
+namespace KAccounts
+{
 
 class UiPluginsManagerPrivate
 {
@@ -117,3 +118,5 @@ KAccountsUiPlugin *UiPluginsManager::plu
 
     return s_instance->pluginsForServices.value(service);
 }
+
+};
diff -pruN 4:22.12.3-1/src/lib/uipluginsmanager.h 4:24.02.2-1/src/lib/uipluginsmanager.h
--- 4:22.12.3-1/src/lib/uipluginsmanager.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/lib/uipluginsmanager.h	2024-04-08 15:00:12.000000000 +0000
@@ -9,10 +9,9 @@
 
 #include <QList>
 
-class KAccountsUiPlugin;
-
 namespace KAccounts
 {
+class KAccountsUiPlugin;
 class UiPluginsManager
 {
 public:
@@ -21,6 +20,6 @@ public:
     static KAccountsUiPlugin *pluginForName(const QString &name);
 };
 
-}
+};
 
 #endif // UIPLUGINSMANAGER_H
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/CMakeLists.txt 4:24.02.2-1/src/plugins/kio-webdav/CMakeLists.txt
--- 4:22.12.3-1/src/plugins/kio-webdav/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -1,14 +1,6 @@
 set(kio-webdav_SRCS
     kioservices.cpp
-    createnetattachjob.cpp
-    removenetattachjob.cpp
-    createkioservice.cpp
-    removekioservice.cpp
     kioservices.h
-    createnetattachjob.h
-    removenetattachjob.h
-    createkioservice.h
-    removekioservice.h
 )
 
 kcoreaddons_add_plugin(kaccounts_kio_webdav_plugin
@@ -19,13 +11,14 @@ kcoreaddons_add_plugin(kaccounts_kio_web
 target_link_libraries(kaccounts_kio_webdav_plugin
     Qt::Core
     Qt::Widgets
-    KF5::CoreAddons
-    KF5::ConfigCore
-    KF5::Wallet
-    KF5::KIOCore
-    KF5::I18n
-    KF5::DBusAddons
+    KF${QT_MAJOR_VERSION}::CoreAddons
+    KF${QT_MAJOR_VERSION}::ConfigCore
+    KF${QT_MAJOR_VERSION}::Wallet
+    KF${QT_MAJOR_VERSION}::KIOCore
+    KF${QT_MAJOR_VERSION}::I18n
+    KF${QT_MAJOR_VERSION}::DBusAddons
     kaccounts
     ${ACCOUNTSQT_LIBRARIES}
     ${SIGNONQT_LIBRARIES}
+    QCoro::Core
 )
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/createkioservice.cpp 4:24.02.2-1/src/plugins/kio-webdav/createkioservice.cpp
--- 4:22.12.3-1/src/plugins/kio-webdav/createkioservice.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/createkioservice.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,107 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#include "createkioservice.h"
-#include "../lib/getcredentialsjob.h"
-#include "createnetattachjob.h"
-#include <core.h>
-
-#include <Accounts/Manager>
-#include <QDebug>
-
-CreateKioService::CreateKioService(QObject *parent)
-    : KJob(parent)
-{
-    m_manager = KAccounts::accountsManager();
-}
-
-CreateKioService::~CreateKioService()
-{
-    delete m_account;
-}
-
-void CreateKioService::start()
-{
-    QMetaObject::invokeMethod(this, "createKioService", Qt::QueuedConnection);
-}
-
-void CreateKioService::createKioService()
-{
-    qDebug();
-    m_account = m_manager->account(m_accountId);
-
-    GetCredentialsJob *job = new GetCredentialsJob(m_accountId, QString(), QString(), this);
-    connect(job, &GetCredentialsJob::finished, this, &CreateKioService::gotCredentials);
-    job->setServiceType(m_serviceType);
-    job->start();
-}
-
-void CreateKioService::gotCredentials(KJob *job)
-{
-    qDebug();
-    if (job->error()) {
-        setError(job->error());
-        setErrorText(job->errorText());
-        emitResult();
-        return;
-    }
-
-    GetCredentialsJob *gjob = qobject_cast<GetCredentialsJob *>(job);
-    const QVariantMap data = gjob->credentialsData();
-
-    const Accounts::Service service = m_manager->service(m_serviceName);
-    const QString host = m_account->value(QStringLiteral("dav/host")).toString();
-    const QString path = m_account->value(QStringLiteral("dav/storagePath")).toString();
-
-    m_account->selectService(service);
-    const QString username = data[QStringLiteral("UserName")].toString();
-    CreateNetAttachJob *netJob = new CreateNetAttachJob(this);
-    connect(netJob, &CreateNetAttachJob::finished, this, &CreateKioService::netAttachCreated);
-
-    netJob->setHost(host);
-    netJob->setPath(path);
-    netJob->setUsername(username);
-    netJob->setPassword(data[QStringLiteral("Secret")].toString());
-    netJob->setIcon(service.iconName());
-    netJob->setUniqueId(QString::number(m_accountId) + QLatin1Char('_') + m_serviceName);
-    netJob->setName(m_manager->provider(service.provider()).displayName() + QLatin1Char(' ') + service.displayName());
-    netJob->start();
-}
-
-void CreateKioService::netAttachCreated(KJob *job)
-{
-    emitResult();
-}
-
-Accounts::AccountId CreateKioService::accountId() const
-{
-    return m_accountId;
-}
-
-void CreateKioService::setAccountId(const Accounts::AccountId accId)
-{
-    m_accountId = accId;
-}
-
-QString CreateKioService::serviceName() const
-{
-    return m_serviceName;
-}
-
-void CreateKioService::setServiceName(const QString &serviceName)
-{
-    m_serviceName = serviceName;
-}
-
-QString CreateKioService::serviceType() const
-{
-    return m_serviceType;
-}
-
-void CreateKioService::setServiceType(const QString &serviceType)
-{
-    m_serviceType = serviceType;
-}
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/createkioservice.h 4:24.02.2-1/src/plugins/kio-webdav/createkioservice.h
--- 4:22.12.3-1/src/plugins/kio-webdav/createkioservice.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/createkioservice.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,58 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#ifndef CREATE_KIOSERVICE_H
-#define CREATE_KIOSERVICE_H
-
-#include <KJob>
-
-#include <Accounts/Account>
-
-namespace Accounts
-{
-class Manager;
-}
-
-namespace KWallet
-{
-class Wallet;
-}
-
-class CreateKioService : public KJob
-{
-    Q_OBJECT
-
-public:
-    explicit CreateKioService(QObject *parent = nullptr);
-    ~CreateKioService() override;
-
-    void start() override;
-
-    Accounts::AccountId accountId() const;
-    void setAccountId(const Accounts::AccountId accId);
-
-    QString serviceName() const;
-    void setServiceName(const QString &serviceName);
-
-    QString serviceType() const;
-    void setServiceType(const QString &serviceType);
-
-private Q_SLOTS:
-    void createKioService();
-    void gotCredentials(KJob *job);
-    void netAttachCreated(KJob *job);
-
-private:
-    void createDesktopFile();
-
-    Accounts::Manager *m_manager = nullptr;
-    Accounts::Account *m_account = nullptr;
-    Accounts::AccountId m_accountId;
-    QString m_serviceName;
-    QString m_serviceType;
-};
-
-#endif // CREATE_KIOSERVICE_H
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/createnetattachjob.cpp 4:24.02.2-1/src/plugins/kio-webdav/createnetattachjob.cpp
--- 4:22.12.3-1/src/plugins/kio-webdav/createnetattachjob.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/createnetattachjob.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,235 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#include "createnetattachjob.h"
-
-#include <Accounts/Manager>
-
-#include <KConfig>
-#include <KConfigGroup>
-#include <KDirNotify>
-#include <KIO/Job>
-#include <KWallet>
-
-#include <QApplication>
-#include <QDebug>
-#include <QDir>
-#include <QRegularExpression>
-#include <QUrl>
-#include <QWidget>
-
-using namespace KWallet;
-
-CreateNetAttachJob::CreateNetAttachJob(QObject *parent)
-    : KJob(parent)
-{
-}
-
-CreateNetAttachJob::~CreateNetAttachJob()
-{
-    delete m_wallet;
-}
-
-void CreateNetAttachJob::start()
-{
-    QMetaObject::invokeMethod(this, "createNetAttach", Qt::QueuedConnection);
-}
-
-void CreateNetAttachJob::createNetAttach()
-{
-    qDebug();
-    WId windowId = 0;
-    if (qApp->activeWindow()) {
-        windowId = qApp->activeWindow()->winId();
-    }
-    m_wallet = Wallet::openWallet(Wallet::NetworkWallet(), windowId, Wallet::Asynchronous);
-
-    connect(m_wallet, &KWallet::Wallet::walletOpened, this, &CreateNetAttachJob::walletOpened);
-}
-
-void CreateNetAttachJob::walletOpened(bool opened)
-{
-    qDebug();
-    if (!opened) {
-        setError(-1);
-        setErrorText(QStringLiteral("Can't open wallet"));
-        emitResult();
-        return;
-    }
-
-    getRealm();
-}
-
-void CreateNetAttachJob::getRealm()
-{
-    qDebug();
-    QUrl url;
-    url.setHost(m_host);
-    url.setUserName(m_username);
-    url.setScheme(QStringLiteral("webdavs"));
-    url.setPath(m_path);
-
-    if (!m_realm.isEmpty()) {
-        createDesktopFile(url);
-        return;
-    }
-
-    KIO::TransferJob *job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
-    connect(job, &KIO::TransferJob::finished, this, &CreateNetAttachJob::gotRealm);
-    KIO::MetaData data;
-    data.insert(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
-    job->setMetaData(data);
-    job->setUiDelegate(nullptr);
-    job->start();
-}
-
-void CreateNetAttachJob::gotRealm(KJob *job)
-{
-    KIO::TransferJob *hJob = qobject_cast<KIO::TransferJob *>(job);
-    QRegularExpression rx(QStringLiteral("www-authenticate: Basic realm=\"([^\"]+)\""));
-    Q_ASSERT(rx.isValid());
-    QString headers = hJob->metaData().value(QStringLiteral("HTTP-Headers"));
-
-    auto match = rx.match(headers);
-
-    if (match.hasMatch()) {
-        m_realm = match.captured(1);
-    }
-
-    createDesktopFile(hJob->url());
-}
-
-void CreateNetAttachJob::createDesktopFile(const QUrl &url)
-{
-    qDebug();
-
-    const QString folderPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/remoteview/");
-
-    QDir saveDir(folderPath);
-    if (!saveDir.exists()) {
-        if (!saveDir.mkpath(folderPath)) {
-            qWarning() << "Directory" << folderPath << "for storage couldn't be created!";
-        }
-    }
-    const QString path = folderPath + m_uniqueId + QStringLiteral(".desktop");
-
-    qDebug() << "Creating knetAttach place";
-    qDebug() << path;
-    qDebug() << url.host();
-    qDebug() << url.toString();
-
-    KConfig _desktopFile(path, KConfig::SimpleConfig);
-    KConfigGroup desktopFile(&_desktopFile, "Desktop Entry");
-
-    desktopFile.writeEntry("Icon", m_icon);
-    desktopFile.writeEntry("Name", m_name);
-    desktopFile.writeEntry("Type", "Link");
-    desktopFile.writeEntry("URL", url.toString());
-    //     desktopFile.writeEntry("Charset", url.fileEncoding());
-    desktopFile.sync();
-
-    QString walletUrl(url.scheme());
-    walletUrl.append(QStringLiteral("-"));
-    walletUrl.append(m_username);
-    walletUrl.append(QStringLiteral("@"));
-    walletUrl.append(url.host());
-    walletUrl.append(QStringLiteral(":-1-")); // Overwrite the first option
-
-    QMap<QString, QString> info;
-    info[QStringLiteral("login")] = m_username;
-    info[QStringLiteral("password")] = m_password;
-
-    m_wallet->setFolder(QStringLiteral("Passwords"));
-
-    if (!m_realm.isEmpty()) {
-        m_wallet->writeMap(walletUrl + m_realm, info);
-    }
-    m_wallet->writeMap(walletUrl + QStringLiteral("webdav"), info);
-    m_wallet->sync();
-
-    org::kde::KDirNotify::emitFilesAdded(QUrl(QStringLiteral("remote:/")));
-
-    emitResult();
-}
-
-QString CreateNetAttachJob::host() const
-{
-    return m_host;
-}
-void CreateNetAttachJob::setHost(const QString &host)
-{
-    m_host = host;
-}
-
-QString CreateNetAttachJob::path() const
-{
-    return m_path;
-}
-
-void CreateNetAttachJob::setPath(const QString &path)
-{
-    m_path = path;
-}
-
-QString CreateNetAttachJob::realm() const
-{
-    return m_realm;
-}
-
-void CreateNetAttachJob::setRealm(const QString &realm)
-{
-    m_realm = realm;
-}
-
-QString CreateNetAttachJob::name() const
-{
-    return m_name;
-}
-
-void CreateNetAttachJob::setName(const QString &name)
-{
-    m_name = name;
-}
-
-QString CreateNetAttachJob::username() const
-{
-    return m_username;
-}
-
-void CreateNetAttachJob::setUsername(const QString &username)
-{
-    m_username = username;
-}
-
-QString CreateNetAttachJob::password() const
-{
-    return m_password;
-}
-
-void CreateNetAttachJob::setPassword(const QString &password)
-{
-    m_password = password;
-}
-
-QString CreateNetAttachJob::uniqueId() const
-{
-    return m_uniqueId;
-}
-
-void CreateNetAttachJob::setUniqueId(const QString &uniqueId)
-{
-    m_uniqueId = uniqueId;
-}
-
-QString CreateNetAttachJob::icon() const
-{
-    return m_icon;
-}
-
-void CreateNetAttachJob::setIcon(const QString &icon)
-{
-    m_icon = icon;
-}
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/createnetattachjob.h 4:24.02.2-1/src/plugins/kio-webdav/createnetattachjob.h
--- 4:22.12.3-1/src/plugins/kio-webdav/createnetattachjob.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/createnetattachjob.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#ifndef CREATE_NETATTACH_H
-#define CREATE_NETATTACH_H
-
-#include <KJob>
-#include <QUrl>
-
-namespace KWallet
-{
-class Wallet;
-}
-
-class CreateNetAttachJob : public KJob
-{
-    Q_OBJECT
-
-public:
-    explicit CreateNetAttachJob(QObject *parent = nullptr);
-    ~CreateNetAttachJob() override;
-
-    void start() override;
-
-    QString host() const;
-    void setHost(const QString &host);
-
-    QString path() const;
-    void setPath(const QString &path);
-
-    QString realm() const;
-    void setRealm(const QString &realm);
-
-    QString name() const;
-    void setName(const QString &name);
-
-    QString username() const;
-    void setUsername(const QString &username);
-
-    QString password() const;
-    void setPassword(const QString &password);
-
-    QString uniqueId() const;
-    void setUniqueId(const QString &uniqueId);
-
-    QString icon() const;
-    void setIcon(const QString &icon);
-
-private Q_SLOTS:
-    void createNetAttach();
-    void walletOpened(bool opened);
-    void gotRealm(KJob *job);
-
-private:
-    void getRealm();
-    void createDesktopFile(const QUrl &url);
-
-    QString m_host;
-    QString m_path;
-    QString m_realm;
-    QString m_name;
-    QString m_username;
-    QString m_password;
-    QString m_uniqueId;
-    QString m_icon;
-
-    KWallet::Wallet *m_wallet = nullptr;
-};
-
-#endif // CREATE_NETATTACH_H
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/kio-webdav.json 4:24.02.2-1/src/plugins/kio-webdav/kio-webdav.json
--- 4:22.12.3-1/src/plugins/kio-webdav/kio-webdav.json	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/kio-webdav.json	2024-04-08 15:00:12.000000000 +0000
@@ -11,11 +11,13 @@
         "Description[de]": "WebDAV-Freigaben mit KIO einhängen",
         "Description[el]": "Προσάρτηση κοινών πόρων WebDAV με το KIO",
         "Description[en_GB]": "Mount WebDAV shares with KIO",
+        "Description[eo]": "Munti WebDAV-komunaĵojn per KIO",
         "Description[es]": "Montar recursos compartidos WebDAV con KIO",
         "Description[et]": "WebDAV-i jagatud ressursside ühendamine KIO-mooduli abil",
         "Description[eu]": "Muntatu WebDAV partekatzeak KIO erabiliz",
         "Description[fi]": "Liitä WebDAV-jakoja KIOlla",
         "Description[fr]": "Montage des partages WebDAV avec KIO",
+        "Description[gl]": "Monta comparticións de WebDAV con KIO",
         "Description[hu]": "WebDAV megosztások csatlakoztatása KIO-val",
         "Description[ia]": "Monta areas compartite de WebDAV con KIO",
         "Description[id]": "Kaitkan berbagi WebDAV dengan KIO",
@@ -54,11 +56,13 @@
         "Name[de]": "KIO WebDAV",
         "Name[el]": "KIO WebDAV",
         "Name[en_GB]": "KIO WebDAV",
+        "Name[eo]": "KIO-WebDAV",
         "Name[es]": "KIO WebDAV",
         "Name[et]": "WebDAV-i KIO-moodul",
         "Name[eu]": "KIO WebDAV",
         "Name[fi]": "KIO WebDAV",
         "Name[fr]": "KIO WebDAV",
+        "Name[gl]": "KIO WebDAV",
         "Name[hu]": "KIO WebDAV",
         "Name[ia]": "KIO WebDAV",
         "Name[id]": "KIO WebDAV",
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/kioservices.cpp 4:24.02.2-1/src/plugins/kio-webdav/kioservices.cpp
--- 4:22.12.3-1/src/plugins/kio-webdav/kioservices.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/kioservices.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -5,21 +5,32 @@
  */
 
 #include "kioservices.h"
-#include "createkioservice.h"
-#include "createnetattachjob.h"
-#include "removekioservice.h"
+#include "core.h"
+#include "getcredentialsjob.h"
 
+#include <QApplication>
 #include <QDebug>
 #include <QDirIterator>
 #include <QFile>
 #include <QStandardPaths>
+#include <QWidget>
 
+#include <KConfig>
+#include <KConfigGroup>
+#include <KDirNotify>
+#include <KIO/TransferJob>
+#include <KLocalizedString>
 #include <KPluginFactory>
+#include <KWallet>
+
+#include <Accounts/Manager>
+
+using namespace KWallet;
 
 K_PLUGIN_CLASS_WITH_JSON(KIOServices, "kio-webdav.json")
 
 KIOServices::KIOServices(QObject *parent, const QVariantList &args)
-    : KAccountsDPlugin(parent, args)
+    : KAccounts::KAccountsDPlugin(parent, args)
 {
 }
 
@@ -95,19 +106,12 @@ void KIOServices::onServiceDisabled(cons
 
 void KIOServices::enableService(const Accounts::AccountId accId, const Accounts::Service &service)
 {
-    CreateKioService *job = new CreateKioService(this);
-    job->setAccountId(accId);
-    job->setServiceName(service.name());
-    job->setServiceType(service.serviceType());
-    job->start();
+    createNetAttach(accId, service);
 }
 
 void KIOServices::disableService(const Accounts::AccountId accId, const QString &serviceName)
 {
-    RemoveKioService *job = new RemoveKioService(this);
-    job->setServiceName(serviceName);
-    job->setAccountId(accId);
-    job->start();
+    removeNetAttach(QString::number(accId) + QStringLiteral("_") + serviceName);
 }
 
 bool KIOServices::isEnabled(const Accounts::AccountId accId, const QString &serviceName)
@@ -120,4 +124,166 @@ bool KIOServices::isEnabled(const Accoun
     return QFile::exists(path);
 }
 
+QCoro::Task<void> KIOServices::createNetAttach(const Accounts::AccountId accountId, const Accounts::Service &_service)
+{
+    std::unique_ptr<Accounts::Account> account(KAccounts::accountsManager()->account(accountId));
+    const Accounts::Service service = _service;
+
+    KAccounts::GetCredentialsJob *job = new KAccounts::GetCredentialsJob(accountId, QString(), QString(), this);
+    job->setServiceType(service.serviceType());
+    job->start();
+
+    co_await qCoro(job, &KJob::finished);
+
+    if (job->error()) {
+        co_return;
+    }
+
+    const QVariantMap credentials = job->credentialsData();
+
+    const QString host = account->value(QStringLiteral("dav/host")).toString();
+    const QString path = account->value(QStringLiteral("dav/storagePath")).toString();
+
+    account->selectService(service);
+    const QString username = credentials[QStringLiteral("UserName")].toString();
+
+    WId windowId = 0;
+    if (qApp->activeWindow()) {
+        windowId = qApp->activeWindow()->winId();
+    }
+
+    auto wallet = Wallet::openWallet(Wallet::NetworkWallet(), windowId, Wallet::Asynchronous);
+
+    bool opened = co_await qCoro(wallet, &KWallet::Wallet::walletOpened);
+
+    if (!opened) {
+        co_return;
+    }
+
+    QUrl url;
+    url.setHost(host);
+    url.setUserName(username);
+    url.setScheme(QStringLiteral("webdavs"));
+    url.setPath(path);
+
+    const QString realm = co_await getRealm(url);
+
+    const QString folderPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/remoteview/");
+
+    QDir saveDir(folderPath);
+    if (!saveDir.exists()) {
+        if (!saveDir.mkpath(folderPath)) {
+            qWarning() << "Directory" << folderPath << "for storage couldn't be created!";
+        }
+    }
+    const QString desktopFilePath = folderPath + QString::number(accountId) + QLatin1Char('_') + service.name() + QStringLiteral(".desktop");
+
+    qDebug() << "Creating knetAttach place";
+    qDebug() << desktopFilePath;
+    qDebug() << url.host();
+    qDebug() << url.toString();
+
+    KConfig _desktopFile(desktopFilePath, KConfig::SimpleConfig);
+    KConfigGroup desktopFile(&_desktopFile, QStringLiteral("Desktop Entry"));
+
+    const QString label = KAccounts::accountsManager()->provider(service.provider()).displayName() + QLatin1Char(' ') + service.displayName();
+
+    desktopFile.writeEntry("Icon", service.iconName());
+    desktopFile.writeEntry("Name", label);
+    desktopFile.writeEntry("Type", "Link");
+    desktopFile.writeEntry("URL", url.toString());
+    //     desktopFile.writeEntry("Charset", url.fileEncoding());
+    desktopFile.sync();
+
+    QString walletUrl(url.scheme());
+    walletUrl.append(QStringLiteral("-"));
+    walletUrl.append(username);
+    walletUrl.append(QStringLiteral("@"));
+    walletUrl.append(url.host());
+    walletUrl.append(QStringLiteral(":-1-")); // Overwrite the first option
+
+    QMap<QString, QString> info;
+    info[QStringLiteral("login")] = username;
+    info[QStringLiteral("password")] = credentials[QStringLiteral("Secret")].toString();
+
+    wallet->setFolder(QStringLiteral("Passwords"));
+
+    if (!realm.isEmpty()) {
+        wallet->writeMap(walletUrl + realm, info);
+    }
+    wallet->writeMap(walletUrl + QStringLiteral("webdav"), info);
+    wallet->sync();
+
+    org::kde::KDirNotify::emitFilesAdded(QUrl(QStringLiteral("remote:/")));
+}
+
+QCoro::Task<QString> KIOServices::getRealm(const QUrl &url)
+{
+    KIO::TransferJob *job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+    KIO::MetaData data;
+    data.insert(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
+    job->setMetaData(data);
+    job->setUiDelegate(nullptr);
+    job->start();
+
+    co_await qCoro(job, &KJob::finished);
+
+    QRegularExpression rx(QStringLiteral("www-authenticate: Basic realm=\"([^\"]+)\""));
+    Q_ASSERT(rx.isValid());
+    QString headers = job->metaData().value(QStringLiteral("HTTP-Headers"));
+
+    auto match = rx.match(headers);
+
+    if (match.hasMatch()) {
+        co_return match.captured(1);
+    }
+
+    co_return QString();
+}
+
+QCoro::Task<void> KIOServices::removeNetAttach(const QString &id)
+{
+    WId windowId = 0;
+    if (qApp->activeWindow()) {
+        windowId = qApp->activeWindow()->winId();
+    }
+    std::unique_ptr<KWallet::Wallet> wallet(Wallet::openWallet(Wallet::NetworkWallet(), windowId, Wallet::Asynchronous));
+
+    bool opened = co_await qCoro(wallet.get(), &KWallet::Wallet::walletOpened);
+
+    if (!opened) {
+        co_return;
+    }
+
+    QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
+    path.append(QStringLiteral("/remoteview/") + id + QStringLiteral(".desktop"));
+
+    KConfig _desktopFile(path, KConfig::SimpleConfig);
+    KConfigGroup desktopFile(&_desktopFile, QStringLiteral("Desktop Entry"));
+
+    const QUrl url(desktopFile.readEntry("URL", QUrl()));
+    Q_ASSERT(!url.isEmpty());
+
+    qDebug() << url.userName() << url.host() << url;
+
+    QFile::remove(path);
+    org::kde::KDirNotify::emitFilesRemoved(QList<QUrl>() << QUrl(QStringLiteral("remote:/") + id));
+
+    QString walletUrl(QStringLiteral("webdav"));
+    walletUrl.append(QStringLiteral("-"));
+    walletUrl.append(url.userName());
+    walletUrl.append(QStringLiteral("@"));
+    walletUrl.append(url.host());
+    walletUrl.append(QStringLiteral(":-1")); // Overwrite the first option
+
+    wallet->setFolder(QStringLiteral("Passwords"));
+    const QStringList entries = wallet->entryList();
+    for (const QString &entry : entries) {
+        if (!entry.startsWith(walletUrl)) {
+            continue;
+        }
+        wallet->removeEntry(entry);
+    }
+}
+
 #include "kioservices.moc"
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/kioservices.h 4:24.02.2-1/src/plugins/kio-webdav/kioservices.h
--- 4:22.12.3-1/src/plugins/kio-webdav/kioservices.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/kioservices.h	2024-04-08 15:00:12.000000000 +0000
@@ -16,6 +16,8 @@
 #include <Accounts/Account>
 #include <Accounts/Service>
 
+#include <QCoroCore>
+
 class KJob;
 class AkonadiAccounts;
 
@@ -24,7 +26,7 @@ namespace Accounts
 class Manager;
 }
 
-class KIOServices : public KAccountsDPlugin
+class KIOServices : public KAccounts::KAccountsDPlugin
 {
     Q_OBJECT
 
@@ -41,6 +43,9 @@ public Q_SLOTS:
 private:
     void enableService(const Accounts::AccountId accId, const Accounts::Service &service);
     void disableService(const Accounts::AccountId accId, const QString &serviceName);
+    QCoro::Task<void> createNetAttach(const Accounts::AccountId accId, const Accounts::Service &service);
+    QCoro::Task<QString> getRealm(const QUrl &url);
+    QCoro::Task<void> removeNetAttach(const QString &id);
     bool isEnabled(const Accounts::AccountId accId, const QString &serviceName);
 };
 
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/removekioservice.cpp 4:24.02.2-1/src/plugins/kio-webdav/removekioservice.cpp
--- 4:22.12.3-1/src/plugins/kio-webdav/removekioservice.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/removekioservice.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,61 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#include "removekioservice.h"
-#include "removenetattachjob.h"
-
-#include <QDebug>
-#include <QFile>
-
-RemoveKioService::RemoveKioService(QObject *parent)
-    : KJob(parent)
-{
-}
-
-void RemoveKioService::start()
-{
-    QMetaObject::invokeMethod(this, "removeKioService", Qt::QueuedConnection);
-}
-
-void RemoveKioService::removeKioService()
-{
-    qDebug();
-    RemoveNetAttachJob *job = new RemoveNetAttachJob(this);
-    job->setUniqueId(QString::number(m_accountId) + QStringLiteral("_") + m_serviceName);
-    connect(job, &RemoveNetAttachJob::finished, this, &RemoveKioService::removeNetAatachFinished);
-    job->start();
-}
-
-void RemoveKioService::removeNetAatachFinished(KJob *job)
-{
-    qDebug();
-    if (job->error()) {
-        setError(job->error());
-        setErrorText(job->errorText());
-    }
-
-    emitResult();
-}
-
-Accounts::AccountId RemoveKioService::accountId() const
-{
-    return m_accountId;
-}
-
-void RemoveKioService::setAccountId(Accounts::AccountId accId)
-{
-    m_accountId = accId;
-}
-
-QString RemoveKioService::serviceName() const
-{
-    return m_serviceName;
-}
-
-void RemoveKioService::setServiceName(const QString &serviceName)
-{
-    m_serviceName = serviceName;
-}
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/removekioservice.h 4:24.02.2-1/src/plugins/kio-webdav/removekioservice.h
--- 4:22.12.3-1/src/plugins/kio-webdav/removekioservice.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/removekioservice.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#ifndef REMOVE_KIOSERVICE_H
-#define REMOVE_KIOSERVICE_H
-
-#include <KJob>
-
-#include <Accounts/Account>
-
-class RemoveKioService : public KJob
-{
-    Q_OBJECT
-
-public:
-    explicit RemoveKioService(QObject *parent = nullptr);
-
-    void start() override;
-
-    Accounts::AccountId accountId() const;
-    void setAccountId(Accounts::AccountId accId);
-
-    QString serviceName() const;
-    void setServiceName(const QString &serviceName);
-
-private Q_SLOTS:
-    void removeKioService();
-    void removeNetAatachFinished(KJob *job);
-
-private:
-    Accounts::AccountId m_accountId;
-    QString m_serviceName;
-};
-
-#endif // REMOVE_KIOSERVICE_H
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/removenetattachjob.cpp 4:24.02.2-1/src/plugins/kio-webdav/removenetattachjob.cpp
--- 4:22.12.3-1/src/plugins/kio-webdav/removenetattachjob.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/removenetattachjob.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#include "removenetattachjob.h"
-
-#include <QApplication>
-#include <QDebug>
-#include <QFile>
-#include <QUrl>
-#include <QWidget>
-
-#include <KConfig>
-#include <KDirNotify>
-#include <KLocalizedString>
-#include <KWallet/KWallet>
-
-using namespace KWallet;
-RemoveNetAttachJob::RemoveNetAttachJob(QObject *parent)
-    : KJob(parent)
-{
-}
-
-RemoveNetAttachJob::~RemoveNetAttachJob()
-{
-    delete m_wallet;
-}
-
-void RemoveNetAttachJob::start()
-{
-    QMetaObject::invokeMethod(this, "removeNetAttach", Qt::QueuedConnection);
-}
-
-void RemoveNetAttachJob::removeNetAttach()
-{
-    WId windowId = 0;
-    if (qApp->activeWindow()) {
-        windowId = qApp->activeWindow()->winId();
-    }
-    m_wallet = Wallet::openWallet(Wallet::NetworkWallet(), windowId, Wallet::Asynchronous);
-    connect(m_wallet, &KWallet::Wallet::walletOpened, this, &RemoveNetAttachJob::walletOpened);
-}
-
-void RemoveNetAttachJob::walletOpened(bool opened)
-{
-    qDebug();
-    if (!opened) {
-        setError(-1);
-        setErrorText(i18n("Can't open wallet"));
-        emitResult();
-        return;
-    }
-
-    deleteDesktopFile();
-}
-
-void RemoveNetAttachJob::deleteDesktopFile()
-{
-    QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    path.append(QStringLiteral("/remoteview/") + m_uniqueId + QStringLiteral(".desktop"));
-
-    KConfig _desktopFile(path, KConfig::SimpleConfig);
-    KConfigGroup desktopFile(&_desktopFile, "Desktop Entry");
-
-    const QUrl url(desktopFile.readEntry("URL", QUrl()));
-    Q_ASSERT(!url.isEmpty());
-
-    qDebug() << url.userName() << url.host() << url;
-
-    QFile::remove(path);
-    org::kde::KDirNotify::emitFilesRemoved(QList<QUrl>() << QUrl(QStringLiteral("remote:/") + m_uniqueId));
-
-    QString walletUrl(QStringLiteral("webdav"));
-    walletUrl.append(QStringLiteral("-"));
-    walletUrl.append(url.userName());
-    walletUrl.append(QStringLiteral("@"));
-    walletUrl.append(url.host());
-    walletUrl.append(QStringLiteral(":-1")); // Overwrite the first option
-
-    m_wallet->setFolder(QStringLiteral("Passwords"));
-    const QStringList entries = m_wallet->entryList();
-    for (const QString &entry : entries) {
-        if (!entry.startsWith(walletUrl)) {
-            continue;
-        }
-        m_wallet->removeEntry(entry);
-    }
-
-    emitResult();
-}
-
-QString RemoveNetAttachJob::uniqueId() const
-{
-    return m_uniqueId;
-}
-
-void RemoveNetAttachJob::setUniqueId(const QString &uniqueId)
-{
-    m_uniqueId = uniqueId;
-}
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/removenetattachjob.h 4:24.02.2-1/src/plugins/kio-webdav/removenetattachjob.h
--- 4:22.12.3-1/src/plugins/kio-webdav/removenetattachjob.h	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/removenetattachjob.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#ifndef REMOVENETATTACHJOB_H
-#define REMOVENETATTACHJOB_H
-
-#include <KConfigGroup>
-#include <KJob>
-
-namespace KWallet
-{
-class Wallet;
-}
-class RemoveNetAttachJob : public KJob
-{
-    Q_OBJECT
-
-public:
-    explicit RemoveNetAttachJob(QObject *parent);
-    ~RemoveNetAttachJob() override;
-
-    void start() override;
-
-    QString uniqueId() const;
-    void setUniqueId(const QString &uniqueId);
-
-private Q_SLOTS:
-    void removeNetAttach();
-    void walletOpened(bool opened);
-    void deleteDesktopFile();
-
-private:
-    QString m_uniqueId;
-
-    KWallet::Wallet *m_wallet = nullptr;
-};
-
-#endif // REMOVENETATTACHJOB_H
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/tests/CMakeLists.txt 4:24.02.2-1/src/plugins/kio-webdav/tests/CMakeLists.txt
--- 4:22.12.3-1/src/plugins/kio-webdav/tests/CMakeLists.txt	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/tests/CMakeLists.txt	2024-04-08 15:00:12.000000000 +0000
@@ -3,8 +3,8 @@ include(ECMMarkAsTest)
 find_package(Qt5 5.2.0 CONFIG REQUIRED Test)
 
 add_definitions("-DTEST_DATA=\"${CMAKE_CURRENT_SOURCE_DIR}/data/\"")
-include_directories(${CMAKE_CURRENT_BINARY_DIR} ${ACCOUNTSQT_INCLUDE_DIRS} ${SIGNONQT_INCLUDE_DIRS})
-set(COMMON_LINK_LIBS Qt5::Test Qt5::Core Qt5::Xml Qt5::DBus KF5::CoreAddons ${ACCOUNTSQT_LIBRARIES})
+include_directories(${CMAKE_CURRENT_BINARY_DIR} SYSTEM ${ACCOUNTSQT_INCLUDE_DIRS} ${SIGNONQT_INCLUDE_DIRS})
+set(COMMON_LINK_LIBS Qt5::Test Qt5::Core Qt5::Xml Qt5::DBus KF${QT_MAJOR_VERSION}::CoreAddons ${ACCOUNTSQT_LIBRARIES})
 
 set(testname testnetattachjobs)
 add_executable(${testname} ${testname}.cpp
@@ -13,4 +13,4 @@ add_executable(${testname} ${testname}.c
 )
 add_test(kaccounts-${testname} ${testname})
 ecm_mark_as_test(${testname})
-target_link_libraries(${testname} ${COMMON_LINK_LIBS}  KF5::ConfigCore KF5::KIOCore Qt5::Widgets KF5::Wallet)
+target_link_libraries(${testname} ${COMMON_LINK_LIBS}  KF${QT_MAJOR_VERSION}::ConfigCore KF${QT_MAJOR_VERSION}::KIOCore Qt5::Widgets KF${QT_MAJOR_VERSION}::Wallet)
diff -pruN 4:22.12.3-1/src/plugins/kio-webdav/tests/testnetattachjobs.cpp 4:24.02.2-1/src/plugins/kio-webdav/tests/testnetattachjobs.cpp
--- 4:22.12.3-1/src/plugins/kio-webdav/tests/testnetattachjobs.cpp	2023-02-27 04:00:14.000000000 +0000
+++ 4:24.02.2-1/src/plugins/kio-webdav/tests/testnetattachjobs.cpp	2024-04-08 15:00:12.000000000 +0000
@@ -12,7 +12,7 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KDirNotify>
-#include <KWallet/KWallet>
+#include <KWallet>
 
 #include <QDBusAbstractAdaptor>
 #include <QDBusConnection>
@@ -62,7 +62,6 @@ void testNetAttachJobs::testCreate()
     CreateNetAttachJob *job = new CreateNetAttachJob(this) job->setHost("host.com");
     job->setUsername("username");
     job->setPassword("password");
-    job->setIcon("modem");
     job->setUniqueId("test-unique-id");
     job->setPath("files/webdav.php/");
     job->setName("test-service");
